-- ATE Tool database upgrade script 
-- From version     : 1.22.0
-- To version       : 1.23.0
-- Target DB engine : MySQL 5.6.x

-- -----------------------------------------------------
-- Table `tool`.`ProjectPlanningCharter`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `tool`.`ProjectPlanningCharter` (
  `ProjectPlanningCharter_ID` INT NOT NULL AUTO_INCREMENT,
  `Project_ID` INT NOT NULL,
  `Year` INT NOT NULL,
  `Name` VARCHAR(200) CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NOT NULL,
  `Type` ENUM('HRS','SUB','TRV','MAT') CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NOT NULL,
  PRIMARY KEY (`ProjectPlanningCharter_ID`),
  CONSTRAINT `ProjectPlanningCharter_fk1`
    FOREIGN KEY (`Project_ID`)
    REFERENCES `tool`.`Project` (`Project_ID`)
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `tool`.`ProjectPlanningCharterItem`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `tool`.`ProjectPlanningCharterItem` (
  `ProjectPlanningCharterItem_ID` INT NOT NULL AUTO_INCREMENT,
  `ProjectPlanningCharter_ID` INT NOT NULL,
  `Type` ENUM('Person','OrganizationUnit','Subcontractor','Other') CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NOT NULL,
  `Person_ID` VARCHAR(7) CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NULL,
  `OrganizationUnit_ID` INT NULL,
  `Subcontractor_ID` INT NULL,
  `CostShare` DECIMAL(3,2) NOT NULL DEFAULT 0,
  `LabourRate` DECIMAL(3,2) NULL,
  PRIMARY KEY (`ProjectPlanningCharterItem_ID`),
  CONSTRAINT `ProjectPlanningCharterItem_fk1`
    FOREIGN KEY (`ProjectPlanningCharter_ID`)
    REFERENCES `tool`.`ProjectPlanningCharter` (`ProjectPlanningCharter_ID`)
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `ProjectPlanningCharterItem_fk2`
    FOREIGN KEY (`Person_ID`)
    REFERENCES `tool`.`Person` (`EID`)
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `ProjectPlanningCharterItem_fk3`
    FOREIGN KEY (`OrganizationUnit_ID`)
    REFERENCES `tool`.`OrganizationUnit` (`OrganizationUnit_ID`)
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `ProjectPlanningCharterItem_fk4`
    FOREIGN KEY (`Subcontractor_ID`)
    REFERENCES `tool`.`Subcontractor` (`Subcontractor_ID`)
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `tool`.`ProjectPlanningCharterItemBudget`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `tool`.`ProjectPlanningCharterItemBudget` (
  `ProjectPlanningCharterItemBudget_ID` INT NOT NULL AUTO_INCREMENT,
  `ProjectPlanningCharterItem_ID` INT NOT NULL,
  `Month` INT NOT NULL,
  `Budget` FLOAT NOT NULL,
  `BudgetType` ENUM('HRS','USD') NOT NULL,
  PRIMARY KEY (`ProjectPlanningCharterItemBudget_ID`),
  CONSTRAINT `ProjectPlanningCharterItemBudget_fk1`
    FOREIGN KEY (`ProjectPlanningCharterItem_ID`)
    REFERENCES `tool`.`ProjectPlanningCharterItem` (`ProjectPlanningCharterItem_ID`)
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;

-- -----------------------------------------------------
-- Table `tool`.`ProjectPlanningCharterState`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `tool`.`ProjectPlanningCharterState` (
  `Project_ID` INT NOT NULL,
  `Year` INT NOT NULL,
  `WorkPackage_ID` INT(11),
  `ProjectCharter_ID` INT(11),
  `State` ENUM('PlanningOngoing', 'CharterExists', 'Finished') CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NOT NULL,
  `AtLeastOnceFinished` BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY (`Project_ID`, `Year`),
  CONSTRAINT `ProjectPlanningCharterState_fk1`
    FOREIGN KEY (`Project_ID`)
    REFERENCES `tool`.`Project` (`Project_ID`)
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `ProjectPlanningCharterState_fk2`
    FOREIGN KEY (`WorkPackage_ID`)
    REFERENCES `tool`.`WorkPackage` (`WorkPackage_ID`)
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `ProjectPlanningCharterState_fk3`
    FOREIGN KEY (`ProjectCharter_ID`)
    REFERENCES `tool`.`ProjectCharter` (`ProjectCharter_ID`)
    ON DELETE RESTRICT
    ON UPDATE CASCADE)
ENGINE = InnoDB;

-- add support for inactive Subcontractors
ALTER TABLE `Subcontractor` ADD COLUMN `Status` tinyint(1) NOT NULL DEFAULT 1;
UPDATE `Subcontractor` SET `Status` = 1 WHERE `Subcontractor_ID` = 1;
UPDATE `Subcontractor` SET `Status` = 1 WHERE `Subcontractor_ID` = 2;
UPDATE `Subcontractor` SET `Status` = 1 WHERE `Subcontractor_ID` = 3;
UPDATE `Subcontractor` SET `Status` = 1 WHERE `Subcontractor_ID` = 4;
UPDATE `Subcontractor` SET `Status` = 1 WHERE `Subcontractor_ID` = 5;
UPDATE `Subcontractor` SET `Status` = 1 WHERE `Subcontractor_ID` = 6;
UPDATE `Subcontractor` SET `Status` = 1 WHERE `Subcontractor_ID` = 7;
UPDATE `Subcontractor` SET `Status` = 1 WHERE `Subcontractor_ID` = 8;
UPDATE `Subcontractor` SET `Status` = 1 WHERE `Subcontractor_ID` = 9;
UPDATE `Subcontractor` SET `Status` = 1 WHERE `Subcontractor_ID` = 10;
UPDATE `Subcontractor` SET `Status` = 1 WHERE `Subcontractor_ID` = 11;
UPDATE `Subcontractor` SET `Status` = 0 WHERE `Subcontractor_ID` = 12;
UPDATE `Subcontractor` SET `Status` = 1 WHERE `Subcontractor_ID` = 13;
UPDATE `Subcontractor` SET `Status` = 1 WHERE `Subcontractor_ID` = 14;
UPDATE `Subcontractor` SET `Status` = 1 WHERE `Subcontractor_ID` = 15;
UPDATE `Subcontractor` SET `Status` = 1 WHERE `Subcontractor_ID` = 16;
UPDATE `Subcontractor` SET `Status` = 1 WHERE `Subcontractor_ID` = 17;
UPDATE `Subcontractor` SET `Status` = 1 WHERE `Subcontractor_ID` = 18;
UPDATE `Subcontractor` SET `Status` = 0 WHERE `Subcontractor_ID` = 19;
UPDATE `Subcontractor` SET `Status` = 1 WHERE `Subcontractor_ID` = 20;
UPDATE `Subcontractor` SET `Status` = 1 WHERE `Subcontractor_ID` = 21;
UPDATE `Subcontractor` SET `Status` = 1 WHERE `Subcontractor_ID` = 22;
UPDATE `Subcontractor` SET `Status` = 1 WHERE `Subcontractor_ID` = 23;
UPDATE `Subcontractor` SET `Status` = 0 WHERE `Subcontractor_ID` = 24;
UPDATE `Subcontractor` SET `Status` = 0 WHERE `Subcontractor_ID` = 25;
UPDATE `Subcontractor` SET `Status` = 0 WHERE `Subcontractor_ID` = 26;
UPDATE `Subcontractor` SET `Status` = 0 WHERE `Subcontractor_ID` = 27;
UPDATE `Subcontractor` SET `Status` = 0 WHERE `Subcontractor_ID` = 28;
UPDATE `Subcontractor` SET `Status` = 0 WHERE `Subcontractor_ID` = 29;
UPDATE `Subcontractor` SET `Status` = 0 WHERE `Subcontractor_ID` = 30;
UPDATE `Subcontractor` SET `Status` = 0 WHERE `Subcontractor_ID` = 31;
UPDATE `Subcontractor` SET `Status` = 1 WHERE `Subcontractor_ID` = 32;
UPDATE `Subcontractor` SET `Status` = 1 WHERE `Subcontractor_ID` = 33;
UPDATE `Subcontractor` SET `Status` = 1 WHERE `Subcontractor_ID` = 34;
UPDATE `Subcontractor` SET `Status` = 1 WHERE `Subcontractor_ID` = 35;
UPDATE `Subcontractor` SET `Status` = 1 WHERE `Subcontractor_ID` = 36;
UPDATE `Subcontractor` SET `Status` = 1 WHERE `Subcontractor_ID` = 37;
UPDATE `Subcontractor` SET `Status` = 0 WHERE `Subcontractor_ID` = 38;
UPDATE `Subcontractor` SET `Status` = 1 WHERE `Subcontractor_ID` = 39;
UPDATE `Subcontractor` SET `Status` = 1 WHERE `Subcontractor_ID` = 40;


-- update WC names
UPDATE `CostCenter` SET `Name` = 'VIRS Virtual Department ED' WHERE `CostCenter_ID` = 'EEEDZZA7';
UPDATE `CostCenter` SET `Name` = 'ECOE Electronic Hardware QU' WHERE `CostCenter_ID` = 'EEQUZZA1';
UPDATE `CostCenter` SET `Name` = 'ECOE Electronic Hardware ED' WHERE `CostCenter_ID` = 'EEEDZZA3';
UPDATE `CostCenter` SET `Name` = 'ATE Brno EP' WHERE `CostCenter_ID` = 'EEEPZZA1';
UPDATE `CostCenter` SET `Name` = 'USBE Minneapolis 1107 RS' WHERE `CostCenter_ID` = 'EERSZZEI';
UPDATE `CostCenter` SET `Name` = 'ECOE Flight Support Services SD' WHERE `CostCenter_ID` = 'EESDZZC8';
UPDATE `CostCenter` SET `Name` = 'USBE AT&R European OEM PM' WHERE `CostCenter_ID` = 'EAPMZZC2';
UPDATE `CostCenter` SET `Name` = 'USBE ISC EMEAI VE' WHERE `CostCenter_ID` = 'EEVEZZC1';
UPDATE `CostCenter` SET `Name` = 'ECOE Electronic Hardware ED' WHERE `CostCenter_ID` = 'EEEDZZA6';
UPDATE `CostCenter` SET `Name` = 'ECOE Electronic Hardware ED' WHERE `CostCenter_ID` = 'EEEDZZC4';
UPDATE `CostCenter` SET `Name` = 'EOPS Product Integrity PM' WHERE `CostCenter_ID` = 'EAPMZZC1';
UPDATE `CostCenter` SET `Name` = 'VIRS Virtual Department PC' WHERE `CostCenter_ID` = 'EAPCZZC2';
UPDATE `CostCenter` SET `Name` = 'ECOE Sensing, Guidance & Navigation SD' WHERE `CostCenter_ID` = 'EESDZZC5';
UPDATE `CostCenter` SET `Name` = 'ECOE Electronic Hardware GR' WHERE `CostCenter_ID` = 'EEGRZZC1';
UPDATE `CostCenter` SET `Name` = 'ECOE Electronic Hardware CO' WHERE `CostCenter_ID` = 'EECOZZC1';
UPDATE `CostCenter` SET `Name` = 'ECOE Electronic Hardware ED' WHERE `CostCenter_ID` = 'EEEDZZC1';
UPDATE `CostCenter` SET `Name` = 'ECOE Electronic Hardware MD' WHERE `CostCenter_ID` = 'EEMDZZC1';
UPDATE `CostCenter` SET `Name` = 'ECOE Electronic Hardware ED' WHERE `CostCenter_ID` = 'EEEDZZC3';
UPDATE `CostCenter` SET `Name` = 'EOPS Configuration Management & Data Services CM' WHERE `CostCenter_ID` = 'EECMZZC6';
UPDATE `CostCenter` SET `Name` = 'ECOE Control Systems ED' WHERE `CostCenter_ID` = 'EEEDZZC2';
UPDATE `CostCenter` SET `Name` = 'ETS Electronic Test SD' WHERE `CostCenter_ID` = 'EESDZZC4';
UPDATE `CostCenter` SET `Name` = 'ETS Test Systems SD' WHERE `CostCenter_ID` = 'EESDZZC9';
UPDATE `CostCenter` SET `Name` = 'EOPS Product Integrity QU' WHERE `CostCenter_ID` = 'EEQUZZC1';
UPDATE `CostCenter` SET `Name` = 'EOPS Product Integrity QU' WHERE `CostCenter_ID` = 'EEQUZCP1';
UPDATE `CostCenter` SET `Name` = 'EOPS Product Integrity QU' WHERE `CostCenter_ID` = 'EEQUZZC2';
UPDATE `CostCenter` SET `Name` = 'EOPS Product Integrity PJ' WHERE `CostCenter_ID` = 'EAPJZZC1';
UPDATE `CostCenter` SET `Name` = 'ESEA Displays & Graphics SD' WHERE `CostCenter_ID` = 'EESDZCG1';
UPDATE `CostCenter` SET `Name` = 'ECOE Control Systems SY' WHERE `CostCenter_ID` = 'EESYZCS1';
UPDATE `CostCenter` SET `Name` = 'USBE Des Plaines Research 1015 SY' WHERE `CostCenter_ID` = 'EESYZZDP';
UPDATE `CostCenter` SET `Name` = 'ECOE Electronic Hardware ED' WHERE `CostCenter_ID` = 'EEEDQCS1';
UPDATE `CostCenter` SET `Name` = 'ECOE Communication, Navigation & Surveillance PJ' WHERE `CostCenter_ID` = 'EEPJQCS2';
UPDATE `CostCenter` SET `Name` = 'ECOE Communication, Navigation & Surveillance SD' WHERE `CostCenter_ID` = 'EESDQCS2';
UPDATE `CostCenter` SET `Name` = 'ECOE Communication, Navigation & Surveillance SY' WHERE `CostCenter_ID` = 'EESYQCS2';
UPDATE `CostCenter` SET `Name` = 'ECOE Electronic Hardware CO' WHERE `CostCenter_ID` = 'EECOQCS1';
UPDATE `CostCenter` SET `Name` = 'ECOE Control Systems SY' WHERE `CostCenter_ID` = 'EESYQCS1';
UPDATE `CostCenter` SET `Name` = 'ECOE Control Systems VE' WHERE `CostCenter_ID` = 'EEVEQCS1';
UPDATE `CostCenter` SET `Name` = 'ECOE Electronic Hardware ED' WHERE `CostCenter_ID` = 'EEEDQCS2';
UPDATE `CostCenter` SET `Name` = 'ECOE Flight Support Services SD' WHERE `CostCenter_ID` = 'EESDQCM1';
UPDATE `CostCenter` SET `Name` = 'ECOE Electronic Hardware MD' WHERE `CostCenter_ID` = 'EEMDQCS1';
UPDATE `CostCenter` SET `Name` = 'ECOE Sensing, Guidance & Navigation SD' WHERE `CostCenter_ID` = 'EESDQCS3';
UPDATE `CostCenter` SET `Name` = 'EOPS Engineering Tools SD' WHERE `CostCenter_ID` = 'EESDQCO1';
UPDATE `CostCenter` SET `Name` = 'EOPS Product Integrity QU' WHERE `CostCenter_ID` = 'EEQUQCP1';
UPDATE `CostCenter` SET `Name` = 'EOPS Project Support PC' WHERE `CostCenter_ID` = 'EAPCQCI1';
UPDATE `CostCenter` SET `Name` = 'ESEA Air Transport and Specialty Applications SY' WHERE `CostCenter_ID` = 'EESYQCG6';
UPDATE `CostCenter` SET `Name` = 'ESEA Cabine Management System SY' WHERE `CostCenter_ID` = 'EESYQCG8';
UPDATE `CostCenter` SET `Name` = 'ESEA Condition Based Maintenance SD' WHERE `CostCenter_ID` = 'EESDQCG1';
UPDATE `CostCenter` SET `Name` = 'ESEA Condition Based Maintenance SD' WHERE `CostCenter_ID` = 'EESDQCG2';
UPDATE `CostCenter` SET `Name` = 'ESEA Displays & Graphics SD' WHERE `CostCenter_ID` = 'EESDQCG4';
UPDATE `CostCenter` SET `Name` = 'ESEA EPIC APEX SY' WHERE `CostCenter_ID` = 'EESYQCG7';
UPDATE `CostCenter` SET `Name` = 'ESEA Flight Management System SD' WHERE `CostCenter_ID` = 'EESDQCG5';
UPDATE `CostCenter` SET `Name` = 'ETS Electronic Test EL' WHERE `CostCenter_ID` = 'EEELQCT1';
UPDATE `CostCenter` SET `Name` = 'ETS Electronic Test EL' WHERE `CostCenter_ID` = 'EEELQCT2';
UPDATE `CostCenter` SET `Name` = 'USBE Guest XX' WHERE `CostCenter_ID` = 'XXXXXXXX';
UPDATE `CostCenter` SET `Name` = 'HAO Material & Process MT' WHERE `CostCenter_ID` = 'EEMTZZ00';
UPDATE `CostCenter` SET `Name` = 'USBE Minneapolis 1107 RS' WHERE `CostCenter_ID` = 'EERSZZHP';
UPDATE `CostCenter` SET `Name` = 'USBE Minneapolis 1107 RS' WHERE `CostCenter_ID` = 'EERSZZFB';
UPDATE `CostCenter` SET `Name` = 'USBE Minneapolis 1107 RS' WHERE `CostCenter_ID` = 'EERSZZHZ';
UPDATE `CostCenter` SET `Name` = 'HTS System Engineering & Applications xx' WHERE `CostCenter_ID` = 'CZxxxxxx';
UPDATE `CostCenter` SET `Name` = 'USBE Marketing & Product Management SY' WHERE `CostCenter_ID` = 'EESYZZA1';
UPDATE `CostCenter` SET `Name` = 'USBE Moca 2802 PJ' WHERE `CostCenter_ID` = 'EEPJZZI3';
UPDATE `CostCenter` SET `Name` = 'USBE Bendix King PJ' WHERE `CostCenter_ID` = 'EEPJQCB1';
UPDATE `CostCenter` SET `Name` = 'ECOE Control Systems SD' WHERE `CostCenter_ID` = 'EESDQCB1';
UPDATE `CostCenter` SET `Name` = 'USBE Bendix King SY' WHERE `CostCenter_ID` = 'EESYQCB1';
UPDATE `CostCenter` SET `Name` = 'ECOE Control Systems SD' WHERE `CostCenter_ID` = 'EESDQCS1';
UPDATE `CostCenter` SET `Name` = 'USBE Guest SD' WHERE `CostCenter_ID` = 'EESDQCV2';


-- Project Charter checklist
CREATE TABLE IF NOT EXISTS `tool`.`ProjectCharterChecklist` (
  `ProjectCharterChecklist_ID` INT NOT NULL AUTO_INCREMENT,
  `ProjectCharter_ID` INT(11) NOT NULL,
  `Title` VARCHAR(200) CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NOT NULL,
  `Needed1` BOOL NOT NULL DEFAULT 0,
  `Needed2` BOOL NOT NULL DEFAULT 0,
  `Needed3` BOOL NOT NULL DEFAULT 0,
  `Needed4` BOOL NOT NULL DEFAULT 0,
  `Needed5` BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY (`ProjectCharterChecklist_ID`),
  CONSTRAINT `ProjectPlanningCharterChecklist_fk1`
    FOREIGN KEY (`ProjectCharter_ID`)
    REFERENCES `tool`.`ProjectCharter` (`ProjectCharter_ID`)
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;