-- ATE Tool database upgrade script 
-- From version: 1.2.0
-- To version: 1.3.0
-- Target DB engine: MySQL 5.1.x

-- Added Email column for Person 
ALTER TABLE  `Person` ADD  `Email` VARCHAR( 100 ) DEFAULT NULL;

--
-- Table structure for table `ExchangeRate`
--
-- Defines logging table for actions over data
-- or logging of general messages
-- logs can be groupped by Type, Batch or Group, or (ObjectType and ObjectID)

CREATE TABLE IF NOT EXISTS `LogData` (
  `LogID` int(11) NOT NULL AUTO_INCREMENT,
  `Responsible` char(7) COLLATE utf8_unicode_ci NOT NULL,
  `Created` timestamp NOT NULL,
  `Type` enum('debug','info','notice','warning','error','fatal') COLLATE utf8_unicode_ci NOT NULL DEFAULT 'info',
  `Batch` varchar(20) DEFAULT NULL,
  `Group` varchar(20) DEFAULT NULL,
  `ObjectType` varchar(50) DEFAULT NULL,
  `ObjectID` varchar(20) DEFAULT NULL,
  `Message` text,
  PRIMARY KEY (`LogID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

-- new key for cron authentication to application for eCharge actuals update
INSERT INTO `GlobalSetting` (`Key` ,`Value` ,`Default` ,`DataType`)
VALUES ('eCharge.credentials.cronToken', NULL , '', 'string');
INSERT INTO `GlobalSetting` (`Key` ,`Value` ,`Default` ,`DataType`)
VALUES ('eCharge.notifyList', 'petr.novotny@honeywell.com,martin.kotlar@honeywell.com,rostislav.barina@honeywell.com' , '', 'string');

--  Added Table for newly found projects that can be later added to Project table
CREATE TABLE IF NOT EXISTS `ProjectFound` (
  `SAP_ID` varchar(100) COLLATE utf8_unicode_ci NOT NULL,
  `Name` varchar(500) COLLATE utf8_unicode_ci NOT NULL,
  `Blacklisted` tinyint(1) NOT NULL DEFAULT 0,
  PRIMARY KEY (`SAP_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

--  Added Table for newly found projects that can be later added to Project table
CREATE TABLE IF NOT EXISTS `ProjectFoundPlan` (
  `SAP_ID` varchar(100) COLLATE utf8_unicode_ci NOT NULL,
  `Year` int(11) NOT NULL,
  `LastUpdated` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `Plan` text,
  PRIMARY KEY (`SAP_ID`, `Year`),
  CONSTRAINT `ProjectFoundPlan_ibfk_1` FOREIGN KEY (`SAP_ID`) REFERENCES `ProjectFound` (`SAP_ID`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

-- Drop unused Tables
DROP TABLE IF EXISTS `TaskNew`;
DROP TABLE IF EXISTS `WorkPackageNew`;
DROP TABLE IF EXISTS `ProjectNew`;

--
-- Dummy workpackage (no SAP ID and no Name) clean up
--
--- PREPARATIONS
DROP TABLE IF EXISTS `DummyWorkPackageTaskRemap`;
CREATE TABLE `DummyWorkPackageTaskRemap` (
  `Task_ID` int(11) NOT NULL,
  `WorkPackageDummy` int(11) NOT NULL,
  `WorkPackageNew` int(11) NOT NULL, 
  PRIMARY KEY `Task_ID` (`Task_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
DROP PROCEDURE IF EXISTS `RemapDummyWorkPackages`;
DELIMITER ;;
CREATE PROCEDURE `RemapDummyWorkPackages` ()
BEGIN
  DECLARE wid INT;
  DECLARE tid INT;
  DECLARE p_wid INT;
  DECLARE new_wid INT;
  DECLARE wp_sap_id VARCHAR(100);
  DECLARE done INT DEFAULT 0;
  DECLARE dummy_wp_cursor CURSOR FOR SELECT `Task`.`Task_ID`, `WorkPackage`.`WorkPackage_ID` FROM `Task`,`WorkPackage` WHERE `Task`.`WorkPackage_ID`=`WorkPackage`.`WorkPackage_ID`
AND `WorkPackage`.`SAP_ID` IS NULL;
  DECLARE CONTINUE HANDLER FOR NOT FOUND SET done = 1;
  
  OPEN dummy_wp_cursor;
  
  read_loop: LOOP
    FETCH dummy_wp_cursor INTO tid, wid;
    IF done = 1 THEN
      LEAVE read_loop;
    END IF;
    -- find for task first non-NULL workpackage in the WBS tree
    SET new_wid = wid;
    SET wp_sap_id = NULL; 
    REPEAT
      SELECT `Parent_ID` INTO p_wid FROM `WorkPackage` WHERE `WorkPackage_ID`=new_wid;
      SELECT `SAP_ID` INTO wp_sap_id FROM `WorkPackage` WHERE `WorkPackage_ID`=p_wid;
      SET new_wid = p_wid;
    UNTIL (wp_sap_id IS NOT NULL)
    END REPEAT; 
    INSERT INTO `DummyWorkPackageTaskRemap` (`Task_ID`, `WorkPackageDummy`, `WorkPackageNew`) VALUES (tid, wid, new_wid);
    -- SELECT statements can lead to NOT FOUND HANDLER call thus setting done to 1 and prematurely ending the loop
    SET done = 0;
  END LOOP read_loop;  

  CLOSE dummy_wp_cursor;

END ;;
DELIMITER ;

--- FIX
CALL `RemapDummyWorkPackages`;
UPDATE `Task`,`DummyWorkPackageTaskRemap` SET `Task`.`WorkPackage_ID`=`DummyWorkPackageTaskRemap`.`WorkPackageNew` 
WHERE `Task`.`WorkPackage_ID`=`DummyWorkPackageTaskRemap`.`WorkPackageDummy`;
--- CLEAN UP
DELETE FROM `WorkPackage` WHERE `SAP_ID` IS NULL;
DROP TABLE IF EXISTS `DummyWorkPackageTaskRemap`;
DROP PROCEDURE IF EXISTS `RemapDummyWorkPackages`;

--- Type column in project table cannot be NULL
ALTER TABLE `Project` CHANGE `Type` `Type` varchar(20) COLLATE utf8_unicode_ci NOT NULL DEFAULT 'Internal';
