-- ATE Tool database upgrade script 
-- From version     : 1.5.x
-- To version       : 1.6.0
-- Target DB engine : MySQL 5.5.x
--
--

-- Column has been moved into table `ProjectCharterApprovalHistory`
ALTER TABLE `ProjectCharter` DROP COLUMN `FinalApprovalDate`;
-- New column added.
ALTER TABLE `ProjectCharter` ADD COLUMN `DaysForFinalApproval` INT(11) NOT NULL DEFAULT 0;

-- Definition of table `ProjectCharterApproverHistory`
DROP TABLE IF EXISTS `ProjectCharterApproverHistory`;
CREATE TABLE `ProjectCharterApproverHistory` (
  `ProjectCharter_ID` INT(11) NOT NULL,
  `Version` INT(11) NOT NULL,
  `CreationDateTime` DATETIME NOT NULL,
  `Responsible` VARCHAR(7) COLLATE utf8_unicode_ci NOT NULL,
  `LatestVersion` TINYINT NOT NULL DEFAULT '0',
  `BudgetVersion` INT(11) DEFAULT NULL,
  `FileVersion` INT(11) DEFAULT NULL,
  `EmailContent` TEXT COLLATE utf8_unicode_ci,
  `FinalApprovalDate` INT(11) DEFAULT NULL,
  PRIMARY KEY (`ProjectCharter_ID`, `Version`),
  KEY `ProjectCharterApprovalHistory_fk` (`Responsible`),
  CONSTRAINT `ProjectCharterApprovalHistory_fk` FOREIGN KEY (`Responsible`) REFERENCES `Person` (`EID`) ON DELETE NO ACTION ON UPDATE NO ACTION
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

-- Redefinition of table `ProjectCharterApprover`
DROP TABLE IF EXISTS `ProjectCharterApprover`;
CREATE TABLE `ProjectCharterApprover` (
  `ProjectCharterApprover_ID` INT(11) NOT NULL AUTO_INCREMENT,
  `ProjectCharter_ID` INT(11) NOT NULL,
  `Version` INT(11) NOT NULL,
  `Role` VARCHAR(50) COLLATE utf8_unicode_ci NOT NULL,
  `Approver_EID` VARCHAR(7) COLLATE utf8_unicode_ci NOT NULL,
  `Surname` VARCHAR(100) COLLATE utf8_unicode_ci,
  `Name` VARCHAR(100) COLLATE utf8_unicode_ci,
  `Email` VARCHAR(100) COLLATE utf8_unicode_ci,
  `Approval` TINYINT NOT NULL DEFAULT '0',
  `DecisionDateTime` DATETIME,
  `Comment` TEXT COLLATE utf8_unicode_ci,
  `AutoApproved` TINYINT,
  PRIMARY KEY(`ProjectCharterApprover_ID`),
  KEY `ProjectCharterApprover_fk` (`ProjectCharter_ID`, `Version`),
  CONSTRAINT `ProjectCharterApprover_fk` FOREIGN KEY (`ProjectCharter_ID`, `Version`) REFERENCES `ProjectCharterApproverHistory` (`ProjectCharter_ID`, `Version`) ON DELETE NO ACTION ON UPDATE NO ACTION
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;


-- there must always be organization unit assigned to a person
ALTER TABLE `Person` CHANGE `OrganizationUnit_ID` `OrganizationUnit_ID` INT( 11 ) NOT NULL; 

-- drop of current foreign key constraint for Leader column to be regenerated with different rules (below)
ALTER TABLE `OrganizationUnit` DROP FOREIGN KEY `OrganizationUnit_fk`;
ALTER TABLE `OrganizationUnit` DROP INDEX `OrganizationUnit_fk`;

-- not every group has to have Leader in the Person table (it has to be possible to set to NULL to set FOREIGN KEY ON DELETE SET NULL below)
ALTER TABLE `OrganizationUnit` CHANGE `Leader` `Leader` VARCHAR( 7 ) CHARACTER SET utf8 COLLATE utf8_unicode_ci NULL;

-- set new foreign key constraint for Leader column
ALTER TABLE `OrganizationUnit` ADD CONSTRAINT `Leader_fk` FOREIGN KEY (`Leader`) REFERENCES `Person` (`EID`) ON DELETE SET NULL ON UPDATE CASCADE;

-- global settings - new rows
INSERT INTO `tool`.`GlobalSetting` (`Key` ,`Value` ,`Default` ,`DataType`) VALUES 
('charters.finalApprovalFirstRoundDays', NULL , '14', 'int'), 
('charters.finalApprovalNextRoundDays', NULL , '7', 'int');

-- OrganizaitonUnit table - New column added.
ALTER TABLE `OrganizationUnit` ADD COLUMN `Virtual` TINYINT NOT NULL DEFAULT 0;

-- PEC cluster is virtual
UPDATE `OrganizationUnit`
SET `OrganizationUnit`.`Virtual` = 1
WHERE `OrganizationUnit`.`OrganizationUnit_ID` = 67;

-- TaskPlan_OrganizationUnit_view partially replaces TaskPlan_Group & Task_Group tables
-- (on request of Rostislav Barina)
-- this view is built using indexes on key so it is very fast and does not need special table
CREATE VIEW `TaskPlan_OrganizationUnit_view` AS 
SELECT DISTINCT `TaskPlan`.`TaskPlan_ID`,`Person`.`OrganizationUnit_ID` 
FROM `Person_Task`,`TaskPlan`,`Person` 
WHERE `Person_Task`.`EID`=`Person`.`EID` 
AND `TaskPlan`.`Task_ID`=`Person_Task`.`Task_ID` 
AND `TaskPlan`.`Year`=`Person_Task`.`Year`;

-- Divide column `Comment` into columns for comment of charter owner and for comment of line manager.
ALTER TABLE `ProjectCharterFileHistory` CHANGE `Comment` `OwnerComment` TEXT;
ALTER TABLE `ProjectCharterFileHistory` ADD COLUMN `LineManagerComment` TEXT AFTER `OwnerComment`;
-- Flag for determining moment, when to create new version.
ALTER TABLE `ProjectCharterFileHistory` ADD COLUMN `Committed` TINYINT(1) NOT NULL DEFAULT 0;
-- Set flag to all committed files
UPDATE `ProjectCharterFileHistory` JOIN `ProjectCharter`
ON `ProjectCharterFileHistory`.`ProjectCharter_ID` = `ProjectCharter`.`ProjectCharter_ID`
SET `ProjectCharterFileHistory`.`Committed` = 1
WHERE `ProjectCharter`.`Status` = 'WaitingForLMApproval';

-- Add new column `Comment` into table `Person`
ALTER TABLE `Person` ADD COLUMN `Comment` TEXT DEFAULT NULL;

-- Application clean-up
-- Department + Group + Skill relations
ALTER TABLE `Person` DROP FOREIGN KEY `Person_ibfk_1`;
ALTER TABLE `Person` DROP COLUMN `Group_ID`;
ALTER TABLE `Person` DROP COLUMN `Group_Leader`;
ALTER TABLE `Person` DROP COLUMN `Department_Manager`;
DROP TABLE `Person_Skill`;
DROP TABLE `Task_Group`;
DROP TABLE `TaskPlan_Group`;
DROP TABLE `Skill`;
DROP TABLE `Group`;
DROP TABLE `Department`;

-- Increased length of possible file name uploaded - UTF8 consumes more "varchar - characters" for one UTF8 character
ALTER TABLE `ProjectCharterFileHistory` CHANGE `FileName` `FileName` VARCHAR( 1000 ) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL; 

-- autoapproval setup
INSERT INTO `GlobalSetting` (`Key` ,`Value` ,`Default` ,`DataType`) VALUES 
('charters.autoApprovalMaxExecTimeSeconds', NULL, '300', 'int'),
('charters.credentials.schedulerToken', 'dfcdd84c9d909800b63ff1c2983e7c54', '', 'string');
-- rename key for admin mailing list 
UPDATE `GlobalSetting` SET `Key`='mail.adminList' 
WHERE `Key`='eCharge.notifyList'; 

-- Global settings - authentication token values for EAC and TT reports inserted.
INSERT INTO `tool`.`GlobalSetting` (`Key` ,`Value` ,`Default` ,`DataType`) VALUES
 ('EACReport.credentials.cronToken', '392f10b7d32784095f78913438b54c72' , '', 'string'), 
 ('TTReport.credentials.cronToken', '4e02c596b776a9002ba2c8d79bc17d7d' , '', 'string');
