-- ATE Tool database upgrade script 
-- From version     : 1.6.x
-- To version       : 1.7.0
-- Target DB engine : MySQL 5.5.x

-- Adds index to the ActualsCost table on Activity_SAP_ID variable.
ALTER TABLE `ActualsCost` ADD INDEX (Activity_SAP_ID);

-- Adds new columns into the table Customer
ALTER TABLE `Customer` ADD COLUMN `Responsible` VARCHAR(7);
ALTER TABLE `Customer` ADD COLUMN `Remarks` TEXT;
ALTER TABLE `Customer` ADD CONSTRAINT `Customer_Person_fk` FOREIGN KEY (`Responsible`) REFERENCES `Person` (`EID`) ON DELETE NO ACTION ON UPDATE NO ACTION;


-- Definition of table `CustomerProgram`
DROP TABLE IF EXISTS `CustomerProgram`;
CREATE TABLE `CustomerProgram` (
  `Program_ID` INT(11) NOT NULL AUTO_INCREMENT,
  `Customer_ID` INT(11) NOT NULL,
  `Program` VARCHAR(50) COLLATE utf8_unicode_ci NOT NULL,
  `Remarks` TEXT COLLATE utf8_unicode_ci,
  PRIMARY KEY (`Program_ID`),
  KEY `CustomerProgram_Customer_fk` (`Customer_ID`),
  CONSTRAINT `CustomerProgram_Customer_fk` FOREIGN KEY (`Customer_ID`) REFERENCES `Customer` (`Customer_ID`) ON DELETE NO ACTION ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

-- Definition of table `CustomerProgramCall`
DROP TABLE IF EXISTS `CustomerProgramCall`;
CREATE TABLE `CustomerProgramCall` (
  `Call_ID` INT(11) NOT NULL AUTO_INCREMENT,
  `Program_ID` INT(11) NOT NULL,
  `Call` VARCHAR(50) COLLATE utf8_unicode_ci NOT NULL,
  `Remarks` TEXT COLLATE utf8_unicode_ci,
  `OpeningDate` DATE,
  `ClosingDate` DATE,
  `CostShare` NUMERIC(3,2),
  `Responsible` VARCHAR(7) COLLATE utf8_unicode_ci,
  PRIMARY KEY (`Call_ID`),
  KEY `CustomerProgramCall_CustomerProgram_fk` (`Program_ID`),
  KEY `CustomerProgramCall_Person_fk` (`Responsible`),
  CONSTRAINT `CustomerProgramCall_CustomerProgram_fk` FOREIGN KEY (`Program_ID`) REFERENCES `CustomerProgram` (`Program_ID`) ON DELETE NO ACTION ON UPDATE NO ACTION,
  CONSTRAINT `CustomerProgramCall_Person_fk` FOREIGN KEY (`Responsible`) REFERENCES `Person` (`EID`) ON DELETE NO ACTION ON UPDATE NO ACTION
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

-- Definition of table `Pursuit`
DROP TABLE IF EXISTS `Pursuit`;
CREATE TABLE `Pursuit` (
  `Pursuit_ID` INT(11) NOT NULL AUTO_INCREMENT,
  `Customer_ID` INT(11) NOT NULL,
  `Program_ID` INT(11),
  `Call_ID` INT(11),
  `CostShare` NUMERIC(3,2),
  `Name` VARCHAR(200) COLLATE utf8_unicode_ci NOT NULL,
  `Status` INT(11),
  `CreatedDate` DATETIME,
  `LastUpdatedDate` DATETIME,
  `PreScreenDate` DATETIME,
  `PnPDate` DATETIME,
  `BnBDate` DATETIME,
  `PricingDate` DATETIME,
  `DeadlineDate` DATE,
  `MarketingStudyDate` DATETIME,
  `GreenTeamReviewDate` DATETIME,
  `RedTeamReviewDate` DATETIME,
  `SFDCNumber` VARCHAR(10) COLLATE utf8_unicode_ci,
  `PursuitManager` VARCHAR(7) COLLATE utf8_unicode_ci,
  `PursuitPI` VARCHAR(7) COLLATE utf8_unicode_ci,
  `Remarks` TEXT COLLATE utf8_unicode_ci,
  `ClosureResult` INT(11),
  `ProbabilityOfWin` NUMERIC(3,2),
  PRIMARY KEY (`Pursuit_ID`),
  KEY `Pursuit_Customer_fk` (`Customer_ID`),
  KEY `Pursuit_CustomerProgram_fk` (`Program_ID`),
  KEY `Pursuit_CustomerProgramCall_fk` (`Call_ID`),
  KEY `Pursuit_Person_fk` (`PursuitManager`),
  KEY `Pursuit_Person_fk1` (`PursuitPI`),
  CONSTRAINT `Pursuit_Customer_fk` FOREIGN KEY (`Customer_ID`) REFERENCES `Customer` (`Customer_ID`) ON DELETE NO ACTION ON UPDATE NO ACTION,
  CONSTRAINT `Pursuit_CustomerProgram_fk` FOREIGN KEY (`Program_ID`) REFERENCES `CustomerProgram` (`Program_ID`) ON DELETE NO ACTION ON UPDATE NO ACTION,
  CONSTRAINT `Pursuit_CustomerProgramCall_fk` FOREIGN KEY (`Call_ID`) REFERENCES `CustomerProgramCall` (`Call_ID`) ON DELETE NO ACTION ON UPDATE NO ACTION,
  CONSTRAINT `Pursuit_Person_fk` FOREIGN KEY (`PursuitManager`) REFERENCES `Person` (`EID`) ON DELETE NO ACTION ON UPDATE NO ACTION,
  CONSTRAINT `Pursuit_Person_fk1` FOREIGN KEY (`PursuitPI`) REFERENCES `Person` (`EID`) ON DELETE NO ACTION ON UPDATE NO ACTION
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

-- Add new columns into the table Project
ALTER TABLE `Project` ADD COLUMN `Program_ID` INT(11);
ALTER TABLE `Project` ADD COLUMN `Call_ID` INT(11);
ALTER TABLE `Project` ADD COLUMN `ResponsibleUnit` INT(11);
ALTER TABLE `Project` ADD CONSTRAINT `Project_CustomerProgram_fk` FOREIGN KEY (`Program_ID`) REFERENCES `CustomerProgram` (`Program_ID`) ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER TABLE `Project` ADD CONSTRAINT `Project_CustomerProgramCall_fk` FOREIGN KEY (`Call_ID`) REFERENCES `CustomerProgramCall` (`Call_ID`) ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER TABLE `Project` ADD CONSTRAINT `Project_OrganizationUnit_fk` FOREIGN KEY (`ResponsibleUnit`) REFERENCES `OrganizationUnit` (`OrganizationUnit_ID`) ON DELETE NO ACTION ON UPDATE NO ACTION;

-- Add new columns into the table ProjectCharter
ALTER TABLE `ProjectCharter` ADD COLUMN `Program_ID` INT(11) AFTER `Customer_ID`;
ALTER TABLE `ProjectCharter` ADD COLUMN `Call_ID` INT(11) AFTER `Program_ID`;
ALTER TABLE `ProjectCharter` ADD CONSTRAINT `ProjectCharter_CustomerProgram_fk` FOREIGN KEY (`Program_ID`) REFERENCES `CustomerProgram` (`Program_ID`) ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER TABLE `ProjectCharter` ADD CONSTRAINT `ProjectCharter_CustomerProgramCall_fk` FOREIGN KEY (`Call_ID`) REFERENCES `CustomerProgramCall` (`Call_ID`) ON DELETE NO ACTION ON UPDATE NO ACTION;

-- -----------------------------------------------------
-- Table `tool`.`StrapItem`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `tool`.`StrapItem` ;

CREATE  TABLE IF NOT EXISTS `tool`.`StrapItem` (
  `StrapItem_ID` INT NOT NULL AUTO_INCREMENT ,
  `Custom_ID` VARCHAR(20) COLLATE utf8_unicode_ci NOT NULL ,
  `Name` VARCHAR(150) COLLATE utf8_unicode_ci NOT NULL ,
  `ResponsibleOrgUnit_ID` INT NOT NULL ,
  `TargetTRL` INT NOT NULL DEFAULT 0 ,
  `TargetTRLYear` INT NOT NULL DEFAULT 0 ,
  `Description` TEXT COLLATE utf8_unicode_ci NULL ,
  `Active` INT NOT NULL DEFAULT '1',
  PRIMARY KEY (`StrapItem_ID`) ,
  UNIQUE INDEX `Custom_ID_UNIQUE` (`Custom_ID` ASC) ,
  CONSTRAINT `OrganizationUnit_ID`
    FOREIGN KEY (`ResponsibleOrgUnit_ID` )
    REFERENCES `tool`.`OrganizationUnit` (`OrganizationUnit_ID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `tool`.`NeedToPursue`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `tool`.`NeedToPursue` ;

CREATE  TABLE IF NOT EXISTS `tool`.`NeedToPursue` (
  `NeedToPursue_ID` INT NOT NULL AUTO_INCREMENT ,
  `Name` VARCHAR(150) COLLATE utf8_unicode_ci NOT NULL ,
  `PotentialCustomer` VARCHAR(255) COLLATE utf8_unicode_ci NULL ,
  PRIMARY KEY (`NeedToPursue_ID`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `tool`.`ProductLine`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `tool`.`ProductLine` ;

CREATE  TABLE IF NOT EXISTS `tool`.`ProductLine` (
  `ProductName` VARCHAR(100) COLLATE utf8_unicode_ci NOT NULL ,
  PRIMARY KEY (`ProductName`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `tool`.`TechnologyRoadmapDomain`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `tool`.`TechnologyRoadmapDomain` ;

CREATE  TABLE IF NOT EXISTS `tool`.`TechnologyRoadmapDomain` (
  `Domain` VARCHAR(100) COLLATE utf8_unicode_ci NOT NULL ,
  PRIMARY KEY (`Domain`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `tool`.`Advisor`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `tool`.`Advisor` ;

CREATE  TABLE IF NOT EXISTS `tool`.`Advisor` (
  `EID` VARCHAR(7) COLLATE utf8_unicode_ci NOT NULL ,
  `Name` VARCHAR(100) COLLATE utf8_unicode_ci NULL ,
  `Surname` VARCHAR(100) COLLATE utf8_unicode_ci NULL ,
  `Domain` VARCHAR(100) COLLATE utf8_unicode_ci NULL ,
  `Role` VARCHAR(100) COLLATE utf8_unicode_ci NOT NULL ,
  UNIQUE INDEX `Advisor_UNIQUE` (`EID` ASC, `Role` ASC)  )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `tool`.`StrapItemActivity`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `tool`.`StrapItemActivity` ;

CREATE  TABLE IF NOT EXISTS `tool`.`StrapItemActivity` (
  `Activity_ID` INT NOT NULL AUTO_INCREMENT ,
  `StrapItem_ID` INT NOT NULL ,
  `Custom_ID` VARCHAR(20) COLLATE utf8_unicode_ci NOT NULL ,
  `Pursuit_ID` INT NULL ,
  `Project_ID` INT NULL ,
  `NeedToPursue_ID` INT NULL ,
  `TargetTRL` INT NULL DEFAULT 0 ,
  `TargetTRLYear` INT NULL DEFAULT 0 ,
  `Name` VARCHAR(150) COLLATE utf8_unicode_ci NULL ,
  `Remarks` TEXT NULL ,
  `TechnologyRoadmapDomain` VARCHAR(100) COLLATE utf8_unicode_ci NULL ,
  `MarketingProductManager` VARCHAR(7) COLLATE utf8_unicode_ci NULL ,
  `PortfolioManager` VARCHAR(7) COLLATE utf8_unicode_ci NULL ,
  `ProductLine` VARCHAR(100) COLLATE utf8_unicode_ci NULL ,
  `RTCDirector` VARCHAR(7) COLLATE utf8_unicode_ci NULL ,
  `Created` DATETIME NOT NULL ,
  `Creator` VARCHAR(7) COLLATE utf8_unicode_ci NOT NULL ,
  `CostShare` DECIMAL(3,2) NULL ,
  `ProjectBudgetUsage` DECIMAL(3,2) NOT NULL DEFAULT 0 ,
  `PotentialCustomer` VARCHAR(255) COLLATE utf8_unicode_ci NULL ,
  `Active` INT NOT NULL DEFAULT '1',
  PRIMARY KEY (`Activity_ID`) ,
  CONSTRAINT `ProductLine`
    FOREIGN KEY (`ProductLine` )
    REFERENCES `tool`.`ProductLine` (`ProductName` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `Project_ID`
    FOREIGN KEY (`Project_ID` )
    REFERENCES `tool`.`Project` (`Project_ID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `StrapItem_ID`
    FOREIGN KEY (`StrapItem_ID` )
    REFERENCES `tool`.`StrapItem` (`StrapItem_ID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `TechnologyRoadmapDomain`
    FOREIGN KEY (`TechnologyRoadmapDomain` )
    REFERENCES `tool`.`TechnologyRoadmapDomain` (`Domain` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `MarketingProductManager`
    FOREIGN KEY (`MarketingProductManager` )
    REFERENCES `tool`.`Advisor` (`EID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `PortfolioManager`
    FOREIGN KEY (`PortfolioManager` )
    REFERENCES `tool`.`Advisor` (`EID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `RTCDirector`
    FOREIGN KEY (`RTCDirector` )
    REFERENCES `tool`.`Advisor` (`EID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `tool`.`StrapItemActivityYearlyBudget`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `tool`.`StrapItemActivityYearlyBudget` ;

CREATE  TABLE IF NOT EXISTS `tool`.`StrapItemActivityYearlyBudget` (
  `Activity_ID` INT NOT NULL ,
  `Year` INT NOT NULL ,
  `LabourCosts` DECIMAL(10,0) NOT NULL DEFAULT 0 ,
  `SubcontractingCosts` DECIMAL(10,0) NOT NULL DEFAULT 0 ,
  `TravelCosts` DECIMAL(10,0) NOT NULL DEFAULT 0 ,
  `MaterialCosts` DECIMAL(10,0) NOT NULL DEFAULT 0 ,
  PRIMARY KEY (`Activity_ID`, `Year`) ,
  CONSTRAINT `StrapItemActivity_ID`
    FOREIGN KEY (`Activity_ID` )
    REFERENCES `tool`.`StrapItemActivity` (`Activity_ID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;

-- -----------------------------------------------------
-- Table `tool`.`StrapItemActivity_Pursuit`
-- -----------------------------------------------------

DROP TABLE IF EXISTS `tool`.`StrapItemActivity_Pursuit` ;
CREATE  TABLE IF NOT EXISTS `tool`.`StrapItemActivity_Pursuit` (
  `Activity_ID` INT NOT NULL ,
  `Pursuit_ID` INT NOT NULL ,
  INDEX `Activity_ID_idx` (`Activity_ID` ASC) ,
  INDEX `Pursuit_ID_idx` (`Pursuit_ID` ASC) ,
  UNIQUE INDEX `Activity_Pursuit_UNIQUE` (`Activity_ID` ASC, `Pursuit_ID` ASC) ,
  CONSTRAINT `fk_StrapItemActivity_ID`
    FOREIGN KEY (`Activity_ID` )
    REFERENCES `tool`.`StrapItemActivity` (`Activity_ID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Pursuit_ID`
    FOREIGN KEY (`Pursuit_ID` )
    REFERENCES `tool`.`Pursuit` (`Pursuit_ID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;

-- Change comment column data type in table ProjectCharterBudgetHistory
ALTER TABLE `ProjectCharterBudgetHistory` CHANGE `Comment` `Comment` TEXT COLLATE utf8_unicode_ci;

-- Change number of days for rounds of charter approval process. +1 day will eliminate problem with time zones
UPDATE `GlobalSetting` SET `Default` = 15 WHERE `Key` = 'charters.finalApprovalFirstRoundDays';
UPDATE `GlobalSetting` SET `Default` = 8 WHERE `Key` = 'charters.finalApprovalNextRoundDays';
