-- ATE Tool database upgrade script 
-- From version     : 1.7.0
-- To version       : 1.7.2
-- Target DB engine : MySQL 5.5.x

-- -----------------------------------------------------
-- Table `tool`.`PursuitPlan`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `tool`.`PursuitPlan` ;

CREATE  TABLE IF NOT EXISTS `tool`.`PursuitPlan` (
  `Pursuit_ID` INT NOT NULL ,
  `Milestone` ENUM('Prescreen', 'PnP', 'BnB', 'Pricing', 'Marketing Study', 'GREEN Team Review', 'RED Team Review', 'Proposal Submission') ,
  `PlannedDate` DATETIME NULL ,
  `ActualDate` DATETIME NULL ,
  `Link` VARCHAR(200) CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NULL ,
  `BnP_Plan` INT NULL ,
  `BnP_Actuals` INT NULL ,
  `Remarks` TEXT CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NULL ,
  PRIMARY KEY (`Pursuit_ID`, `Milestone`),
  CONSTRAINT `PursuitPlan_Pursuit_fk`
    FOREIGN KEY (`Pursuit_ID` )
    REFERENCES `tool`.`Pursuit` (`Pursuit_ID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  UNIQUE INDEX `PursuitPlan_UNIQUE` (`Pursuit_ID` ASC, `Milestone` ASC)
) ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `tool`.`RedTeam`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `tool`.`RedTeam` ;

CREATE  TABLE IF NOT EXISTS `tool`.`RedTeam` (
  `EID` VARCHAR(7) CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NOT NULL ,
  `Pursuit_ID` INT NOT NULL ,
  PRIMARY KEY (`EID`, `Pursuit_ID`),
  CONSTRAINT `REDTeam_Person`
    FOREIGN KEY (`EID` )
    REFERENCES `tool`.`Person` (`EID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `REDTeam_Pursuit`
    FOREIGN KEY (`Pursuit_ID` )
    REFERENCES `tool`.`Pursuit` (`Pursuit_ID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  UNIQUE INDEX `REDTeam_UNIQUE` (`EID` ASC, `Pursuit_ID` ASC)
) ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `tool`.`PursuitAction`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `tool`.`PursuitAction` ;

CREATE  TABLE IF NOT EXISTS `tool`.`PursuitAction` (
  `Action_ID` INT NOT NULL AUTO_INCREMENT ,
  `Pursuit_ID` INT NOT NULL ,
  `Action` VARCHAR(200) CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NOT NULL ,
  `Owner` VARCHAR(7) CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NULL ,
  `Deadline` DATETIME NULL ,
  `Status` VARCHAR(40) CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NULL ,
  `Remarks` TEXT CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NULL ,
  PRIMARY KEY (`Action_ID`) ,
  CONSTRAINT `PursuitAction_Pursuit_fk`
    FOREIGN KEY (`Pursuit_ID` )
    REFERENCES `tool`.`Pursuit` (`Pursuit_ID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `PursuitAction_Person_fk`
    FOREIGN KEY (`Owner` )
    REFERENCES `tool`.`Person` (`EID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `tool`.`PursuitRisk`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `tool`.`PursuitRisk` ;

CREATE  TABLE IF NOT EXISTS `tool`.`PursuitRisk` (
  `Risk_ID` INT NOT NULL AUTO_INCREMENT ,
  `Pursuit_ID` INT NOT NULL ,
  `Risk` VARCHAR(200) CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NOT NULL ,
  `Owner` VARCHAR(7) CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NULL ,
  `Deadline` DATETIME NULL ,
  `Status` VARCHAR(40) CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NULL ,
  `Remarks` TEXT CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NULL ,
  INDEX `PursuitRisk_Pursuit_fk_idx` (`Pursuit_ID` ASC) ,
  PRIMARY KEY (`Risk_ID`) ,
  CONSTRAINT `PursuitRisk_Pursuit_fk`
    FOREIGN KEY (`Pursuit_ID` )
    REFERENCES `tool`.`Pursuit` (`Pursuit_ID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `PursuitRisk_Person_fk`
    FOREIGN KEY (`Owner` )
    REFERENCES `tool`.`Person` (`EID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- --------------------------------------------------------
-- Move data from `tool`.`Pursuit` to `tool`.`PursuitPlan`
-- --------------------------------------------------------
DROP TABLE IF EXISTS `tool`.`temp_PursuitDates`;

CREATE  TABLE IF NOT EXISTS `tool`.`temp_PursuitDates` (
  `Pursuit_ID` INT,
  `PreScreenDate` DATETIME,
  `PnPDate` DATETIME,
  `BnBDate` DATETIME,
  `PricingDate` DATETIME,
  `DeadlineDate` DATETIME,
  `MarketingStudyDate` DATETIME,
  `GreenTeamReviewDate` DATETIME,
  `RedTeamReviewDate` DATETIME
) ENGINE = InnoDB;

INSERT INTO `temp_PursuitDates`
    SELECT `Pursuit_ID`, `PreScreenDate`, `PnPDate`, `BnBDate`, `PricingDate`,
           `DeadlineDate`, `MarketingStudyDate`, `GreenTeamReviewDate`, `RedTeamReviewDate`
    FROM `Pursuit`;

INSERT INTO `PursuitPlan` (`Pursuit_ID`, `Milestone`, `PlannedDate`)
    SELECT `Pursuit_ID`, 'Prescreen', `PreScreenDate`
    FROM `temp_PursuitDates`;

INSERT INTO `PursuitPlan` (`Pursuit_ID`, `Milestone`, `PlannedDate`)
    SELECT `Pursuit_ID`, 'PnP', `PnPDate`
    FROM `temp_PursuitDates`;

INSERT INTO `PursuitPlan` (`Pursuit_ID`, `Milestone`, `PlannedDate`)
    SELECT `Pursuit_ID`, 'BnB', `BnBDate`
    FROM `temp_PursuitDates`;

INSERT INTO `PursuitPlan` (`Pursuit_ID`, `Milestone`, `PlannedDate`)
    SELECT `Pursuit_ID`, 'Pricing', `PricingDate`
    FROM `temp_PursuitDates`;

INSERT INTO `PursuitPlan` (`Pursuit_ID`, `Milestone`, `PlannedDate`)
    SELECT `Pursuit_ID`, 'Proposal Submission', `DeadlineDate`
    FROM `temp_PursuitDates`;

INSERT INTO `PursuitPlan` (`Pursuit_ID`, `Milestone`, `PlannedDate`)
    SELECT `Pursuit_ID`, 'Marketing Study', `MarketingStudyDate`
    FROM `temp_PursuitDates`;

INSERT INTO `PursuitPlan` (`Pursuit_ID`, `Milestone`, `PlannedDate`)
    SELECT `Pursuit_ID`, 'GREEN Team Review', `GreenTeamReviewDate`
    FROM `temp_PursuitDates`;

INSERT INTO `PursuitPlan` (`Pursuit_ID`, `Milestone`, `PlannedDate`)
    SELECT `Pursuit_ID`, 'RED Team Review', `RedTeamReviewDate`
    FROM `temp_PursuitDates`;

DROP TABLE IF EXISTS `tool`.`temp_PursuitDates`;


-- -----------------------------------------------------
-- Table `tool`.`Pursuit`
-- -----------------------------------------------------

-- drop moved columns
ALTER TABLE `Pursuit` DROP COLUMN `PreScreenDate`;
ALTER TABLE `Pursuit` DROP COLUMN `PnPDate`;
ALTER TABLE `Pursuit` DROP COLUMN `BnBDate`;
ALTER TABLE `Pursuit` DROP COLUMN `PricingDate`;
ALTER TABLE `Pursuit` DROP COLUMN `DeadlineDate`;
ALTER TABLE `Pursuit` DROP COLUMN `MarketingStudyDate`;
ALTER TABLE `Pursuit` DROP COLUMN `GreenTeamReviewDate`;
ALTER TABLE `Pursuit` DROP COLUMN `RedTeamReviewDate`;

-- add new columns
ALTER TABLE `Pursuit` ADD COLUMN `UpdatedBy` VARCHAR(7) CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' AFTER `LastUpdatedDate`;
ALTER TABLE `Pursuit` ADD CONSTRAINT `Pusuit_Person_fk2` FOREIGN KEY (`UpdatedBy`) REFERENCES `Person` (`EID`) ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER TABLE `Pursuit` ADD COLUMN `DocumentStorage` VARCHAR(200);

-- -----------------------------------------------------
-- Table `tool`.`StrapItemActivity`
-- -----------------------------------------------------

ALTER TABLE `StrapItemActivity` ADD COLUMN `UpdatedBy` VARCHAR(7) CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' AFTER `Active`;
ALTER TABLE `StrapItemActivity` ADD CONSTRAINT `StrapItemActivity_Person_fk1_idx` FOREIGN KEY (`UpdatedBy`) REFERENCES `Person` (`EID`) ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER TABLE `StrapItemActivity` ADD COLUMN `LastUpdatedDate` DATETIME NULL AFTER `UpdatedBy`;


-- -----------------------------------------------------
-- Drop old table `tool`.`Advisor` 
-- -----------------------------------------------------

ALTER TABLE `StrapItemActivity` DROP FOREIGN KEY MarketingProductManager;
ALTER TABLE `StrapItemActivity` DROP FOREIGN KEY PortfolioManager;
ALTER TABLE `StrapItemActivity` DROP FOREIGN KEY RTCDirector;

DROP TABLE IF EXISTS `tool`.`Advisor`;

-- -----------------------------------------------------
-- Create new table `tool`.`Advisor` 
-- -----------------------------------------------------

CREATE  TABLE IF NOT EXISTS `tool`.`Advisor` (
  `Advisor_ID` INT NOT NULL AUTO_INCREMENT ,
  `Parent_ID` INT NULL ,
  `Name` VARCHAR(100) CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NULL ,
  `Type` VARCHAR(100) CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NOT NULL ,
  PRIMARY KEY (`Advisor_ID`),
  KEY `Advisor_fk1` (`Parent_ID`),
  CONSTRAINT `Advisor_fk1` FOREIGN KEY (`Parent_ID`) REFERENCES `Advisor` (`Advisor_ID`) ON DELETE NO ACTION ON UPDATE NO ACTION
) ENGINE = InnoDB;

-- -----------------------------------------------------
-- Deleteing old advisors from table `tool`.`StrapItemActivity` 
-- -----------------------------------------------------

UPDATE `StrapItemActivity` SET `MarketingProductManager` = NULL;
UPDATE `StrapItemActivity` SET `PortfolioManager` = NULL;
UPDATE `StrapItemActivity` SET `RTCDirector` = NULL;

ALTER TABLE `StrapItemActivity` MODIFY COLUMN `MarketingProductManager` INT NULL;
ALTER TABLE `StrapItemActivity` MODIFY COLUMN `PortfolioManager` INT NULL;
ALTER TABLE `StrapItemActivity` MODIFY COLUMN `RTCDirector` INT NULL;

ALTER TABLE `StrapItemActivity` ADD CONSTRAINT `MarketingProductManager` FOREIGN KEY (`MarketingProductManager`) REFERENCES `Advisor` (`Advisor_ID`) ON DELETE NO ACTION ON UPDATE NO ACTION; 
ALTER TABLE `StrapItemActivity` ADD CONSTRAINT `PortfolioManager` FOREIGN KEY (`PortfolioManager`) REFERENCES `Advisor` (`Advisor_ID`) ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER TABLE `StrapItemActivity` ADD CONSTRAINT `RTCDirector` FOREIGN KEY (`RTCDirector`) REFERENCES `Advisor` (`Advisor_ID`) ON DELETE NO ACTION ON UPDATE NO ACTION; 

-- -----------------------------------------------------
-- Insert data to table `tool`.`Advisor` 
-- -----------------------------------------------------

INSERT INTO `tool`.`Advisor` (`Advisor_ID` ,`Parent_ID`, `Name`, `Type`)
VALUES 
(1, null, 'Advanced Sensors & Microsystems', 'RTC'),
(2, null, 'Components & Power Controls', 'RTC'),
(3, null, 'Communication, Navigation & Surveillance Systems', 'RTC'),
(4, null, 'Advanced Systems & Prototyping', 'RTC'),
(5, null, 'Engines & Air Management', 'RTC'),
(6, null, 'Crew, Interface & Platform Systems', 'RTC'),
(7, null, 'Aerospace Services', 'MaPMPort'),
(8, null, 'Mechanical Sub Systems', 'MaPMPort'),
(9, null, 'Safety & Info Management', 'MaPMPort'),
(10, null, 'Propulsion Systems', 'MaPMPort'),
(11, null, 'Wheels & Brakes', 'MaPMPort'),
(12, null, 'Navigation Sub Systems & Sensors', 'MaPMPort'),
(13, null, 'Lighting', 'MaPMPort'),
(14, null, 'Mechanical Components', 'MaPMPort'),
(15, null, 'Cockpit Systems', 'MaPMPort');

INSERT INTO `tool`.`Advisor` (`Parent_ID`, `Name`, `Type`)
VALUES 
(7, 'Ground Support Services', 'MaPMSub'),
(7, 'Flight Support Services', 'MaPMSub'),
(7, 'Cabin and Zing', 'MaPMSub'),
(7, 'Conditioned Based Maintenance', 'MaPMSub'),
(7, 'Data Subscriptions & Services', 'MaPMSub'),
(7, 'HUMS', 'MaPMSub'),
(8, 'Small APU', 'MaPMSub'),
(8, 'Large APU', 'MaPMSub'),
(8, 'Gas Processing', 'MaPMSub'),
(8, 'Air Management Systems', 'MaPMSub'),
(8, 'Electric Green Taxi Systems', 'MaPMSub'),
(8, 'Cabin Pressure Systems', 'MaPMSub'),
(8, 'Thermal Mgmt. Systems', 'MaPMSub'),
(8, 'Electric Power Products', 'MaPMSub'),
(8, 'Turbo Systems', 'MaPMSub'),
(8, 'Engines & Air Management', 'MaPMSub'),
(8, 'Components Power & Controls', 'MaPMSub'),
(9, 'SATCOM', 'MaPMSub'),
(9, 'SATCOM/GX Aviation', 'MaPMSub'),
(9, 'Data Management', 'MaPMSub'),
(9, 'Connected Aircraft', 'MaPMSub'),
(9, 'Traffic / Surveillance', 'MaPMSub'),
(9, 'RAD/ALT', 'MaPMSub'),
(9, 'Radar', 'MaPMSub'),
(9, 'OBS/SKUs', 'MaPMSub'),
(10, 'TFE / LF', 'MaPMSub'),
(10, 'HPW3000 / T55', 'MaPMSub'),
(10, 'HTF7000', 'MaPMSub'),
(10, 'LTS / HTS', 'MaPMSub'),
(10, 'TPE', 'MaPMSub'),
(10, 'F124-5 / AGT / CTS', 'MaPMSub'),
(10, 'New Commercial Engine Programs', 'MaPMSub'),
(11, 'Wheels & Brakes', 'MaPMSub'),
(12, 'Inertial Sensors', 'MaPMSub'),
(12, 'Space Navigation & Microelectronics', 'MaPMSub'),
(12, 'Tactical Navigation', 'MaPMSub'),
(12, 'Commercial Navigation', 'MaPMSub'),
(12, 'Defense Navigation Aircraft', 'MaPMSub'),
(12, 'Satellite Systems', 'MaPMSub'),
(12, 'Magnetic Sensors & Adjacencies', 'MaPMSub'),
(12, 'GBAS & GNSS', 'MaPMSub'),
(12, 'Thermal Switch & Adjacencies', 'MaPMSub'),
(12, 'Air Data & EW', 'MaPMSub'),
(12, 'Surface & Marine Navigation', 'MaPMSub'),
(12, 'Manned Space', 'MaPMSub'),
(13, 'Lighting', 'MaPMSub'),
(14, 'Components Fuel Controls', 'MaPMSub'),
(14, 'Pneumatic Components', 'MaPMSub'),
(14, 'Component Growth Portfolio', 'MaPMSub'),
(14, 'Actuation Components', 'MaPMSub'),
(15, 'Cross Product Integration', 'MaPMSub'),
(15, 'SW Products', 'MaPMSub'),
(15, 'Primus Epic', 'MaPMSub'),
(15, 'AIMS, VIA, AFCS', 'MaPMSub'),
(15, 'NGFMS', 'MaPMSub'),
(15, 'Platform Hardware Management', 'MaPMSub'),
(15, 'NTE', 'MaPMSub'),
(15, 'Displays Software', 'MaPMSub'),
(15, 'Primus Apex & China Avionics', 'MaPMSub'),
(15, 'P1K/P2K & Helos', 'MaPMSub'),
(15, 'Legacy FMS', 'MaPMSub'),
(15, 'Core Display Technologies', 'MaPMSub'),
(15, 'Lifecycle Strategies Interior Electronic', 'MaPMSub'),
(15, 'Future Flight Deck', 'MaPMSub'),
(15, 'SVS / EGPWS', 'MaPMSub'),
(15, 'D&S Platforms', 'MaPMSub'),
(15, 'Engine Controllers', 'MaPMSub'),
(15, 'Primus Epic/Apex HardwareEngine Controllers', 'MaPMSub'),
(15, 'China Avionics', 'MaPMSub'),
(15, 'INAV', 'MaPMSub');