<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2014 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package presenters
 */

/**
 * Presenter for administration of distribution lists.
 *
 * @author Vojtech Obrusnik <vojtech.obrusnik@honeywell.com>
 */
class DistributionListPresenter extends SecuredPresenter
{		
	/**
	 * Shows default page
	 */
	public function renderDefault()
	{
		if ($this->context->formStateRepository->exists('dlOrganizationUnitForm'))
			$this->context->formStateRepository->load('dlOrganizationUnitForm', $this['organizationUnitForm']);
		
		if ($this->context->formStateRepository->exists('dlProjectForm'))
			$this->context->formStateRepository->load('dlProjectForm', $this['projectForm']);
        
		if ($this->context->formStateRepository->exists('dlRoleForm'))
			$this->context->formStateRepository->load('dlRoleForm', $this['roleForm']);
	}
	
	/**
     * Creates form for generation of distribution list based on organization unit
     * @param string $name Name of the form.
     * @return AppForm Returns AppForm.
     */
	public function createComponentOrganizationUnitForm($name)
	{
		$form = new AppForm($this, $name);
		
		$form['OrganizationUnitSelector'] = new OrganizationUnitSelectorContainer;
		    $form['OrganizationUnitSelector']['ajaxHandle']->setValue($this->link('OrganizationUnitSelector'));
		
		$form->addTextArea('List', HPTForm::createLabel('Distribution List', 'Click into the area of Distribution List and use CRTL+C to copy it\'s content.'), 40, 7)
				->setAttribute('readonly', 'readonly');
	
		$form->addSubmit('Send', 'Show')
				->onClick[] = array($this, 'organizationUnitFormSendSubmitted');
		
		$form->addSubmit('Clear', 'Clear')
				->onClick[] = array($this, 'organizationUnitFormClearSubmitted');
        
		$form->addSubmit('Export', 'Export')
				->onClick[] = array($this, 'organizationUnitFormExportSubmitted');
		
		return $form;
	}
    
    /**
     * Generates distribution list according to organization unit
     * @param SubmitButton $button
     * @param boolean $export
     */
    private function generateOrganizationUnitDistibutionList(SubmitButton $button, $export = FALSE)
    {
        $entry = $button->form->getValues();
		
		if ($entry->OrganizationUnitSelector->TechnicalGroup)
			$unit_id = $entry->OrganizationUnitSelector->TechnicalGroup;
		elseif ($entry->OrganizationUnitSelector->Cluster)
			$unit_id = $entry->OrganizationUnitSelector->Cluster;
		elseif ($entry->OrganizationUnitSelector->Department)
			$unit_id = $entry->OrganizationUnitSelector->Department;
		elseif ($entry->OrganizationUnitSelector->SBE)
			$unit_id = $entry->OrganizationUnitSelector->SBE;
		else
			$unit_id = NULL;
		
		if ($unit_id)
		{
			$unit = $this->context->organizationUnitRepository->find($unit_id);
			if ($unit)
			{
			    $units = $this->context->organizationUnitRepository->findAllChildrenByPath($unit->Path);
				$all_persons = array();
				foreach ($units as $id => $unit)
				    $all_persons = array_merge($all_persons, $this->context->personRepository->findByOrganizationUnitID($id));
				
				$eid_array = array();
				foreach ($all_persons as $person)
                {
                    if ($person->Status)
					    $eid_array[] = $person->ID;
                }
                
                if (count($eid_array) === 0)
                    $this->emptyDistributionList();
                
                if ($export)
                {
                    try
                    {
                        $report_name = 'orgunit-' . preg_replace('/\s+/', '', $unit->Name);
                        $dl_report = new DistributionListReportService($this->context, $report_name, $eid_array, NULL);
                        $dl_report->runDistributionListReportGeneration();
                    }
                    catch (Exception $e)
                    {
                        $this->flashMessage('Can not export distibution list. Unable to set up execution time. Please, try it again.', 'error');
                    }
                }
                else
                {
                    $list = $this->createEIDList($eid_array);
				    $button->form['List']->setValue($list);
                }
			}
            else
            {
                $this->emptyDistributionList();
            }
		}
        else
        {
            $this->emptyDistributionList();
        }

		$this->context->formStateRepository->save('dlOrganizationUnitForm', $button->form);
	    $this->redirect('DistributionList:default');
    }
	
	/**
	 * Service for Send button of OrganizationUnitForm
	 * @param SubmitButton $button
	 */
	public function organizationUnitFormSendSubmitted(SubmitButton $button)
	{
		$this->generateOrganizationUnitDistibutionList($button);
	}
	
    /**
	 * Service for Send button of OrganizationUnitForm
	 * @param SubmitButton $button
	 */
	public function organizationUnitFormExportSubmitted(SubmitButton $button)
	{
		$this->generateOrganizationUnitDistibutionList($button, TRUE);
	}
	
	/**
	 * Service for Clear button of OrganizationUnitForm
	 * @param SubmitButton $button
	 */
	public function organizationUnitFormClearSubmitted(SubmitButton $button)
	{
		$this->context->formStateRepository->drop('dlOrganizationUnitForm');
	    $this->redirect('DistributionList:default');
	}
    
	/**
     * Creates form for generation of distribution list based on role
     * @param string $name Name of the form.
     * @return AppForm Returns AppForm.
     */
	public function createComponentRoleForm($name)
	{
		$form = new AppForm($this, $name);
        
        $sbes = $default_sbes = array();
        $all_sbe = $this->context->organizationUnitRepository->findAllOrgUnitByType(OrganizationUnit::ORG_UNIT_TYPE_SBE);
        foreach ($all_sbe as $sbe)
        {
            $sbes[$sbe->ID] = $sbe->Short;
            $default_sbes[] = $sbe->ID;
        }
        $form->addCheckboxList('SBE', HPTForm::createLabel('SBE / Tier3', 'Search only people who are members of selected SBEs.'), $sbes);
            $form['SBE']->setDefaultValue($default_sbes);
		    $form['SBE']->getSeparatorPrototype()->setName(NULL);
        
        $roles = array(
            Person::ROLE_CLUSTER_LEADER => 'Cluster leader / Tier5 ('.Person::ROLE_CLUSTER_LEADER.' / T5)',
            Person::ROLE_DEPARTMENT_LEADER => 'Department leader / Tier4 ('.Person::ROLE_DEPARTMENT_LEADER.' / T4)',
            Person::ROLE_PIPM => 'Project investigator ('.Person::ROLE_PIPM.')',
            Person::ROLE_PMOE => 'Project manager ('.Person::ROLE_PMOE.')',
            Person::ROLE_PPaC => 'Project planner ('.Person::ROLE_PPaC.')',
            Person::ROLE_RESOURCE_OWNER => 'Resource owner ('.Person::ROLE_RESOURCE_OWNER.')',
        );
        
        $form->addCheckboxList('ProjectPhase', HPTForm::createLabel('Project Phase', 'Search only people who participate on projects in selected phases.'), Project::getPhases());
            $form['ProjectPhase']->setDefaultValue(array_keys(Project::getPhases()));
		    $form['ProjectPhase']->getSeparatorPrototype()->setName(NULL);
            
		$form->addSelect('Role', 'Role', $roles)
				->setPrompt('')
				->setAttribute('style', 'width: 220px;');
                $form['Role']->addCondition(Form::EQUAL, array(Person::ROLE_PIPM, Person::ROLE_PMOE, Person::ROLE_PPaC))
                    ->toggle('project-phase')
                    ->toggle('extra-row', FALSE);
                $form['Role']->addCondition(Form::EQUAL, array(Person::ROLE_PIPM, Person::ROLE_PMOE, Person::ROLE_PPaC, Person::ROLE_RESOURCE_OWNER, Person::ROLE_CLUSTER_LEADER, Person::ROLE_DEPARTMENT_LEADER))
                    ->toggle('sbes')
                    ->toggle('extra-row-2', FALSE);
		
		$form->addTextArea('List', HPTForm::createLabel('Distribution List', 'Click into the area of Distribution List and use CRTL+C to copy it\'s content.'), 40, 7)
				->setAttribute('readonly', 'readonly');
	
		$form->addSubmit('Send', 'Show')
				->onClick[] = array($this, 'roleFormSendSubmitted');
		
		$form->addSubmit('Clear', 'Clear')
				->onClick[] = array($this, 'roleFormClearSubmitted');
		
		$form->addSubmit('Export', 'Export')
				->onClick[] = array($this, 'roleFormExportSubmitted');
		
		return $form;
	}
    
    /**
     * Generates distribution list according to role
     * @param SubmitButton $button
     * @param boolean $export
     */
    private function generateRoleDistributionList(SubmitButton $button, $export = FALSE)
    {
        $entry = $button->form->getValues();
		
        if ($entry->Role)
        {
            switch ($entry->Role)
            {
                case Person::ROLE_PIPM:
                case Person::ROLE_PMOE:
                case Person::ROLE_PPaC:
                    $all_persons = $this->context->personRepository->findByProjectRole($entry->Role, $entry->SBE, $entry->ProjectPhase);
                    break;
                case Person::ROLE_CLUSTER_LEADER:
                    $all_persons = $this->context->personRepository->getLeadersByOrgUnitTypeAndSBE(array(OrganizationUnit::ORG_UNIT_TYPE_CLUS), $entry->SBE);
                    break;
                case Person::ROLE_DEPARTMENT_LEADER:
                    $all_persons = $this->context->personRepository->getLeadersByOrgUnitTypeAndSBE(array(OrganizationUnit::ORG_UNIT_TYPE_DEP), $entry->SBE);
                    break;
                case Person::ROLE_RESOURCE_OWNER:
                    $all_persons = $this->context->personRepository->findResourceOwners($entry->SBE);
                    break;
                default:
                    $all_persons = array();
                    break;
            }

            $eid_array = array();
            foreach ($all_persons as $eid => $person)
            {
                if ($person->Status)
                    $eid_array[] = $person->ID;
            }
            
            if (count($eid_array) === 0)
                $this->emptyDistributionList();
            
            if ($export)
            {
                try
                {
                    $report_name = 'role-' . $entry->Role;
                    $dl_report = new DistributionListReportService($this->context, $report_name, $eid_array, NULL);
                    $dl_report->runDistributionListReportGeneration();
                }
                catch (Exception $e)
                {
                    $this->flashMessage('Can not export distibution list. Unable to set up execution time. Please, try it again.', 'error');
                }
            }
            else
            {
                $list = $this->createEIDList($eid_array);
                $button->form['List']->setValue($list);
            }
        }
        else
        {
            $this->emptyDistributionList();
        }

		$this->context->formStateRepository->save('dlRoleForm', $button->form);
        $this->redirect('DistributionList:default');
    }
	
	/**
	 * Service for Send button of RoleForm
	 * @param SubmitButton $button
	 */
	public function roleFormSendSubmitted(SubmitButton $button)
	{
		$this->generateRoleDistributionList($button);
	}
    
	/**
	 * Service for Export button of RoleForm
	 * @param SubmitButton $button
	 */
	public function roleFormExportSubmitted(SubmitButton $button)
	{
		$this->generateRoleDistributionList($button, TRUE);
	}
	
	/**
	 * Service for Clear button of RoleForm
	 * @param SubmitButton $button
	 */
	public function roleFormClearSubmitted(SubmitButton $button)
	{
		$this->context->formStateRepository->drop('dlRoleForm');
	    $this->redirect('DistributionList:default');
	}
	
    /**
     * Creates form for generation of distribution list based on project
     * @param string $name Name of the form.
     * @return AppForm Returns AppForm.
     */
	public function createComponentProjectForm($name)
	{
		$form = new AppForm($this, $name);
		
		$all_projects = $this->context->projectRepository->findAllProjects();
		$projects = array();
		foreach ($all_projects as $project)
		    $projects[$project->ID] = $project->Name;
		
		$form->addSelect('Project', 'Project', $projects)
				->setPrompt('')
				->setAttribute('style', 'width: 300px;');
		
		$form->addTextArea('List', HPTForm::createLabel('Distribution List', 'Click into the area of Distribution List and use CRTL+C to copy it\'s content.'), 40, 7)
				->setAttribute('readonly', 'readonly');
	
		$form->addSubmit('Send', 'Show')
				->onClick[] = array($this, 'projectFormSendSubmitted');
		
		$form->addSubmit('Clear', 'Clear')
				->onClick[] = array($this, 'projectFormClearSubmitted');
        
        $form->addSubmit('Export', 'Export')
				->onClick[] = array($this, 'projectFormExportSubmitted');
		
		return $form;
	}
	
    /**
     * Generates distribution list according to project
     * @param SubmitButton $button
     * @param boolean $export
     */
    private function generateProjectDistributionList(SubmitButton $button, $export = FALSE)
    {
        $entry = $button->form->getValues();
		
		$project = $this->context->projectRepository->find($entry->Project);		
		if ($project)
		{
			$eid_array = array($project->PIPM, $project->TM, $project->PMOE, $project->PPaC);
            
            if (count($eid_array) === 0)
                $this->emptyDistributionList();

            if ($export)
            {
                try
                {
                    $report_name = 'project-' . preg_replace('/\s+/', '', $project->Name);
                    $dl_report = new DistributionListReportService($this->context, $report_name, $eid_array, NULL);
                    $dl_report->runDistributionListReportGeneration();
                }
                catch (Exception $e)
                {
                    $this->flashMessage('Can not export distibution list. Unable to set up execution time. Please, try it again.', 'error');
                }
            }
            else
            {
                $list = $this->createEIDList($eid_array);
                $button->form['List']->setValue($list);
            }
		}
        else
        {
            $this->emptyDistributionList();
        }

		$this->context->formStateRepository->save('dlProjectForm', $button->form);
	    $this->redirect('DistributionList:default');
    }
    
	/**
	 * Service for Send button of ProjectForm
	 * @param SubmitButton $button
	 */
	public function projectFormSendSubmitted(SubmitButton $button)
	{
		$this->generateProjectDistributionList($button);
	}
    
	/**
	 * Service for Export button of ProjectForm
	 * @param SubmitButton $button
	 */
	public function projectFormExportSubmitted(SubmitButton $button)
	{
		$this->generateProjectDistributionList($button, TRUE);
	}
	
	/**
	 * Service for Clear button of ProjectForm
	 * @param SubmitButton $button
	 */
	public function projectFormClearSubmitted(SubmitButton $button)
	{
		$this->context->formStateRepository->drop('dlProjectForm');
	    $this->redirect('DistributionList:default');
	}
    
    /**
     * Notify about empty distribution list
     */
    private function emptyDistributionList()
    {
        $this->flashMessage('Selected distribution list is empty.', 'info');
        $this->redirect('DistributionList:default');
    }
    
	/**
	 * Creates list of EIDs containing unique values delimited by predefined character.
	 * Example: "E123456; E987452; "
	 * @param array $array Should contains EIDs
	 * @return string List of EIDs
	 */
	protected function createEIDList($array)
	{
		$eid_array = array_unique($array);
		
		$list = '';		
		foreach ($eid_array as $eid)
			if (preg_match('/(E|e|H|h|T|t)[0-9]{6}/', $eid) === 1)
			    $list .= $eid . '; ';
			
		return $list;
	}
}
