<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2011, 2012 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package presenters
 */

/**
 * Presenter for EAC hours report.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class EACPresenter extends SecuredPresenter
{
        
    /**
     * Nette default render method.
     */
    public function renderDefault()
    {
        $formDefaultReport = array();
		$lock = $this->context->createLock('EAC_Report');
        $downloadReport = $this['downloadForm'];
		if($lock->locked())
		{
			$downloadReport['download']->setDisabled(TRUE);
			$this->flashMessage('Report is generated right now.', 'notice');
		}
        $downloadReport->setDefaults($formDefaultReport);
        $this->template->downloadReport = $downloadReport;
		
		$dir = null;
        if (file_exists(Environment::getConfig('eacDetails_storage_dir'))) 
			$dir = opendir(Environment::getConfig('eacDetails_storage_dir'));
		$files = array();
		//List files in directory
		if($dir != null)
		{
			while (($file = readdir($dir)) !== false)
			{
				if(preg_match('#.xlsx#', $file))
				{
					$files[$file]['file'] = $file;
					$files[$file]['modDate'] = date("Y-d-m H:i:s.", filemtime(Environment::getConfig('eacDetails_storage_dir') . $file));
				}
			}
			closedir($dir); 
		}
		
		$this->template->path = Environment::getConfig('eacDetails_storage_dir');
		$this->template->files = $files;
    }  
    
    /**
     * Creates form for download.
     * 
     * @param string $name Name of the form.
     * @return AppForm Returns AppForm.
     */
    public function createComponentDownloadForm($name)
    {
        $form = new AppForm($this, $name);
        $years = array();
		for ($i = 2012; $i <= (date('Y') +2); $i++)
			$years[$i] = $i;
        $form->addSelect('Year', 'Year', $years)->setDefaultValue(date('Y'));
		
        $allSbe = $this->context->organizationUnitRepository->findAllOrgUnitByType(OrganizationUnit::ORG_UNIT_TYPE_SBE);
        $sbes = array();
		$sbes[0] = 'AEE - All SBEs';
		foreach ($allSbe as $sbe)
		{
			$sbes[$sbe->ID] = $sbe->Name;
		}
        $form->addSelect('sbe', 'Strategic Business Unit', $sbes);
        $form->addHidden('download_token_value_id');
        $form->addSubmit('download', 'Regenerate EAC details');
        $form->onSuccess[] = array($this, 'downloadFormSubmitted');
    }    
    
    /**
     * Component downloadForm submit download EAC report.
     * 
     * @param AppForm $form 
     */
    public function downloadFormSubmitted(AppForm $form)
    {
        $values = $form->getValues();
		$year = $values['Year'];
		$sbe = null;
		if($values['sbe'] == 0)
		{
			$sbe = $this->context->organizationUnitRepository->findAllOrgUnitByType(OrganizationUnit::ORG_UNIT_TYPE_SBE);
		}
		else
		{
			$sbe[] = $this->context->organizationUnitRepository->find($values['sbe']);
		}

		if(count($sbe) <= 0)
		{
			$this->flashMessage('SBE with ID: ' . $values['sbe'] . ' was not found.', 'error');
			$this->redirect('default');
		}
		$multilog = new MultiLogger();
		$batch_id = 'EAC-'.time().'-'. rand(1, 9);
		$multilog->add($this->context->createLogger($batch_id, "EAC generation"));
        $EACReportService = new EACReportService($this->context, $multilog, $year, $sbe, $values['download_token_value_id']);
		$importResult = true;
        try
        {
            $EACReportService->runEACDetailsGeneration();
		}
        catch (EeacReportServiceException $e)
        {
			$importResult = false;
            Debugger::log('TT manual generation failed: ' . $e->getMessage(), Debugger::ERROR);
			$multilog->log('TT manual generation failed: ' . $e->getMessage(), ILogger::ERROR);
			$this->flashMessage('TT manual generation failed: ' . $e->getMessage(), 'error');
		}
		if($importResult)
		{
			$multilog->log('EAC manual generation completed.', ILogger::NOTICE);
			$this->flashMessage('Report regeneration was successful.', 'success');
		}
		$this->redirect('default');
    }
}