<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2011, 2012 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Presenter for administration of exchange rates.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class ExchangeRatePresenter extends SecuredPresenter
{

	/** @const Definition of currnecies */
	const CZK = 'CZK';
	const USD = 'USD';
	const EUR = 'EUR';
    /**
     * (non-phpDoc)
     *
     * @see Nette\Application\Presenter#startup()
     */
    protected function startup() 
    {
        parent::startup();
    }
    
    /**
     * List of Exchange rates for defined years.
     */
    public function renderDefault() 
    {
        $yearsCZKtoUSD = $this->context->exchangeRatesRepository->findExchangeRateYears(ExchangeRatePresenter::CZK, ExchangeRatePresenter::USD);
		$yearsEURtoUSD = $this->context->exchangeRatesRepository->findExchangeRateYears(ExchangeRatePresenter::EUR, ExchangeRatePresenter::USD);		
        $this->template->yearsCZKtoUSD = $yearsCZKtoUSD;
		$this->template->yearsEURtoUSD = $yearsEURtoUSD;
        //die;
        $formDefaultReport = array();
        $addYearReport = $this['addYearForm'];
        $addYearReport->setDefaults($formDefaultReport);
        $this->template->addYearButton = $addYearReport;
    }
    
    /**
     * Shows detail of a Exchange rates for year $year.
	 * @param string $source_curr	Source currency (3-letter ISO code)
	 * @param string $target_curr	Target currency (3-letter ISO code)
     * @param type $year Year.
     */
    public function renderShowDetail($year, $source_curr, $target_curr)
    {
        $rates = array();
        $rates = $this->context->exchangeRatesRepository->findYearRates($source_curr, $target_curr, $year);

        $form_defaults = array();
        $form_defaults['Year'] = $year;
		$form_defaults['source_curr'] = $source_curr;
		$form_defaults['target_curr'] = $target_curr;
        
        for($i=0; $i<12; $i++)
        {            
            $form_defaults[ FiscalCalendar::fiscalMonthIndexToName($i, false) ] = $rates[$i+1]->value;
        }
        
        $this->template->form = $this['exchangeRateForm'];
        $this->template->form->setDefaults($form_defaults);
    }
    
    /**
     * Creates ExchangeRateForm for editing Exchange Rates.
     * 
     * @param string $name ExchangeRateForm.
     * @return AppForm ExchangeRateForm.
     */
    public function createComponentExchangeRateForm($name)
    {
        $form = new AppForm($this, $name);
        
        $width = 3;

        $form->addText('Year', 'Year', $width)
            ->setAttribute('readonly', 'readonly');
		
		$form->addHidden('source_curr');
		$form->addHidden('target_curr');

        $form->addText('Jan', 'January', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [January]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [January]', array(0, 999));
        $form->addText('Feb', 'February', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [February]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [February]', array(0, 999));
        $form->addText('Mar', 'March', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [March]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [March]', array(0, 999));
        $form->addText('Apr', 'April', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [April]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [April]', array(0, 999));
        $form->addText('May', 'May', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [May]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [May]', array(0, 999));
        $form->addText('Jun', 'June', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [June]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [June]', array(0, 999));
        $form->addText('Jul', 'July', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [July]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [July]', array(0, 999));
        $form->addText('Aug', 'August', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [August]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [August]', array(0, 999));
        $form->addText('Sep', 'September', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [September]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [September]', array(0, 999));
        $form->addText('Oct', 'October', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [October]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [October]', array(0, 999));
        $form->addText('Nov', 'November', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [November]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [November]', array(0, 999));
        $form->addText('Dec', 'December', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [December]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [December]', array(0, 999));
        
        $form->addSubmit('back', 'Go back')
            ->setValidationScope(FALSE)
            ->onClick[] = callback($this, 'backClicked');
        $submit_button = $form->addSubmit('save', 'Save');
		if (!$this->isAllowed(self::RESOURCE_EXCHANGE_RATE, self::ACTION_EDIT))
			$submit_button->setDisabled(true);
		
        $form->onSuccess[] = array($this, 'exchangeRateFormSubmitted');

        return $form;
    }
    
    
    /**
     * Creates AddYearForm for inserting new years.
     * 
     * @param string $name AddYearForm.
     * @return AppForm AddYearForm.
     */
    public function createComponentAddYearForm($name)
    {
        $form = new AppForm($this, $name);
        $button = $form->addSubmit('addYearCZKtoUSD', 'Add next year');

		if (!$this->isAllowed(self::RESOURCE_EXCHANGE_RATE, self::ACTION_CREATE))
            $button->setDisabled(true);
        
        $button->setValidationScope(FALSE)
            ->onClick[] = callback($this, 'addYearClickedCZKtoUSD');
		
		$button = $form->addSubmit('addYearEURtoUSD', 'Add next year');

		if (!$this->isAllowed(self::RESOURCE_EXCHANGE_RATE, self::ACTION_CREATE))
            $button->setDisabled(true);
        
        $button->setValidationScope(FALSE)
            ->onClick[] = callback($this, 'addYearClickedEURtoUSD');
    }
    
    /**
     * ExchangeRateForm submitted.
     * 
     * @param AppForm $form ExchangeRateForm submitted.
     */
    public function exchangeRateFormSubmitted(AppForm $form)
    {
        $entry = array();
		$monthArray = array('Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec');
        $entry = $form->getValues();
		if ($this->isAllowed(self::RESOURCE_EXCHANGE_RATE, self::ACTION_EDIT))
		{
			if ($form->isValid())
			{
                $currencyExchangeRate = new CurrencyExchangeRate();
                $currencyExchangeRate->setSourceCurrencyCode($entry['source_curr']);
                $currencyExchangeRate->setTargetCurrencyCode($entry['target_curr']);
                $currencyExchangeRate->setYear($entry['Year']);
                $succes = false;
				$i=1;
                foreach($entry as $month => $monthValue)
                {
                    if(in_array($month, $monthArray))
                    {
                        $currencyExchangeRate->setMonth($i);
                        $currencyExchangeRate->setValue($monthValue);
                        if ($this->context->exchangeRatesRepository->update($currencyExchangeRate))                        
                            $succes = true;                        
                        else                        
                            $succes = false;                         
						$i++;
                    }
                }
                if ($succes)                
                    $this->flashMessage("Exchange Rate for year " . $entry['Year'] . " updated successfully.", 'success');                
                else                
                    $this->flashMessage("Exchange Rate for year " . $entry['Year'] . " updated unsuccessfully.", 'error');                
			}
			else
			{
				$this->flashMessage("Invalid form values.");
			}
		}
		else
		{
			$this->flashMessage("You are not authorized to update exchange rate. ADMIN role required.", 'error');
		}
        $this->redirect('ExchangeRate:showDetail', $entry['Year'], $entry['source_curr'], $entry['target_curr']);
    }
    
    /**
     * Go back button redirects back to ExchangeRate:default.
     * 
     * @param SubmitButton $button Go back button.
     */
    public function backClicked(SubmitButton $button)
    {
        $this->redirect('default');
    }
    
    /**
     * Add year button inserts new year.
     * 
     * @param SubmitButton $button.
     */
    public function addYearClickedCZKtoUSD(SubmitButton $button)
    {        
		if ($this->isAllowed(self::RESOURCE_EXCHANGE_RATE, self::ACTION_CREATE))
		{
            $years = $this->context->exchangeRatesRepository->findExchangeRateYears('CZK', 'USD');
            $lastYear = end($years);
            $succes = false;
            
            $currencyExchangeRate = new CurrencyExchangeRate();
            $currencyExchangeRate->setSourceCurrencyCode('CZK');
            $currencyExchangeRate->setTargetCurrencyCode('USD');
            $currencyExchangeRate->setYear(++$lastYear);
            $currencyExchangeRate->setValue(1.00);
            for($i = 1; $i < 13; $i++)
            {
                $currencyExchangeRate->setMonth($i);
                if ($this->context->exchangeRatesRepository->save($currencyExchangeRate))                        
                    $succes = true;                        
                else                        
                    $succes = false; 
                
            }
            if ($succes)                
                $this->flashMessage("Year was added successfully.", 'success');                
            else                
                $this->flashMessage("Adding new year failed.", 'error');                
		}
		else
		{
			$this->flashMessage("You are not authorized to add new year. ADMIN role required.", 'error');
		}
        $this->redirect('ExchangeRate:default');
    }
	
    /**
     * Add year button inserts new year.
     * 
     * @param SubmitButton $button.
     */
    public function addYearClickedEURtoUSD(SubmitButton $button)
    {        
		if ($this->isAllowed(self::RESOURCE_EXCHANGE_RATE, self::ACTION_CREATE))
		{
            $years = $this->context->exchangeRatesRepository->findExchangeRateYears('EUR', 'USD');
            $lastYear = end($years);
            $succes = false;
            
            $currencyExchangeRate = new CurrencyExchangeRate();
            $currencyExchangeRate->setSourceCurrencyCode('EUR');
            $currencyExchangeRate->setTargetCurrencyCode('USD');
            $currencyExchangeRate->setYear(++$lastYear);
            $currencyExchangeRate->setValue(1.00);
            for($i = 1; $i < 13; $i++)
            {
                $currencyExchangeRate->setMonth($i);
                if ($this->context->exchangeRatesRepository->save($currencyExchangeRate))                        
                    $succes = true;                        
                else                        
                    $succes = false; 
                
            }
            if ($succes)                
                $this->flashMessage("Year was added successfully.", 'success');                
            else                
                $this->flashMessage("Adding new year failed.", 'error');                
		}
		else
		{
			$this->flashMessage("You are not authorized to add new year. ADMIN role required.", 'error');
		}
        $this->redirect('ExchangeRate:default');
    }
}