<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2013 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package presenters/Helpers
 */

/**
 * Set of helper functions for styling coverages in templates/output.
 * It is intended to simplify latte templates.
 * 
 * Warning: This class is strongly coupled with CSS styles!
 *
 * @author Martin Kotlar <martin.kotlar@honeywell.com>
 * @static
 */
class CoverageStyleHelper extends Object 
{
	const CRITICAL_LEVEL_CSS = 'resourceUndercharged';
	const WARNING_LEVEL_CSS = 'resourceOvercharged';
	const CORRECT_LEVEL_CSS = 'resourceChargedOk';

	const CRITICAL_LEVEL_LOWER_BOUND = 50;
	const WARNING_LEVEL_LOWER_BOUND = 85;
	const WARNING_LEVEL_UPPER_BOUND = 115;
	const CRITICAL_LEVEL_UPPER_BOUND = 150;

	/**
     * Hidden constructor. Class is static.
	 * @todo Load styles and levels from GlobalSettings (to be added).
     */
    private function __construct() 
    {
    }

    /**
     * Returns name of CSS style to be used for formatting coverage.
	 * Input is interpreted as a percentage.
     * 
     * @param float $percentage Percentage to be formated.
     * @return string Returns CSS style name.
     * @throws InvalidArgumentException on invalid input
     */
    public static function coveragePercentageToCSS($percentage) 
    {
		if (is_numeric($percentage))
		{
			if (($percentage >= CoverageStyleHelper::WARNING_LEVEL_LOWER_BOUND) && ($percentage <= CoverageStyleHelper::WARNING_LEVEL_UPPER_BOUND))
				return CoverageStyleHelper::CORRECT_LEVEL_CSS;
			elseif ((($percentage >= CoverageStyleHelper::CRITICAL_LEVEL_LOWER_BOUND) && ($percentage < CoverageStyleHelper::WARNING_LEVEL_LOWER_BOUND))
					|| (($percentage > CoverageStyleHelper::WARNING_LEVEL_UPPER_BOUND) && ($percentage <= CoverageStyleHelper::CRITICAL_LEVEL_UPPER_BOUND)))
				return CoverageStyleHelper::WARNING_LEVEL_CSS;
			else
				return CoverageStyleHelper::CRITICAL_LEVEL_CSS;
		}
		else
			throw new InvalidArgumentException('Input is not a number representation.');
    }

    /**
     * Returns type of a coverage percentage as CSS style.
	 * Possible $type parameter values are "critical", "warning", "correct".
	 * Can be used for queriying CSS styles for legend creation.
     * 
     * @param string $type Type of coverage percentage evaluation.
     * @return string Returns CSS style name.
     */
    public static function coveragePercentageTypeToCSS($type) 
    {
		if ($type == "critical")
			return CoverageStyleHelper::CRITICAL_LEVEL_CSS;
		elseif ($type == "warning")
			return CoverageStyleHelper::WARNING_LEVEL_CSS;
		elseif ($type == "correct")
			return CoverageStyleHelper::CORRECT_LEVEL_CSS;
		else 
			return "";
    }

    /**
     * Returns boudary of a ranges for coverage percentage evaluation.
	 * Possible $type parameter values are "critical", "warning", "correct".
	 * Can be used for queriying CSS styles for legend creation.
	 * 
	 * 
	 * 
     * @param string $type Type of coverage percentage evaluation: "critical", "warning"
     * @param boolean $upper Returns upper boundary for given type above "correct" range if TRUE, otherwise boundary below "correct" range.
     * @return int Returns boundary or NULL is invalid type
     */
    public static function coveragePercentageBoundary($type, $upper) 
    {
		if ($type == "critical")
			return ($upper) ? CoverageStyleHelper::CRITICAL_LEVEL_UPPER_BOUND : CoverageStyleHelper::CRITICAL_LEVEL_LOWER_BOUND;
		elseif ($type == "warning")
			return ($upper) ? CoverageStyleHelper::WARNING_LEVEL_UPPER_BOUND : CoverageStyleHelper::WARNING_LEVEL_LOWER_BOUND;
		else 
			return NULL;
    }
	
}
