<?php
/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2011 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package presenters
 */

/**
 * LoginPresenter presents login forms 
 * and logs user in the applications.
 *
 * @author Jiri Zajic <jiri.zajic@honeywell.com>
 * @author Martin Kotlar <martin.kotlar@honeywell.com>
 */
class LoginPresenter extends BasePresenter
{
    /** @persistent */
    public $backlink = '';
	
	/**
	 * Kicks user out of application
	 */
    public function actionLogout()
    {
    	// Log out and clear identity
    	$this->getUser()->logout(true);
        $this->flashMessage('You have been logged out.');
        $this->redirect('Login:default');
    }

	/**
	 * Shows default page
	 */
    public function renderDefault()
	{
		// Redirect to dashboard if user is logged in
		if ($this->getUser()->isLoggedIn())
			$this->redirect('Dashboard:default');
    }
    
	/**
	 * Creates login form
	 * @return AppForm
	 */
	protected function createComponentLoginForm()
	{
		$form = new AppForm();

		$form->addText('username', 'Honeywell EID')
				->addRule(Form::FILLED, 'Input your Honeywell EID.');

		$form->addPassword('password', 'LDAP Password')
				->addRule(Form::FILLED, 'Input your LDAP password.');

		$form->addSubmit('login', 'Log in');

		$form->onSuccess[] = array($this, 'loginFormSubmitted');

		return $form;
	}

	/**
	 * Action triggerd by submitting the login form.
	 * Performs actual login if correct credentials are inputted.
	 * 
	 * @param AppForm
	 */
	public function loginFormSubmitted($form)
	{
		try
		{
            $values = $form->getValues();

			$user = $this->getUser();
			$user->login($values['username'], $values['password']);
			// Life expectancy of user login is 7 days
			$user->setExpiration('7 days', false);
			
			$multilog = new MultiLogger();
			$batch_id = 'login-'.time().'-'. rand(1, 9);
			$multilog->add($this->context->createLogger($batch_id, "LOGIN"));
			
            $person = $this->context->personRepository->find($user->getId());

            if ($person !== null)
            {
            	$multilog->log($person->FullName . ' was logged in via HPT database.', ILogger::NOTICE);
            }
            else
            {
            	$multilog->log($user->getId() . ' was logged in via LDAP server.', ILogger::NOTICE);
            }

            $this->restoreRequest($this->backlink);
			$this->redirect('Dashboard:default');
		}
		catch (AuthenticationException $e)
		{
			$this->flashMessage($e->getMessage(), 'error');
		}
	}	
}