<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2011, 2012 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Presenter for administration of user roles.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class UserRolePresenter extends SecuredPresenter
{
    
	/**
	 * Overloads startup of presenter.
	 *
	 * @see Nette\Application\Presenter#startup()
	 */
	protected function startup()
	{
		parent::startup();
	}
    
    /**
     * Nette default render method.
     */
    public function renderDefault($id) 
    {
        $person = $this->context->personRepository->find($id);
        $this->template->userName = $person->surname . ", " . substr($person->firstname, 0, 1) . ".";
        
        if (!$this->testUserRoles('ADMIN'))
		{
			$this->flashMessage("You are not authorized to use this functionality. ADMIN role required.", 'info');
			$this->redirect('Person:showDetail', $id);
		}
        
        $userRoles = $this->context->userRoleRepository->findUserRoles($id);        
        $formDefaultUserRole = array();
        $count = count($userRoles);
        
        if($count == 0)
        {
                $formDefaultUserRole['admin'] = 0;
                $formDefaultUserRole['pmo'] = 0;
        }
        elseif($count == 1)
        {
            if($userRoles[0]->role == "ADMIN")
            {
                $formDefaultUserRole['admin'] = 1;
                $formDefaultUserRole['pmo'] = 0;
            }
            else
            {
                $formDefaultUserRole['admin'] = 0;
                $formDefaultUserRole['pmo'] = 1;
            }
        }
        else
        {
                $formDefaultUserRole['admin'] = 1;
                $formDefaultUserRole['pmo'] = 1;
        }

        $formUserRole = $this['userRoleForm'];
        $formUserRole->setDefaults($formDefaultUserRole);
        $this->template->formUserRole = $formUserRole;        
    }
    
    /**
     * Creates form for user roles.
     * 
     * @param string $name Name of the form.
     * @return AppForm Returns AppForm.
     */
    public function createComponentUserRoleForm($name)
    {
        $form = new AppForm($this, $name);
        
        $options = array(            
            '1' => 'Yes',
            '0' => 'No',
        );        

        $form->addRadioList('admin', 'ADMIN', $options)
                ->getSeparatorPrototype()->setName(NULL);
        $form->addRadioList('pmo', 'PMO', $options)
                ->getSeparatorPrototype()->setName(NULL);
        $form->addSubmit('save', 'Save');
        $form->addSubmit('back', 'Go back')
                ->setValidationScope(FALSE)
                ->onClick[] = callback($this, 'backClicked');
        $form->onSuccess[] = array($this, 'userRoleFormSubmittedSave');
    }
    
    /**
     * User setting form submitted.
     * 
     * @param AppForm $form 
     */
    public function userRoleFormSubmittedSave($form)
    {
        $eid = $this->getHttpRequest()->getQuery('id');
        $data = $form->getValues();
        $userRoles = new UserRole();
        $userRoles->ID = $eid;
        $deleteRole = false;
        if($this->context->userRoleRepository->delete($eid, "ADMIN") AND $this->context->userRoleRepository->delete($eid, "PMO"))
        {
            $deleteRole = true;
        }

        if ($this->testUserRoles('ADMIN'))
        {
            if($form->isValid())
            {
                if($data['pmo'] == "1" AND $data['admin'] == "1")
                {
                    $userRoles->role = "PMO";
                    if ($this->context->userRoleRepository->save($userRoles))
                        Debugger::log("User role of person: ".$eid." updated.", Debugger::INFO);
                    $userRoles->role = "ADMIN";
                    if ($this->context->userRoleRepository->save($userRoles))
                    {
                        Debugger::log("User role of person: ".$eid." updated.", Debugger::INFO);
                        $this->flashMessage("User roles updated.", 'success');
                    }
                    else
                        $this->flashMessage("Updating user roles failed.", 'error');
                }
                elseif ($data['pmo'] == "1" AND $data['admin'] == "0")
                {
                    $userRoles->role = "PMO";
                    if ($this->context->userRoleRepository->save($userRoles))
                    {
                        Debugger::log("User role of person: ".$eid." updated.", Debugger::INFO);
                        $this->flashMessage("User roles updated.", 'success');
                    }
                    else
                        $this->flashMessage("Updating user roles failed.", 'error');
                }
                elseif ($data['pmo'] == "0" AND $data['admin'] == "1")
                {
                    $userRoles->role = "ADMIN";
                    if ($this->context->userRoleRepository->save($userRoles))
                    {
                        Debugger::log("User role of person: ".$eid." updated.", Debugger::INFO);
                        $this->flashMessage("User roles updated.", 'success');
                    }
                    else
                        $this->flashMessage("Updating user roles failed.", 'success');
                }
                else
                    if($deleteRole)
                        $this->flashMessage("User roles updated.", 'success');
                    else
                        $this->flashMessage("Updating user roles failed.", 'error');
            }
            else
            {  
                $this->flashMessage("Invalid User role values.");
            }
        }
        else
        {
            $this->flashMessage("You are not authorized to use this functionality. ADMIN role required.", 'info');
        }

        $this->redirect('Person:showDetail', $eid);
    }
    
    /**
     * Go back button redirects back to Person:showDetail.
     * 
     * @param SubmitButton $button Go back button.
     */
    public function backClicked(SubmitButton $button)
    {
        $person_id = $this->getHttpRequest()->getQuery('id');
        $this->redirect('Person:showDetail', $person_id);
    }
}