<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2011 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package presenters
 */

/**
 * Presenter for administration of Strap Item Activities.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class ActivityPresenter extends SecuredPresenter
{
    /**
     * Nette default render method.
	 * Shows list of STRAP Item Activities
	 * 
	 * @param int $item Strap Item ID. 
     */
    public function renderDefault($item = null)
    {
		$activity = $this->context->itemRepository->find($item);
		if(is_null($activity))
		{
			$this->flashMessage("Selected Strap Item with ID: " . $item . " does not exist.", 'notice');
			$this->redirect('Item:default');
		}
		
		//find all activities
		$activities = $this->context->itemActivityRepository->findByItemID($activity->ID);
		$all_licences = $this->context->ecLicenceRepository->findAll();
		$this->template->activities = $activities;
		$this->template->all_licences = $all_licences;
    }
    
	/*
	 * Shows detail of selected Strap Item Activtity
	 * 
	 * @param int $item Strap Item ID. 
	 * @param int $activity Strap Item Activity ID.
	 */
    public function renderShowActivity($item = null, $activity = null)
    {		
		// select sub portfolios if portfolio is selected
		if(isset($this->payload->portfolioManager))
		{
			if($this->payload->portfolioManager)
			{
				// finds all marketing and project manager
				$MaPMItems = array();
				$MaPMs = $this->context->advisorRepository->findAllChildren($this->payload->portfolioManager);
				foreach($MaPMs as $MaPM)
					$MaPMItems[$MaPM->ID] = $MaPM->Name;
				$form = $this['detailActivityForm'];
				$form['MaPM']->setItems($MaPMItems);
				$form['MaPM']->setPrompt('- Choose -');
				$this->template->form = $form;
			}
			else
			{
				$form = $this['detailActivityForm'];
				$form['MaPM']->setPrompt('- Choose -');
				$this->template->form = $form;
			}
			//prepare url for ajax action MaPM change
			$url2 = str_replace('?', '?do=MaPMChange&', $this->link('Activity:showActivity'));
			$this->template->linkMaPMChange = $url2;
			return;
		}
		//redirecting if activity parameter is null
		$activityID  = $activity;
		if(is_null($activityID) && $this->isAjax())
		{
			$activityID = $this->payload->activityID;
		}
		$activity = $this->context->itemActivityRepository->find($activityID);
		if(is_null($activity))
		{
			$this->flashMessage("Selected Strap Item Activity with ID: " . $activityID . " does not exist.", 'notice');
			if($item)
				$this->redirect('Item:showItem', $item);
			else
				$this->redirect('Item:default');
		}
		$this->template->item = $this->context->itemRepository->find($activity->itemID);
		// select pursuit form defaults
		$selectPursuitDefaults = array();
		$this->template->linkToPursuits = array();
		$selectPursuitDefaults['itemID'] = $activity->itemID;
		$selectPursuitDefaults['activityID'] = $activity->ID;
		
		$form = $this['detailActivityForm'];
		$selectPursuitForm = $this['selectPursuitForm'];
		
		// setting prompt values
		$form['targetTRL']->setPrompt('- Choose -');
		$form['productLine']->setPrompt('- Choose -');
		$form['technologyRoadmapDomain']->setPrompt('- Choose -');
		$form['MaPM']->setPrompt('- Choose -');
		$form['RTCDirector']->setPrompt('- Choose -');
		$form['portfolioManager']->setPrompt('- Choose -');
		// pre fill form by previous values
		if(isset($this->payload->form))
		{
			$formDefaults = $this->payload->form;
			if($this->payload->form['portfolioManager'])
			{
				// finds all marketing and project manager
				$MaPMItems = array();
				$MaPMs = $this->context->advisorRepository->findAllChildren($this->payload->form['portfolioManager']);
				foreach($MaPMs as $MaPM)
					$MaPMItems[$MaPM->ID] = $MaPM->Name;
				$form['MaPM']->setItems($MaPMItems);
				$form['MaPM']->setPrompt('- Choose -');
			}
		}
		// gets default form values from Database
		else
		{
			$formDefaults = array();
			$formDefaults['id'] = $activity->ID;
			$formDefaults['item'] = $activity->ItemID;
			$formDefaults['itemID'] = $activity->ItemID;
			$formDefaults['name'] = $activity->Name;
			$formDefaults['targetTRL'] = $activity->TargetTRL;
			$formDefaults['TRLyear'] = $activity->TargetTRLYear;
			$formDefaults['remarks'] = $activity->Remarks;
			$productLine = $this->context->productLineRepository->find($activity->ProductLine);
			if($productLine)
				$formDefaults['productLine'] = $productLine->ProductName;
			$technologyRoadmapDomain = $this->context->technologyRoadmapDomainRepository->find($activity->TechnologyRoadmapDomain);
			if($technologyRoadmapDomain)
				$formDefaults['technologyRoadmapDomain'] = $technologyRoadmapDomain->Domain;
			$MaPM = $this->context->advisorRepository->find($activity->MarketingProductManager);
			if($MaPM)
				$formDefaults['MaPM'] = $MaPM->ID;
			$RTCDirector = $this->context->advisorRepository->find($activity->RTCDirector);
			if($RTCDirector)
				$formDefaults['RTCDirector'] = $RTCDirector->ID;
			$portfolioManager = $this->context->advisorRepository->find($activity->PortfolioManager);
			if($portfolioManager)
			{
				$formDefaults['portfolioManager'] = $portfolioManager->ID;
				$MaPMItems = array();
				$MaPMs = $this->context->advisorRepository->findAllChildren($portfolioManager->ID);
				foreach($MaPMs as $MaPM)
					$MaPMItems[$MaPM->ID] = $MaPM->Name;
				$form['MaPM']->setItems($MaPMItems);
				$form['MaPM']->setPrompt('- Choose -');
			}
			$formDefaults['ECLicenceID'] = $activity->ECLicenceID;
		}
		//some default values depend on the activity type
		if(isset($this->payload->activityType))
		{
			$type = $this->payload->activityType;
			if($activity->getType() != $type)
			{
				$form['pursuit']->setPrompt('- Choose -');
				$form['project']->setPrompt('- Choose -');
			}
			$formDefaults['type'] = $this->payload->activityType;
		}
		else
		{
			$type = $activity->getType();
			if($type)
				$formDefaults['type'] = $type;
		}
		
		switch($type)
		{
			//project
			case $activity::ITEM_ACTIVITY_TYPE_PROJECT :
				$form['project']->addRule(FORM::FILLED, 'Project is mandatory.');
				$formDefaults['probabilityOfWin'] = 100;
				$form['probabilityOfWin']->setDisabled(true);
				$formDefaults['costShare'] = $activity->CostShare * 100;
				if(isset($this->payload->activityTypeChoosenID))
				{
					if($this->payload->activityTypeChoosenID != null)
						$project = $this->context->projectRepository->find($this->payload->activityTypeChoosenID);
					else
						$project = $this->context->projectRepository->find($activity->ProjectID);
				}
				else
				{
					$project = $this->context->projectRepository->find($activity->ProjectID);
				}
				if($project)
				{
					$year = Date('Y');
					// budget plan for current year
					$reporter = new ProjectEACReporter($this->context, $project, $year);
					try
					{
						$formDefaults[$year . '_Labor'] = $reporter->getProjectLabourPlannedCostsMonthTotals()->sum();
					}
					catch (InvalidStateException $e)
					{
						$this->flashMessage($e->getMessage(), 'error');
						Debugger::log($e->getMessage(), Debugger::ERROR);
						$this->redirect('default');
					}
					$formDefaults[$year . '_Travel'] = $reporter->getProjectTravelPlannedCostsMonthTotals()->sum();
					$formDefaults[$year . '_Material'] = $reporter->getProjectMaterialPlannedCostsMonthTotals()->sum();
					$formDefaults[$year . '_Subcontracting'] = $reporter->getProjectSubcontractingPlannedCostsMonthTotals()->sum();
					$formDefaults[$year . '_Total'] = $formDefaults[$year . '_Labor'] + $formDefaults[$year . '_Travel'] + $formDefaults[$year . '_Material'] + $formDefaults[$year . '_Subcontracting'];
					$form[$year . '_Labor']->setDisabled(true);
					$form[$year . '_Travel']->setDisabled(true);
					$form[$year . '_Material']->setDisabled(true);
					$form[$year . '_Subcontracting']->setDisabled(true);
					//TODO: add plan for year + 1 from project charter plan.
					
					//budget default values
					$currentYear = (Date('Y') + 1);
					for($year = (Date('Y') + 1); $year <= ($currentYear+10); $year++)
					{
						$budget = $this->context->itemActivityYearlyBudgetRepository->find($activity->ID, $year);
						if($budget)
						{
							$formDefaults[$year . '_Labor'] = $budget->LaborCosts;
							$formDefaults[$year . '_Travel'] = $budget->TravelCosts;
							$formDefaults[$year . '_Material'] = $budget->MaterialCosts;
							$formDefaults[$year . '_Subcontracting'] = $budget->SubcontractingCosts;
							$formDefaults[$year . '_Total'] = $budget->LaborCosts + $budget->TravelCosts + $budget->MaterialCosts + $budget->SubcontractingCosts;
						}
					}
					$formDefaults['project'] = $project->ID;
					$formDefaults['projectAllocation'] = $activity->ProjectBudgetUsage * 100;
					$form['projectAllocation']->addRule(FORM::RANGE, 'Project allocation is over available range.', array(0, (100 - $this->context->itemActivityRepository->findProjectAllocation($project->ID)*100) + $activity->ProjectBudgetUsage*100));
					$this->template->ProjectAllocationRemain = (100 - $this->context->itemActivityRepository->findProjectAllocation($project->ID)*100);
					$this->template->linkToProjectID = $project->ID;
					$this->template->activitiesList = $this->context->itemActivityRepository->findProjectActivities($project->ID);
					// Activity covered by project inherits project EC licence
					// This EC licence is unchangeable - it depends on project
					$formDefaults['ECLicenceID'] = $project->ECLicenceID;
					$form['ECLicenceID']->setDisabled(TRUE);
				}
				break;
			//pursuit
			case $activity::ITEM_ACTIVITY_TYPE_PURSUIT :
				$form['pursuit']->addRule(FORM::FILLED, 'Pursuit is mandatory.');
				$selectPursuitForm['pursuit']->addRule(FORM::FILLED, 'Pursuit is mandatory.');
				$formDefaults['probabilityOfWin'] = null;
				$form['probabilityOfWin']->setDisabled(true);
				$formDefaults['costShare'] = null;
				$form['costShare']->setDisabled(true);
				if(isset($this->payload->activityTypeChoosenID))
				{
					if($this->payload->activityTypeChoosenID != null)
					{
						if (count($this->payload->activityTypeChoosenID) == 1)
						{
							$pursuit = $this->context->pursuitRepository->find($this->payload->activityTypeChoosenID);
							if($pursuit)
							{
								$formDefaults['pursuit'] = array($pursuit->PursuitID);
								$selectPursuitDefaults['pursuit'] = array($pursuit->PursuitID);
								$formDefaults['probabilityOfWin'] = $pursuit->ProbabilityOfWin * 100;
								$formDefaults['costShare'] = $pursuit->CostShare * 100;
								array_push($this->template->linkToPursuits, array('ID' => $pursuit->PursuitID, 'name' => $pursuit->Name));
							}
						}
						else
						{
							$formDefaults['pursuit'] = $this->payload->activityTypeChoosenID;
							$selectPursuitDefaults['pursuit'] = $this->payload->activityTypeChoosenID;
							foreach($this->payload->activityTypeChoosenID as $id)
							{
								$pursuit = $this->context->pursuitRepository->find($id);
								array_push($this->template->linkToPursuits, array('ID' => $pursuit->PursuitID, 'name' => $pursuit->Name));
							}
						}
					}
				}
				else
				{
					$pursuits = $this->context->pursuitRepository->findAllPursuitsByActivityID($activityID);
					if($pursuits)
					{
						if (count($pursuits) == 1)
						{
							$key = key($pursuits);
							$formDefaults['pursuit'] = array($key);
							$selectPursuitDefaults['pursuit'] = array($key);
							$formDefaults['probabilityOfWin'] = $pursuits[$key]->ProbabilityOfWin * 100;
							$formDefaults['costShare'] = $pursuits[$key]->CostShare * 100;
							array_push($this->template->linkToPursuits, array('ID' => $pursuits[$key]->PursuitID, 'name' => $pursuits[$key]->Name));
						}
						else
						{
							$pursuitsID = array();
							foreach($pursuits as $key => $pursuit)
							{
								$pursuitsID[] = $key;
								array_push($this->template->linkToPursuits, array('ID' => $pursuit->PursuitID, 'name' => $pursuit->Name));
							}
							$formDefaults['pursuit'] = $pursuitsID;
							$selectPursuitDefaults['pursuit'] = $pursuitsID;
						}
					}
				}

				//budget default values
				$currentYear = Date('Y');
				for($year = Date('Y'); $year <= ($currentYear+10); $year++)
				{
					$budget = $this->context->itemActivityYearlyBudgetRepository->find($activity->ID, $year);
					if($budget)
					{
						$formDefaults[$year . '_Labor'] = $budget->LaborCosts;
						$formDefaults[$year . '_Travel'] = $budget->TravelCosts;
						$formDefaults[$year . '_Material'] = $budget->MaterialCosts;
						$formDefaults[$year . '_Subcontracting'] = $budget->SubcontractingCosts;
						$formDefaults[$year . '_Total'] = $budget->LaborCosts + $budget->TravelCosts + $budget->MaterialCosts + $budget->SubcontractingCosts;
					}
				}
				break;
			//need to pursue
			case $activity::ITEM_ACTIVITY_TYPE_NEED_TO_PURSUE :
				$formDefaults['probabilityOfWin'] = 0;
				$form['probabilityOfWin']->setDisabled(true);
				$formDefaults['costShare'] = $activity->CostShare * 100;
				if($activity->PotentialCustomer)
				{
					$formDefaults['potentialCustomer'] = $activity->PotentialCustomer;
				}
				//budget default values
				$currentYear = Date('Y');
				for($year = Date('Y'); $year <= ($currentYear+10); $year++)
				{
					$budget = $this->context->itemActivityYearlyBudgetRepository->find($activity->ID, $year);
					if($budget)
					{
						$formDefaults[$year . '_Labor'] = $budget->LaborCosts;
						$formDefaults[$year . '_Travel'] = $budget->TravelCosts;
						$formDefaults[$year . '_Material'] = $budget->MaterialCosts;
						$formDefaults[$year . '_Subcontracting'] = $budget->SubcontractingCosts;
						$formDefaults[$year . '_Total'] = $budget->LaborCosts + $budget->TravelCosts + $budget->MaterialCosts + $budget->SubcontractingCosts;
					}
				}
				break;
			default :
				;
		}
		
		$form->setDefaults($formDefaults);
		
		// prepare template values
		$this->template->form = $form;
		$this->template->type = $type;
		$this->template->activity = $activity;
		$this->template->updatedBy = null;
		$updatedBy = $this->context->personRepository->find($activity->UpdatedBy);
		if($updatedBy)
			$this->template->updatedBy = $updatedBy->getFullNameWithEID();
		
		//prepare url for ajax action handle type change
        $url = str_replace('?', '?do=typeChangeDetailForm&', $this->link('Activity:showActivity'));
        $this->template->linkToSignal = $url;
		
		//prepare url for ajax action MaPM change
        $url2 = str_replace('?', '?do=MaPMChange&', $this->link('Activity:showActivity'));
        $this->template->linkMaPMChange = $url2;
		
		// set select pursuit form default values
		$selectPursuitForm->setDefaults($selectPursuitDefaults);
    }
	
	/*
	 * Renders form for creating new Strap Item Activtity
	 * 
	 * @param int $item Strap Item ID. 
	 */
	public function renderCreateActivity($item = null)
	{
		// select sub portfolios if portfolio is selected
		if(isset($this->payload->portfolioManager))
		{
			if($this->payload->portfolioManager)
			{
				// finds all marketing and project manager
				$MaPMItems = array();
				$MaPMs = $this->context->advisorRepository->findAllChildren($this->payload->portfolioManager);
				foreach($MaPMs as $MaPM)
					$MaPMItems[$MaPM->ID] = $MaPM->Name;
				$form = $this['createActivityForm'];
				$form['MaPM']->setItems($MaPMItems);
				$form['MaPM']->setPrompt('- Choose -');
				$this->template->form = $form;
			}
			else
			{
				$form = $this['createActivityForm'];
				$form['MaPM']->setPrompt('- Choose -');
				$this->template->form = $form;
			}
			//prepare url for ajax action MaPM change
			$url2 = str_replace('?', '?do=MaPMChange&', $this->link('Activity:showActivity'));
			$this->template->linkMaPMChange = $url2;
			return;
		}
		//redirecting if activity parameter is null
		$itemID  = $item;
		if(is_null($itemID) && $this->isAjax())
		{
			$itemID = $this->payload->itemID;
		}
		$item = $this->context->itemRepository->find($itemID);
		if(is_null($item))
		{
			$this->flashMessage("asdfStrap Item with ID: " . $itemID . " does not exist.", 'notice');
			$this->redirect('Item:default');
		}
		$this->template->item = $item;
		
		$activity = new ItemActivity();
		// select pursuit form defaults
		$selectPursuitDefaults = array();
		$this->template->linkToPursuits = array();
		$selectPursuitDefaults['itemID'] = $activity->itemID;
		$selectPursuitDefaults['activityID'] = $activity->ID;
		
		$selectPursuitForm = $this['selectPursuitForm'];
		$form = $this['createActivityForm'];
		
		$formDefaults = array();
		// pre fill form by previous values
		if(isset($this->payload->form))
		{
			$formDefaults = $this->payload->form;
			if(isset($this->payload->form['portfolioManager']))
			{
				// finds all marketing and project manager
				$MaPMItems = array();
				$MaPMs = $this->context->advisorRepository->findAllChildren($this->payload->form['portfolioManager']);
				foreach($MaPMs as $MaPM)
					$MaPMItems[$MaPM->ID] = $MaPM->Name;
				$form['MaPM']->setItems($MaPMItems);
			}
		}
        else
		{
			// Activity inherits EC licence from parent item by default
		    $formDefaults['ECLicenceID'] = $item->ECLicenceID;
        }
		
		// setting prompt values
		$formDefaults['itemID'] = $itemID;
		$form['targetTRL']->setPrompt('- Choose -');
		$form['productLine']->setPrompt('- Choose -');
		$form['technologyRoadmapDomain']->setPrompt('- Choose -');
		$form['MaPM']->setPrompt('- Choose -');
		$form['RTCDirector']->setPrompt('- Choose -');
		$form['portfolioManager']->setPrompt('- Choose -');
		$form['type']->setPrompt('- Choose -');
		$form['pursuit']->setPrompt('- Choose -');
		$form['project']->setPrompt('- Choose -');
				
		//some default options depend on the activity type
		if(isset($this->payload->activityType))
		{
			$type = $this->payload->activityType;
			$formDefaults['type'] = $type;
		}
		else
		{
			$type = null;
		}
		
		switch($type)
		{
			//project
			case $activity::ITEM_ACTIVITY_TYPE_PROJECT :
				$form['project']->addRule(FORM::FILLED, 'Project is mandatory.');
				$formDefaults['probabilityOfWin'] = 100;
				$form['probabilityOfWin']->setDisabled(true);
				if(isset($this->payload->activityTypeChoosenID))
				{
					if($this->payload->activityTypeChoosenID != null)
						$project = $this->context->projectRepository->find($this->payload->activityTypeChoosenID);
				}
				if(isset($project))
				{
					$year = Date('Y');
					// budget plan for current year
					$reporter = new ProjectEACReporter($this->context, $project, $year);
					try
					{
						$formDefaults[$year . '_Labor'] = $reporter->getProjectLabourPlannedCostsMonthTotals()->sum();
					}
					catch (InvalidStateException $e)
					{
						Debugger::log($e->getMessage(), Debugger::ERROR);
						$this->flashMessage($e->getMessage(), 'error');
						$this->redirect('default');
					}
					$formDefaults[$year . '_Travel'] = $reporter->getProjectTravelPlannedCostsMonthTotals()->sum();
					$formDefaults[$year . '_Material'] = $reporter->getProjectMaterialPlannedCostsMonthTotals()->sum();
					$formDefaults[$year . '_Subcontracting'] = $reporter->getProjectSubcontractingPlannedCostsMonthTotals()->sum();
					$form[$year . '_Labor']->setDisabled(true);
					$form[$year . '_Travel']->setDisabled(true);
					$form[$year . '_Material']->setDisabled(true);
					$form[$year . '_Subcontracting']->setDisabled(true);
					//TODO: add plan for year + 1 from project charter plan.
					$formDefaults['project'] = $project->ID;
					$formDefaults['projectAllocation'] = (100 - $this->context->itemActivityRepository->findProjectAllocation($project->ID)*100);
					$form['projectAllocation']->addRule(FORM::RANGE, 'Project allocation is over available range.', array(0, (100 - $this->context->itemActivityRepository->findProjectAllocation($project->ID)*100)));
					$this->template->ProjectAllocationRemain = (100 - $this->context->itemActivityRepository->findProjectAllocation($project->ID)*100);
					$this->template->linkToProjectID = $project->ID;
					$this->template->activitiesList = $this->context->itemActivityRepository->findProjectActivities($project->ID);
					// Activity covered by project inherits project EC licence
					// This EC licence is unchangeable - it depends on project
					$formDefaults['ECLicenceID'] = $project->ECLicenceID;
					$form['ECLicenceID']->setDisabled(TRUE);
				}
				break;
			//pursuit
			case $activity::ITEM_ACTIVITY_TYPE_PURSUIT :
				$form['pursuit']->addRule(FORM::FILLED, 'Pursuit is mandatory.');
				$selectPursuitForm['pursuit']->addRule(FORM::FILLED, 'Pursuit is mandatory.');
				$formDefaults['probabilityOfWin'] = null;
				$form['probabilityOfWin']->setDisabled(true);
				$formDefaults['costShare'] = null;
				$form['costShare']->setDisabled(true);
				if(isset($this->payload->activityTypeChoosenID))
				{
					if($this->payload->activityTypeChoosenID != null)
					{
						if (count($this->payload->activityTypeChoosenID) == 1)
						{
							$pursuit = $this->context->pursuitRepository->find($this->payload->activityTypeChoosenID);
							if(!is_null($pursuit))
							{
								$formDefaults['pursuit'] = array($pursuit->PursuitID);
								$selectPursuitDefaults['pursuit'] = array($pursuit->PursuitID);
								$formDefaults['probabilityOfWin'] = $pursuit->ProbabilityOfWin * 100;
								$formDefaults['costShare'] = $pursuit->CostShare * 100;
								$this->template->linkToPursuitID = $pursuit->PursuitID;
								array_push($this->template->linkToPursuits, array('ID' => $pursuit->PursuitID, 'name' => $pursuit->Name));
							}
						}
						else
						{
							$formDefaults['pursuit'] = $this->payload->activityTypeChoosenID;
							$selectPursuitDefaults['pursuit'] = $this->payload->activityTypeChoosenID;
							foreach($this->payload->activityTypeChoosenID as $id)
							{
								$pursuit = $this->context->pursuitRepository->find($id);
								array_push($this->template->linkToPursuits, array('ID' => $pursuit->PursuitID, 'name' => $pursuit->Name));
							}
						}
					}
				}
				break;
			//need to pursue
			case $activity::ITEM_ACTIVITY_TYPE_NEED_TO_PURSUE :
				$formDefaults['probabilityOfWin'] = 0;
				$form['probabilityOfWin']->setDisabled(true);
				break;
			default :
				;
		}
		$form->setDefaults($formDefaults);
		// prepare template values
		$this->template->form = $form;
		$this->template->type = $type;
		$this->template->activity = $activity;
		
		//prepare url for ajax action handle type change
        $url = str_replace('?', '?do=typeChangeCreateForm&', $this->link('Activity:createActivity'));
        $this->template->linkToSignal = $url;
		
		//prepare url for ajax action MaPM change
        $url2 = str_replace('?', '?do=MaPMChange&', $this->link('Activity:showActivity'));
        $this->template->linkMaPMChange = $url2;
		
		// set select pursuit form default values
		$selectPursuitForm->setDefaults($selectPursuitDefaults);
	}
	
    /**
     * Load values to second select at detail form
	 * @param int Item id
	 * @param int Activity id
     * @param string Activity type
     */
    public function handleTypeChangeDetailForm($itemID, $activityID, $type, $typeID, $formValues)
    {
		if(!is_array($typeID) && $typeID != '')
			$params = $typeID;
		if((ItemActivity::ITEM_ACTIVITY_TYPE_PURSUIT == $type) && ($typeID != ''))
		{
			$params = array();
			$params = json_decode($typeID);
		}
		$formParams = array();
		parse_str($formValues, $formParams);
		$this->payload->form = $formParams;
		$this->payload->itemID = $itemID;
		$this->payload->activityID = $activityID;
		$this->payload->activityType = $type;
		if(isset($params))
			$this->payload->activityTypeChoosenID = $params;
		$this->invalidateControl('activityType');
    }
	
    /**
     * Load values to second select at detail form
	 * @param int Item id
	 * @param int Activity id
     * @param string Activity type
     */
    public function handleMaPMChange($portfolioManager = null)
    {
		$this->payload->portfolioManager = $portfolioManager;
		$this->invalidateControl('MaPM');
    }
	
    /**
     * Load values to second select at create form
	 * @param int Item id
	 * @param int Activity id
     * @param string Activity type
     */
    public function handleTypeChangeCreateForm($item, $type, $typeID, $formValues)
    {
		if(!is_array($typeID) && $typeID != '')
			$params = $typeID;
		if((ItemActivity::ITEM_ACTIVITY_TYPE_PURSUIT == $type) && ($typeID != ''))
		{
			$params = array();
			$params = json_decode($typeID);
		}
		$formParams = array();
		parse_str($formValues, $formParams);
		$this->payload->form = $formParams;
		$this->payload->itemID = $item;
		$this->payload->activityType = $type;
		if(isset($params))
			$this->payload->activityTypeChoosenID = $params;
		$this->invalidateControl('activityTypeChange');
    }
	
    /**
     * Creates general STRAP Item Activity form.
     * 
     * @param string $name Name of the form.
     * @return AppForm Returns AppForm.
     */
    public function createComponentActivityForm($name)
    {
        $form = new AppForm($this, $name);

        $form->addHidden('id');
		$form->addHidden('itemID');
		
        $form->addText('name', 'Name', 46, 150)
				->addRule(FORM::FILLED, 'Name must be filled.');
        
		for($i = 0; $i <= 6; $i++)
			$TRLs[$i] = $i;
        $form->addSelect('targetTRL', 'Target TRL', $TRLs);
		
		$form->addText('TRLyear', 'Target TRL Year', null, 4)
				->addCondition(Form::FILLED)
					->addRule(FORM::PATTERN, 'Year must be four number integer.', '[0-9]{4}|[0]{1}');
		
		$form->addTextArea('remarks', 'Remarks', 35, 5);
		
		// finds all product lines
		$plItems = array();
		$productLines = $this->context->productLineRepository->findAll();
		foreach($productLines as $productLine)
			$plItems[$productLine->ProductName] = $productLine->ProductName;
        $form->addSelect('productLine', 'Product line', $plItems);
		
		// finds all tech roadmaps
		$trItems = array();
		$technologyRoadmaps = $this->context->technologyRoadmapDomainRepository->findAll();
		foreach($technologyRoadmaps as $technologyRoadmap)
			$trItems[$technologyRoadmap->Domain] = $technologyRoadmap->Domain;
        $form->addSelect('technologyRoadmapDomain', 'Technology road map', $trItems);
		
		// finds all marketing and project manager
		$MaPMItems = array();
		$MaPMs = $this->context->advisorRepository->findAllByType(Advisor::ADVISOR_MAPM_SUB_PORTFOLIO);
		foreach($MaPMs as $MaPM)
			$MaPMItems[$MaPM->ID] = $MaPM->Name;
        $form->addSelect('MaPM', 'M&PM Sub-Portfolio', $MaPMItems);
		
		// finds all rtc directors
		$RTCDirectorsItems = array();
		$RTCDirectors = $this->context->advisorRepository->findAllByType(Advisor::ADVISOR_RTC);
		foreach($RTCDirectors as $RTCDirector)
			$RTCDirectorsItems[$RTCDirector->ID] = $RTCDirector->Name;
        $form->addSelect('RTCDirector', 'RTC', $RTCDirectorsItems);
		
		// finds all portfolio managers
		$portfolioManagerItems = array();
		$portfolioManagers = $this->context->advisorRepository->findAllByType(Advisor::ADVISOR_MAPM_PORTFOLIO);
		foreach($portfolioManagers as $portfolioManager)
			$portfolioManagerItems[$portfolioManager->ID] = $portfolioManager->Name;
        $form->addSelect('portfolioManager', 'M&PM Portfolio', $portfolioManagerItems);
		
		$types = ItemActivity::getTypes();
		$form->addSelect('type', 'Covered by', $types)
				->addRule(FORM::FILLED, 'Covered by is mandatory.');

		// finds all projects
		$projectItems = array();
		$projects = $this->context->projectRepository->findAllProjects();
		foreach($projects as $project)
			$projectItems[$project->ID] = $project->Name;
        $form->addSelect('project', 'Project', $projectItems);
		
		// finds all pursuits
		$pursuitItems = array();
		$pursuits = $this->context->pursuitRepository->findAll();
		foreach($pursuits as $pursuit)
			$pursuitItems[$pursuit->PursuitID] = $pursuit->Name;
        $form->addMultiSelect('pursuit', 'Pursuit', $pursuitItems);
		
		$form->addText('projectAllocation', 'Project allocation (%)', 3, 3)
					->addRule(FORM::RANGE, 'Project allocation must be integer.', array(0, NULL))
					->addRule(FORM::PATTERN, 'Project allocation must be integer.', '[0-9]*');
				
		$form->addText('potentialCustomer', 'Potential customer', null, 255);
		
		$form->addText('probabilityOfWin', 'Probability of win (%)', 3, 3)
				->setDisabled(TRUE);
		
		$form->addText('costShare', 'Cost Share (%)', 3, 3)
				->addRule(FORM::INTEGER, 'Cost Share must be filled and must be integer.');
		
		$currentYear = Date('Y');
		for($year = Date('Y'); $year <= ($currentYear+10); $year++)
		{
			$form->addText($year . '_Labor', 'Labor', 10, 12)
					->setDefaultValue(0)
					->addRule(FORM::RANGE, 'Labor budget must be positive integer.', array(0, NULL))
					->addRule(FORM::PATTERN, 'Labor budget must be positive integer.', '[0-9]*');
			$form->addText($year . '_Travel', 'Travel', 10, 12)
					->setDefaultValue(0)
					->addRule(FORM::RANGE, 'Travel budget must be positive integer.', array(0, NULL))
					->addRule(FORM::PATTERN, 'Travel budget must be positive integer.', '[0-9]*');
			$form->addText($year . '_Material', 'Material', 10, 12)
					->setDefaultValue(0)
					->addRule(FORM::RANGE, 'Material budget must be positive integer.', array(0, NULL))
					->addRule(FORM::PATTERN, 'Material budget must be positive integer.', '[0-9]*');
			$form->addText($year . '_Subcontracting', 'Subcontracting', 10, 12)
					->setDefaultValue(0)
					->addRule(FORM::RANGE, 'Subcontracting budget must be positive integer.', array(0, NULL))
					->addRule(FORM::PATTERN, 'Subcontracting budget must be positive integer.', '[0-9]*');
			$form->addText($year . '_Total', 'Total', 10, 12)
					->setDefaultValue(0)
					->setAttribute('readonly', 'readonly');
		}
		
		$form->addButton('editPursuit', 'Edit') // only shows overlay window with another part of the form.
				->setAttribute('onclick', '$.fancybox({content: $("#editPursuit").html()});');
		
		$form->addButton('projectAllocated', 'Related activities') // only shows overlay window with another part of the form.
				->setAttribute('onclick', '$.fancybox({content: $("#projectAllocated").html()});');
		
		$licences = array();
		$all_licences = $this->context->ecLicenceRepository->findAll();
		foreach ($all_licences as $licence)
			$licences[$licence->ECLicenceID] = $licence->Name;
 	  	$form->addSelect('ECLicenceID', HPTForm::createLabel('Licence', 'Export control licence determines importance of given data. It usually depends on target customer.'), $licences)
				->setPrompt('')
			    ->setAttribute('style', 'width: 140px;');
		
        return $form;
	}
	
    /**
     * Creates detail STRAP Item Activity form.
     * 
     * @param string $name Name of the form.
     * @return AppForm Returns AppForm.
     */
    public function createComponentDetailActivityForm($name)
    {
        $form = $this->createComponentActivityForm($name);
		
		//Selec for strap item change
		$itemsArray = array();
		$items = $this->context->itemRepository->findAll();
		foreach($items as $item)
			if($item->Active == 1)
			{
				$itemsArray[$item->ID] = substr($item->Name, 0, 25);
				if(strlen($item->Name) > 25)
					$itemsArray[$item->ID] .= '...';
				$itemsArray[$item->ID] .= ' (' . $item->CustomID . ')';
			}

        $form->addSelect('item', 'Change STRAP Item', $itemsArray);
		
		// update button
        $form->addSubmit('update', 'Update')
                ->onClick[] = callback($this, 'activityFormSubmittedUpdate');

		//go back button
        $form->addSubmit('back', 'Back to item')
                ->setValidationScope(false)
                ->onClick[] = callback($this, 'backFromShowClicked');
		
		//discard button
        $form->addSubmit('discard', 'Discard changes')
                ->setValidationScope(false)
                ->onClick[] = callback($this, 'discardClicked');
		
		//discard button
        $form->addSubmit('delete', 'Delete')
                ->setValidationScope(false)
                ->onClick[] = callback($this, 'deleteClicked');
		
        return $form;
    }
	
    /**
     * Creates create STRAP Item Activity form.
     * 
     * @param string $name Name of the form.
     * @return AppForm Returns AppForm.
     */
    public function createComponentCreateActivityForm($name)
    {
        $form = $this->createComponentActivityForm($name);
		
		// save button
        $form->addSubmit('save', 'Save')
                ->onClick[] = callback($this, 'activityFormSubmittedSave');
		
		//go back button
        $form->addSubmit('back', 'Back to item')
                ->setValidationScope(false)
                ->onClick[] = callback($this, 'backFromCreateClicked');
		
        return $form;
    }
	
    /**
     * Go back button redirects back to :default.
     * 
     * @param SubmitButton $button Go back button.
     */
    public function backFromCreateClicked(SubmitButton $button)
    {
		if($this->getHttpRequest()->getQuery('item'))
		{
			$item_ID['itemID'] = $this->getHttpRequest()->getQuery('item');
		}
		else
		{
			$item_ID = $button->getForm()->getValues();
		}
        $this->redirect('Item:showItem' , $item_ID['itemID']);
    }
	
    /**
     * Go back button redirects back to :default.
     * 
     * @param SubmitButton $button Go back button.
     */
    public function backFromShowClicked(SubmitButton $button)
    {
		if($this->getHttpRequest()->getQuery('itemID'))
		{
			$item_ID['itemID'] = $this->getHttpRequest()->getQuery('item');
		}
		else
		{
			$item_ID = $button->getForm()->getValues();
		}
        $this->redirect('Item:showItem' , $item_ID['itemID']);
    }
	
    /**
     * Strap Item Form Submitted - Update.
     * 
     * @param SubmitButton $button 
     */
    public function activityFormSubmittedUpdate(SubmitButton $button)
    {
		$values = $button->getForm()->getValues();

		if($button->form->isValid())
		{
			// prepare and update strap item activity
			$activity = $this->context->itemActivityRepository->find($values['id']);
			//change of Item of activity, if changed
			if($activity->ItemID != (int)$values['item'])
			{
				$activity->ItemID = (int)$values['item'];
				$activity->CustomID = $this->context->itemActivityRepository->getNextCustomIDNumber($values['item']) + 1;
			}
			
			// Get parent item
			$item = $this->context->itemRepository->find($activity->ItemID);

			if($values['targetTRL'])
				$activity->TargetTRL = $values['targetTRL'];
			else
				$activity->TargetTRL = 0;
			if($values['TRLyear'])
				$activity->TargetTRLYear = $values['TRLyear'];
			else
				$activity->TargetTRLYear = 0;
			$activity->Name = $values['name'];
			$activity->Remarks = $values['remarks'];
			$activity->TechnologyRoadmapDomain = $values['technologyRoadmapDomain'];
			$activity->MarketingProductManager = $values['MaPM'];
			$activity->PortfolioManager = $values['portfolioManager'];
			$activity->ProductLine = $values['productLine'];
			$activity->RTCDirector = $values['RTCDirector'];
			// Activity inherits EC licence from parent item by default in case that licence is not filled.
			$activity->ECLicenceID = ($values['ECLicenceID']) ? $values['ECLicenceID'] : $item->ECLicenceID;
			// setting of dependent values
			switch($values['type'])
			{
				//project
				case $activity::ITEM_ACTIVITY_TYPE_PROJECT :
					$project = $this->context->projectRepository->find($values['project']);
					
					$activity->ProjectID = $values['project'];
					$activity->ProjectBudgetUsage = $values['projectAllocation']/100;
					$activity->CostShare = $values['costShare']/100;
					$activity->ECLicenceID = $project->ECLicenceID;
					break;
				//pursuit
				case $activity::ITEM_ACTIVITY_TYPE_PURSUIT :
					$pursuits = $values['pursuit'];
					$activity->PursuitID = 1;
					break;
				//need to pursue
				case $activity::ITEM_ACTIVITY_TYPE_NEED_TO_PURSUE :
					$activity->NeedToPursueID = 1;
					$activity->PotentialCustomer = $values['potentialCustomer'];
					$activity->CostShare = $values['costShare']/100;
					break;
				default :
					;
			}
			
			// saving activities
			switch($values['type'])
			{
				//project
				case $activity::ITEM_ACTIVITY_TYPE_PROJECT :
					$activity->PursuitID = null;
					$activity->NeedToPursueID = null;
					$activity->PotentialCustomer = null;
					if ($this->context->itemActivityRepository->update($activity))
					{
						$this->flashMessage("Updating Strap Item Activity was successful.", 'success');
					}
					else
					{
						$this->flashMessage("Updating Strap Item Activity failed.", 'error');
						$this->redirect('Item:showItem', $values['itemID']);
					}
					break;
				//pursuit
				case $activity::ITEM_ACTIVITY_TYPE_PURSUIT :
					$activity->ProjectID = null;
					$activity->NeedToPursueID = null;
					$activity->CostShare = null;
					$activity->ProjectBudgetUsage = 0;
					$activity->PotentialCustomer = null;
					if ($this->context->itemActivityRepository->update($activity))
					{
						$this->flashMessage("Updating Strap Item Activity was successful.", 'success');
					}
					else
					{
						$this->flashMessage("Updating Strap Item Activity failed.", 'error');
						$this->redirect('Item:showItem', $values['itemID']);
					}
					$alreadySavedPursuits = $this->context->pursuitRepository->findAllPursuitsByActivityID($activity->ID);
					foreach($pursuits as $pursuitID)
					{
						if(!array_key_exists($pursuitID, $alreadySavedPursuits))
							$this->context->itemActivityRepository->savePursuitLinkage($activity->ID, $pursuitID);
					}
					foreach($alreadySavedPursuits as $pursuitID => $pursuit)
					{
						if(!in_array($pursuitID, $pursuits))
							$this->context->itemActivityRepository->deletePursuitLinkage($activity->ID, $pursuitID);
					}
					break;
				//need to pursue
				case $activity::ITEM_ACTIVITY_TYPE_NEED_TO_PURSUE :
					$activity->ProjectID = null;
					$activity->PursuitID = null;
					$activity->ProjectBudgetUsage = 0;
					if ($this->context->itemActivityRepository->update($activity))
					{
						$this->flashMessage("Updating Strap Item Activity was successful.", 'success');
					}
					else
					{
						$this->flashMessage("Updating Strap Item Activity failed.", 'error');
						$this->redirect('Item:showItem', $values['itemID']);
					}
					break;
				default :
					;
			}
			
			// prepare and save strap item activity budget
			$currentYear = Date('Y');
			for($year = Date('Y'); $year <= ($currentYear+10); $year++)
			{
				//update already existing budget
				if($this->context->itemActivityYearlyBudgetRepository->find($values['id'], $year))
				{
					//update if budget has some values
					if(($values[$year . '_Labor'] + $values[$year . '_Subcontracting'] + $values[$year . '_Travel'] + $values[$year . '_Material']) > 0)
					{
						$activityBudget = new ItemActivityYearlyBudget();
						$activityBudget->ID = $activity->ID;
						$activityBudget->Year = $year;
						$activityBudget->LaborCosts = $values[$year . '_Labor'];
						$activityBudget->SubcontractingCosts = $values[$year . '_Subcontracting'];
						$activityBudget->TravelCosts = $values[$year . '_Travel'];
						$activityBudget->MaterialCosts = $values[$year . '_Material'];
						if ($this->context->itemActivityYearlyBudgetRepository->update($activityBudget))
						{
							$this->flashMessage("Updating Strap Item Activity Budget for year: " . $year . " was successful.", 'success');
						}
						else
						{
							$this->flashMessage("Updating Strap Item Activity Budget for year: " . $year . " failed.", 'error');
							$this->redirect('Item:showItem', $values['itemID']);
						}
					}
					//delete budget
					else
					{
						if ($this->context->itemActivityYearlyBudgetRepository->delete($values['id'], $year))
						{
							$this->flashMessage("Deleting Strap Item Activity Budget for year: " . $year . " was successful.", 'success');
						}
						else
						{
							$this->flashMessage("Deleting Strap Item Activity Budget for year: " . $year . " failed.", 'error');
							$this->redirect('Item:showItem', $values['itemID']);
						}
					}
				}
				//create completly new budget
				else
				{
					if(($values[$year . '_Labor'] + $values[$year . '_Subcontracting'] + $values[$year . '_Travel'] + $values[$year . '_Material']) > 0)
					{
						$activityBudget = new ItemActivityYearlyBudget();
						$activityBudget->ID = $activity->ID;
						$activityBudget->Year = $year;
						$activityBudget->LaborCosts = $values[$year . '_Labor'];
						$activityBudget->SubcontractingCosts = $values[$year . '_Subcontracting'];
						$activityBudget->TravelCosts = $values[$year . '_Travel'];
						$activityBudget->MaterialCosts = $values[$year . '_Material'];
						if ($this->context->itemActivityYearlyBudgetRepository->save($activityBudget))
						{
							$this->flashMessage("Saving Strap Item Activity Budget for year: " . $year . " was successful.", 'success');
						}
						else
						{
							$this->flashMessage("Saving Strap Item Activity Budget for year: " . $year . " failed.", 'error');
							$this->redirect('Item:showItem', $values['itemID']);
						}
					}
				}
			}
		}
		else
		{
			$this->flashMessage("Invalid form values.", 'error');
			$this->redirect('Activity:showActivity', $values['itemID'], $values['id']);
		}
		$this->redirect('Activity:showActivity', $values['itemID'], $values['id']);
    }
	
	/**
     * Strap Item Form Submitted - Create.
     * 
     * @param SubmitButton $button 
     */
    public function activityFormSubmittedSave(SubmitButton $button)
    {		
		$values = $button->getForm()->getValues();
		if($button->form->isValid())
		{
			// Get parent item
			$item = $this->context->itemRepository->find($values['itemID']);
			
			// prepare and save strap item activity
			$activity = new ItemActivity();
			$activity->ItemID = $values['itemID'];
			
			$activity->CustomID = $this->context->itemActivityRepository->getNextCustomIDNumber($values['itemID']) +1;
			if($values['targetTRL'])
				$activity->TargetTRL = $values['targetTRL'];
			else
				$activity->TargetTRL = 0;
			if($values['TRLyear'])
				$activity->TargetTRLYear = $values['TRLyear'];
			else
				$activity->TargetTRLYear = 0;
			$activity->Name = $values['name'];
			$activity->Remarks = $values['remarks'];
			$activity->TechnologyRoadmapDomain = $values['technologyRoadmapDomain'];
			$activity->MarketingProductManager = $values['MaPM'];
			$activity->PortfolioManager = $values['portfolioManager'];
			$activity->ProductLine = $values['productLine'];
			$activity->RTCDirector = $values['RTCDirector'];
			$activity->Created = new DateTime;
			$activity->Creator = $this->getUser()->getId();
			// Activity inherits EC licence from parent item by default in case that licence is not filled.
			$activity->ECLicenceID = ($values['ECLicenceID']) ? $values['ECLicenceID'] : $item->ECLicenceID;
			
			// setting of dependent values
			switch($values['type'])
			{
				//project
				case $activity::ITEM_ACTIVITY_TYPE_PROJECT :
					$project = $this->context->projectRepository->find($values['project']);
					
					$activity->ProjectID = $values['project'];
					$activity->ProjectBudgetUsage = $values['projectAllocation']/100;
					$activity->CostShare = $values['costShare']/100;
					$activity->ECLicenceID = $project->ECLicenceID;
					break;
				//pursuit
				case $activity::ITEM_ACTIVITY_TYPE_PURSUIT :
					$pursuits = $values['pursuit'];
					$activity->PursuitID = 1;
					break;
				//need to pursue
				case $activity::ITEM_ACTIVITY_TYPE_NEED_TO_PURSUE :
					$activity->NeedToPursueID = 1;
					$activity->PotentialCustomer = $values['potentialCustomer'];
					$activity->CostShare = $values['costShare']/100;
					break;
				default:
					break;
			}
			
			// saving activities
			if ($this->context->itemActivityRepository->save($activity))
			{				
				$this->flashMessage("Saving Strap Item Activity was successful.", 'success');
			}
			else
			{
				$this->flashMessage("Saving Strap Item Activity failed.", 'error');
				$this->redirect('Item:showItem', $values['itemID']);
			}
			
			// If type == Pursuit save linkage
			if ($values['type'] == ItemActivity::ITEM_ACTIVITY_TYPE_PURSUIT)
			{
				foreach($pursuits as $pursuitID)
				{
					$this->context->itemActivityRepository->savePursuitLinkage($activity->ID, $pursuitID);
				}
			}
			
			// prepare and save strap item activity budget
			$currentYear = Date('Y');
			for($year = Date('Y'); $year <= ($currentYear+10); $year++)
			{
				if(($values[$year . '_Labor'] + $values[$year . '_Subcontracting'] + $values[$year . '_Travel'] + $values[$year . '_Material']) > 0)
				{
					$activityBudget = new ItemActivityYearlyBudget();
					$activityBudget->ID = $activity->ID;
					$activityBudget->Year = $year;
					$activityBudget->LaborCosts = $values[$year . '_Labor'];
					$activityBudget->SubcontractingCosts = $values[$year . '_Subcontracting'];
					$activityBudget->TravelCosts = $values[$year . '_Travel'];
					$activityBudget->MaterialCosts = $values[$year . '_Material'];
					if ($this->context->itemActivityYearlyBudgetRepository->save($activityBudget))
					{
						$this->flashMessage("Saving Strap Item Activity Budget for year: " . $year . " was successful.", 'success');
					}
					else
					{
						$this->flashMessage("Saving Strap Item Activity Budget for year: " . $year . " failed.", 'error');
						$this->redirect('Item:showItem', $values['itemID']);
					}
				}
			}
		}
		else
		{
			$this->flashMessage("Invalid form values.", 'error');
			$this->redirect('Activity:showActivity', $values['itemID'], $activity->ID);
		}
		$this->redirect('Activity:showActivity', $values['itemID'], $activity->ID);
    }
	
    /**
     * Delete button makes activity inactive.
     * 
     * @param SubmitButton $button Go back button.
     */	
    public function deleteClicked(SubmitButton $button)
    {
		$values = $button->getForm()->getValues();
		$activity = $activity = $this->context->itemActivityRepository->Find($values['id']);
		$activity->Active = 0;
		if ($this->context->itemActivityRepository->update($activity))
		{
			$this->flashMessage("Strap Item Activity was deleted.", 'success');
			$this->redirect('Item:showItem', $values['itemID']);
		}
		else
		{
			$this->flashMessage("Deleting Strap Item Activity failed.", 'error');
			$this->redirect('Item:showItem', $values['itemID']);
		}
    }
	
    /**
     * Discard button redirects back to showactivity view.
     * 
     * @param SubmitButton $button Go back button.
     */	
    public function discardClicked(SubmitButton $button)
    {
        $this->flashMessage('Changes discarded.', 'info');
		$item_ID = $button->getForm()->getValues();
        $this->redirect('this', null, $item_ID['id']);
    }
	
	/**
	 * Creates Pursuit select form.
	 * @param string $name Name of component.
     * @return AppForm Returns AppForm.
	 */
	public function createComponentSelectPursuitForm($name)
	{
		$form = new AppForm($this, $name);
		
		$form->addHidden('itemID');
		
		$form->addHidden('activityID');
		
		// finds all pursuits
		$pursuitItems = array();
		$pursuits = $this->context->pursuitRepository->findAll();
		foreach($pursuits as $pursuit)
			$pursuitItems[$pursuit->PursuitID] = $pursuit->Name;
        $form->addMultiSelect('pursuit', 'Pursuit', $pursuitItems, 15);
		
		$form->addButton('cancel', 'Cancel')
		        ->setAttribute('onclick', '$.fancybox.close()')
				->setAttribute('class', 'rightFloat');
		
		$form->addButton('ok', 'OK')
				->setAttribute('onclick', 'pursuitChangeAction()');
		
		return $form;
	}
}
