<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2013 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package presenters
 */

/**
 * Presenter for administration of Programs and calls.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class ProgramCallPresenter extends SecuredPresenter
{
    /**
     * Nette default render method.
     */
    public function renderDefault($customer_ID = null, $program_ID = null)
    {
		$calls = array();
		//prepare url link to create new call view.
        $this->template->newCallLink = str_replace('?', '?programID=CallValue&', $this->link('ProgramCall:create'));
		
		if(isset($this->payload->customer))
		{
			$form = $this['programForm'];
			if($this->payload->customer)
			{
				// finds all programs by customer
				$programs = array();
				$prog = $this->context->customerProgramRepository->findByCustomer($this->payload->customer);
				foreach ($prog as $program)
						$programs[$program->ProgramID] = $program->Program;
				$form['program']->setItems($programs);
				$form['program']->setPrompt('- Choose -');
			}
			else
			{
				$form['program']->setPrompt('- Choose -');
			}
			//prepare url for ajax action program change
			$programURL = str_replace('?', '?do=ProgramChange&', $this->link('ProgramCall:default'));
			$this->template->programChangeLink = $programURL;
			return;
		}
		
		// Calls filtering by program
		if(isset($this->payload->program))
		{
			if($this->payload->program)
			{
				// finds all calls by program
				$prepareCalls = array();
				$prepareCalls = $this->context->customerProgramCallRepository->findByProgram($this->payload->program);
				foreach($prepareCalls as $call)
				{
					$calls[$call->CallID][$call->CallID . '_call'] = $call;
					$calls[$call->CallID][$call->CallID . '_responsible'] = $this->context->personRepository->find($call->Responsible)->getFullNameWithEID();
				}
				$program = $this->context->customerProgramRepository->find($this->payload->program);
				// set edit program form default values
				$editProgramDefaults = array();
				$editProgramDefaults['customer'] = $this->context->customerRepository->find($program->CustomerID)->Name;
				$editProgramDefaults['programID'] = $program->ProgramID;
				$editProgramDefaults['name'] = $program->Program;
				$editProgramDefaults['remarks'] = $program->Remarks;
				$editProgramForm = $this['editProgramForm'];
				$editProgramForm->setDefaults($editProgramDefaults);
			}
			else
			{
			}
			//prepare url for ajax action program change
			$programURL = str_replace('?', '?do=ProgramChange&', $this->link('ProgramCall:default'));
			$this->template->programChangeLink = $programURL;
			$this->template->calls = $calls;
			return;
		}
		
		//non ajax rendering
		if($customer_ID != null)
		{
			$custoFormDefaults = array();
			$custoFormDefaults['customer'] = $customer_ID;
			$customerForm = $this['customerForm'];
			$customerForm->setDefaults($custoFormDefaults);
			// finds all programs by customer
			$programs = array();
			$prog = $this->context->customerProgramRepository->findByCustomer($customer_ID);
			if($prog)
			{
				$programForm = $this['programForm'];
				foreach ($prog as $program)
						$programs[$program->ProgramID] = $program->Program;
				$programForm['program']->setItems($programs);
				$programForm['program']->setPrompt('- Choose -');
				if($program_ID != null)
				{
					$progFormDefaults = array();
					$progFormDefaults['program'] = $program_ID;
					$programForm->setDefaults($progFormDefaults);
					$programForm['edit']->setDisabled(false);
					$programForm['remove']->setDisabled(false);
					
					// finds all calls by program
					$prepareCalls = array();
					$prepareCalls = $this->context->customerProgramCallRepository->findByProgram($program_ID);
					foreach($prepareCalls as $call)
					{
						$calls[$call->CallID][$call->CallID . '_call'] = $call;
						$calls[$call->CallID][$call->CallID . '_responsible'] = $this->context->personRepository->find($call->Responsible)->getFullNameWithEID();
					}
					$program = $this->context->customerProgramRepository->find($program_ID);
					// set edit program form default values
					if($program)
					{
						$editProgramDefaults = array();
						$editProgramDefaults['customer'] = $this->context->customerRepository->find($program->CustomerID)->Name;
						$editProgramDefaults['programID'] = $program->ProgramID;
						$editProgramDefaults['name'] = $program->Program;
						$editProgramDefaults['remarks'] = $program->Remarks;
						$editProgramForm = $this['editProgramForm'];
						$editProgramForm->setDefaults($editProgramDefaults);
					}
				}
			}
		}
		elseif($program_ID != null)
		{
			$programForm = $this['programForm'];
			$progFormDefaults = array();
			$progFormDefaults['program'] = $program_ID;
			$programForm->setDefaults($progFormDefaults);
			$programForm['edit']->setDisabled(false);
			$programForm['remove']->setDisabled(false);
			
			// finds all calls by program
			$prepareCalls = array();
			$prepareCalls = $this->context->customerProgramCallRepository->findByProgram($program_ID);
			foreach($prepareCalls as $call)
			{
				$calls[$call->CallID][$call->CallID . '_call'] = $call;
				$calls[$call->CallID][$call->CallID . '_responsible'] = $this->context->personRepository->find($call->Responsible)->getFullNameWithEID();
			}
			$program = $this->context->customerProgramRepository->find($program_ID);
			
			// set edit program form default values
			$editProgramDefaults['customer'] = $this->context->customerRepository->find($program->CustomerID)->Name;
			$editProgramDefaults['programID'] = $program->ProgramID;
			$editProgramDefaults['name'] = $program->Program;
			$editProgramDefaults['remarks'] = $program->Remarks;
			$editProgramForm = $this['editProgramForm'];
			$editProgramForm->setDefaults($editProgramDefaults);
		}
		
		//prepare url for ajax action customer change
        $cutomerURL = str_replace('?', '?do=CustomerChange&', $this->link('ProgramCall:default'));
        $this->template->customerChangeLink = $cutomerURL;
		
		//prepare url for ajax action program change
        $programURL = str_replace('?', '?do=ProgramChange&', $this->link('ProgramCall:default'));
        $this->template->programChangeLink = $programURL;
		
		// get all program's calls
		$this->template->calls = $calls;
    }
	
	/**
     * Renders form for creating new Call.
	 * 
	 * @param type $program_ID ID of Program
	 */
	public function renderCreate($programID = null)
	{
		$program = $this->context->customerProgramRepository->find($programID);
		if(is_null($program))
		{
			$this->flashMessage("You need to select program before creating new call.", 'notice');
			$this->redirect('default');
		}
		$this->template->program = $program->Program;
		$this->template->customer = $this->context->customerRepository->find($program->CustomerID)->Name;
		
		$formDefault = array();
		$formDefault['programID'] = $programID;
		$form = $this['createCallForm'];
		$form->setDefaults($formDefault);
		
		$this->template->form = $form;
	}
	
	/**
     * Shows detail of Person.
	 * 
	 * @param type $call_ID ID of Call
	 */
	public function renderShowDetail($call_ID)
	{
		$call = $this->context->customerProgramCallRepository->find($call_ID);
		if(is_null($call))
		{
			$this->flashMessage("Selected Call doesnt exist.", 'notice');
			$this->redirect('default');
		}
		$program = $this->context->customerProgramRepository->find($call->programID);
		$this->template->program = $program->Program;
		$this->template->customer = $this->context->customerRepository->find($program->CustomerID)->Name;
		
		$formDefault = array();
		$formDefault['callID'] = $call->CallID;
		$formDefault['programID'] = $call->ProgramID;
		$formDefault['call'] = $call->Call;
		$formDefault['open'] = $call->OpeningDate;
		$formDefault['close'] = $call->ClosingDate;
		$formDefault['remarks'] = $call->Remarks;
		$formDefault['costShare'] = $call->CostShare*100;
		$formDefault['responsible'] = $call->Responsible;
		$formDefault['responsible_info'] = $this->context->personRepository->find($call->Responsible)->getFullName();
		$form = $this['detailCallForm'];
		$form->setDefaults($formDefault);
		
		$this->template->form = $form;
		
		//get all pursuits for call
		$pursuits = $this->context->pursuitRepository->findAllPursuitsByCallID($call->CallID);
		$pursuitsArray = array();
		foreach ($pursuits as $pursuit)
		{ 
			$item = array();
			$item['PursuitID'] = $pursuit->PursuitID;
			$item['Name'] = $pursuit->Name;
			$item['Status'] = $pursuit->StatusFullName;
			$item['PursuitManager'] = ($pursuit->PursuitManager) ? $this->context->personRepository->find($pursuit->PursuitManager)->ReversedShortName : '-';
			$item['PursuitManager_Full'] = ($pursuit->PursuitManager) ? $this->context->personRepository->find($pursuit->PursuitManager)->ReversedFullNameWithEID : '-';
			$item['PursuitPI'] = ($pursuit->PursuitPI) ? $this->context->personRepository->find($pursuit->PursuitPI)->ReversedShortName : '-';
			$item['PursuitPI_Full'] = ($pursuit->PursuitPI) ? $this->context->personRepository->find($pursuit->PursuitPI)->ReversedFullNameWithEID : '-';
			$item['Customer'] = ($pursuit->CustomerID) ? $this->context->customerRepository->find($pursuit->CustomerID)->Name : '-';
			    $pursuitPlan = $this->context->pursuitPlanRepository->find($pursuit->PursuitID, PursuitPlan::MILESTONE_PROPOSAL_SUBMISSION);
			$item['ProposalSubmissionDate'] = ($pursuitPlan->PlannedDate) ? $pursuitPlan->PlannedDate : '-';
			$item['ProbabilityOfWin'] = $pursuit->ProbabilityOfWinPercentage;
			
			// Find the nearest upcoming milestone. If Proposal Submission Date(last mandatory milestone) is over or no milestone left, the nearest risk/plan is found.
			$nearestDateArray = array();
			$nearestMilestone = $this->context->pursuitPlanRepository->findNearestByPursuitID($pursuit->PursuitID);
			if($nearestMilestone)
			{
				$date = new DateTime($nearestMilestone->PlannedDate);
				$nearestDateArray[$date->format('U')] = $nearestMilestone->Milestone . ' - ' . $nearestMilestone->PlannedDate;
			}
			
			$nearestRisk = $this->context->pursuitRiskRepository->findNearestByPursuitID($pursuit->PursuitID);
			if($nearestRisk)
			{
				$date = new DateTime($nearestRisk->Deadline);
				$nearestDateArray[$date->format('U')] = 'Risk - ' . $nearestRisk->Deadline;
			}
			
			$nearestAction = $this->context->pursuitActionRepository->findNearestByPursuitID($pursuit->PursuitID);
			if($nearestAction)
			{
				$date = new DateTime($nearestAction->Deadline);
				$nearestDateArray[$date->format('U')] = 'Action - ' . $nearestAction->Deadline;
			}
			if($nearestDateArray)
			{
				ksort($nearestDateArray);
				reset($nearestDateArray);
				$key = key($nearestDateArray);
				$item['NearestMilestone'] = $nearestDateArray[$key];
			}
			else
				$item['NearestMilestone'] = 'None';
			// find if there is missed milestone = milestone planned date which is over and no actual date exist
			// or
			// find if there is missed action/risk = action/risk deadline date which is over and status is not completed
			$item['MissedDates'] = '-';
			$missedDates = array();
			if($this->context->pursuitPlanRepository->existsMissedMilestone($pursuit->PursuitID) 
					|| $this->context->pursuitRiskRepository->existsMissedRisk($pursuit->PursuitID)
					|| $this->context->pursuitActionRepository->existsMissedAction($pursuit->PursuitID))
			{
				$missedPlans = $this->context->pursuitPlanRepository->findMissedByPursuitID($pursuit->PursuitID);
				$missedRisks = $this->context->pursuitRiskRepository->findMissedByPursuitID($pursuit->PursuitID);
				$missedActions = $this->context->pursuitActionRepository->findMissedByPursuitID($pursuit->PursuitID);
				foreach ($missedPlans as $value)
				{
					$missedDates[] = $value->Milestone . ' - ' . $value->PlannedDate;
				}
				foreach ($missedRisks as $value)
				{
					$missedDates[] = 'Risk - ' . $value->Deadline;
				}
				foreach ($missedActions as $value)
				{
					$missedDates[] = 'Action - ' . $value->Deadline;
				}
				$item['MissedDates'] = implode(', ', $missedDates);
				$item['missedMilestone'] = true;
			}
			else
				$item['missedMilestone'] = false;
			//Calculate total budget for each pursuit
			$activities = $this->context->itemActivityRepository->findAllActivitiesByPursuitID($pursuit->PursuitID);
			$totalBudget = 0;
			$totalBudgetFromCurrentYear = 0;
			foreach($activities as $activity)
			{
				$activityBudgets = $this->context->itemActivityYearlyBudgetRepository->findAllByID($activity->ID);
				foreach($activityBudgets as $budget)
				{
					$totalBudget += $budget->LaborCosts + $budget->SubcontractingCosts + $budget->TravelCosts + $budget->MaterialCosts;
					if($budget->Year >= Date('Y'))
					{
						$totalBudgetFromCurrentYear += $budget->LaborCosts + $budget->SubcontractingCosts + $budget->TravelCosts + $budget->MaterialCosts;
					}
				}
			}
			$item['TotalBudgetFromCurrentYear'] = $totalBudgetFromCurrentYear;
			$item['TotalBudget'] = $totalBudget;
			$pursuitsArray[] = $item;
		}
		$this->template->pursuits = $pursuitsArray;
	}
	
    /**
     * Load values to program select at program form
	 * @param int $customer Customer id
     */
    public function handleCustomerChange($customer = null)
    {
		$this->payload->customer = $customer;
		$this->invalidateControl('program');
    }
	
    /**
     * Load values to call select at call table
	 * @param int $program Program id
     */
    public function handleProgramChange($program = null)
    {
		$this->payload->program = $program;
		$this->invalidateControl('call');
    }
	
    /**
     * Creates customer form.
     * 
     * @param string $name Name of the form.
     * @return AppForm Returns AppForm.
     */
    public function createComponentCustomerForm($name)
    {
        $form = new AppForm($this, $name);
        
        $customers = array();
        $cust = $this->context->customerRepository->findAll();
        foreach ($cust as $customer)
				$customers[$customer->ID] = $customer->Name;
        $form->addSelect('customer', 'Customer:', $customers)
				->setPrompt('- Choose -');
    }
	
    /**
     * Creates program form.
     * 
     * @param string $name Name of the form.
     * @return AppForm Returns AppForm.
     */
    public function createComponentProgramForm($name)
    {
        $form = new AppForm($this, $name);
        
        $programs = array();
        $prog = $this->context->customerProgramRepository->findAll();
        foreach ($prog as $program)
				$programs[$program->ProgramID] = $program->Program;
        $form->addSelect('program', 'Program:', $programs)
				->setPrompt('- Choose -');
		
		$form->addButton('edit', 'Edit') // only shows overlay window with another part of the form.
				->setAttribute('onclick', '$.fancybox({content: $("#editProgram").html()});');
		
		$form->addSubmit('remove', 'Remove')
				->onClick[] = array($this, 'removeProgramFormSubmitted');
		
		$form->addButton('add', 'Add new program') // only shows overlay window with another part of the form.
				->setAttribute('onclick', '$.fancybox({content: $("#addProgram").html()});');
		
		$form['edit']->setDisabled(true);
		$form['remove']->setDisabled(true);
    }
	
    /**
     * Creates program edit form.
     * 
     * @param string $name Name of the form.
     * @return AppForm Returns AppForm.
     */
    public function createComponentEditProgramForm($name)
    {
        $form = new AppForm($this, $name);
		
		$form->addHidden('programID');
		
        $form->addText('customer', 'Customer')
				->setAttribute('readonly', 'readonly');
		
        $form->addText('name', 'Name: *', null, 200)
				->addRule(FORM::FILLED, 'Program name field is mandatory.');
		
		$form->addTextArea('remarks', 'Remarks:', 30, 5);
		
		$form->addButton('cancel', 'Cancel')
		        ->setAttribute('onclick', '$.fancybox.close()');
		
		$form->addSubmit('edit', 'Save')				
				->onClick[] = array($this, 'editProgramFormSubmitted');
    }
	
    /**
     * Creates program edit form.
     * 
     * @param string $name Name of the form.
     * @return AppForm Returns AppForm.
     */
    public function createComponentCreateProgramForm($name)
    {
        $form = new AppForm($this, $name);
		
        $customers = array();
        $cust = $this->context->customerRepository->findAll();
        foreach ($cust as $customer)
				$customers[$customer->ID] = $customer->Name;
        $form->addSelect('customer', 'Customer:', $customers)
				->addRule(FORM::FILLED, 'Custumer field is mandatory.')
				->setPrompt('- Choose -');
		
        $form->addText('name', 'Program name:', null, 200)
				->addRule(FORM::FILLED, 'Program name field is mandatory.');
		
		$form->addTextArea('remarks', 'Remarks:', 30, 5);
		
		$form->addButton('cancel', 'Cancel')
		        ->setAttribute('onclick', '$.fancybox.close()');
		
		$form->addSubmit('create', 'Save')				
				->onClick[] = array($this, 'createProgramFormSubmitted');
    }
	
	/**
	 * Processing of program form submitted by edit button.
	 * @param SubmitButton $button
	 */
	public function editProgramFormSubmitted(SubmitButton $button)
	{
		if ($button->form->isValid())
		{
			$entry = $button->form->getValues();
			$program = $this->context->customerProgramRepository->find($entry['programID']);
			$program->setProgram($entry['name']);
			$program->setRemarks($entry['remarks']);
			if ($this->context->customerProgramRepository->update($program))
			{
				$this->flashMessage('Program: "' . $program->Program . '" updated.', 'success');
				$this->redirect('this', $program->CustomerID, $program->ProgramID);
			}
			else
			{
				$this->flashMessage('Updating program failed.', 'error');
				$this->redirect('this', $program->CustomerID, $program->ProgramID);
			}
		}
		else
		{
			$this->flashMessage('Invalid form values.', 'error');
			$this->redirect('this', $program->CustomerID, $program->ProgramID);
		}
	}
	
	/**
	 * Processing of program form submitted by add new program button.
	 * @param SubmitButton $button
	 */
	public function createProgramFormSubmitted(SubmitButton $button)
	{
		if ($button->form->isValid())
		{
			$entry = $button->form->getValues();
			$program = new CustomerProgram();
			$program->setCustomerID($entry['customer']);
			$program->setProgram($entry['name']);
			$program->setRemarks($entry['remarks']);
			if ($this->context->customerProgramRepository->save($program))
			{
				$this->flashMessage('Program: "' . $program->Program . '" saved.', 'success');
				$this->redirect('this', $entry['customer'], $program->ProgramID);
			}
			else
			{
				$this->flashMessage('Saving program failed.', 'error');
				$this->redirect('this', $entry['customer']);
			}
		}
		else
		{
			$this->flashMessage('Invalid form values.', 'error');
			$this->redirect('this', $entry['customer']);
		}
	}
	
	/**
	 * Processing of program form submitted by remove button.
	 * @param SubmitButton $button
	 */
	public function removeProgramFormSubmitted(SubmitButton $button)
	{
		if ($button->form->isValid())
		{
			$entry = $button->form->getValues();
			$program = $this->context->customerProgramRepository->find($entry['program']);
			if ($this->context->customerProgramRepository->delete($entry['program']))
			{
				$this->flashMessage('Program deleted.', 'success');
				$this->redirect('this', $program->customerID);
			}
			else
			{
				$this->flashMessage('Program is assigned to project, pursuit or has call. Deleting failed.', 'error');
				$this->redirect('this', $program->customerID, $entry['program']);
			}
		}
		else
		{
			$this->flashMessage('Invalid form values.', 'error');
			$this->redirect('this', $program->customerID, $entry['program']);
		}
	}
	
    /**
     * Creates general Call form.
     * 
     * @param string $name Name of the form.
     * @return AppForm Returns AppForm.
     */
    public function createComponentCallForm($name)
	{
        $form = new AppForm($this, $name);
		
		$form->addHidden('programID');
		
		$form->addText('call', 'Call name', null, 200)
				->addRule(FORM::FILLED, 'Call name field must be fiiled.');
		
		$form->addTextArea('remarks', 'Remarks', 35, 5);
		
        $form->addText('open', 'Opening date')
			->addCondition(Form::FILLED, TRUE)
				->addRule(Form::PATTERN, '%value is not valid %label!', '2[0-9]{3}-(0[0-9]{1}|1[012]{1})-([012]{1}[0-9]|3[01]{1})');
		$form['open']->getControlPrototype()->addClass('datepicker');
		
        $form->addText('close', 'Closing date')
			->addCondition(Form::FILLED, TRUE)
				->addRule(Form::PATTERN, '%value is not valid %label!', '2[0-9]{3}-(0[0-9]{1}|1[012]{1})-([012]{1}[0-9]|3[01]{1})');
		$form['close']->getControlPrototype()->addClass('datepicker');
		
		$form->addText('costShare', 'Cost Share (%)', 3, 3)
			->addCondition(Form::FILLED)
				->addRule(FORM::RANGE, 'Costshare must be integer from 0 to 100.', array(0, 100));
		
        $form->addText('responsible', 'Responsible', 7)
			->addRule(FORM::FILLED, 'Responsible preson field must be fiiled.')
			->getControlPrototype()
				->addClass('autocomplete');
		$form->addText('responsible_info', 'responsible_info')
				->setAttribute('readonly', 'readonly');
		
		return $form;
	}
	
    /**
     * Creates form for showing Call's details based on createComponentCallForm.
     * 
     * @param string $name Name of the form.
     * @return AppForm Returns AppForm.
     */
    public function createComponentDetailCallForm($name)
    {
        $form = $this->createComponentCallForm($name);
		
		$form->addHidden('callID');
		
        $form->addSubmit('save', 'Save')
                ->onClick[] = callback($this, 'detailCallFormSubmittedUpdate');
		
        $form->addSubmit('delete', 'Delete')
                ->onClick[] = callback($this, 'detailCallFormSubmittedDelete');
		$form['delete']->setAttribute('onclick', '
			return confirm("Are you sure to delete the call?");
		');
		    
        $form->addSubmit('back', 'Go back')
                ->setValidationScope(FALSE)
                ->onClick[] = callback($this, 'backClicked');
        
        return $form;
    }
	
    /**
     * Creates form for creating Call based on createComponentCallForm.
     * 
     * @param string $name Name of the form.
     * @return AppForm Returns AppForm.
     */
    public function createComponentCreateCallForm($name)
    {
        $form = $this->createComponentCallForm($name);

        $form->addSubmit('save', 'Save')
                ->onClick[] = callback($this, 'createCallFormSubmittedSave');

        $form->addSubmit('back', 'Go back')
                ->setValidationScope(FALSE)
                ->onClick[] = callback($this, 'backClicked');

        return $form;
    }
	
	/**
	 * Processing of create call form submitted by save button.
	 * @param SubmitButton $button
	 */
	public function createCallFormSubmittedSave(SubmitButton $button)
	{
		if ($button->form->isValid())
		{
			$entry = $button->form->getValues();
			$call = new CustomerProgramCall();
			$call->setProgramID($entry['programID']);
			$call->setCall($entry['call']);
			$call->setRemarks($entry['remarks']);
			if($entry['open'] == '')
				$call->setOpeningDate(null);
			else
				$call->setOpeningDate($entry['open']);
			if($entry['close'] == '')
				$call->setClosingDate(null);
			else
				$call->setClosingDate($entry['close']);
			$call->setCostShare($entry['costShare']/100);
			$call->setResponsible($entry['responsible']);
			if ($this->context->customerProgramCallRepository->save($call))
			{
				$this->flashMessage('Program: "' . $call->Call . '" saved.', 'success');
				$this->redirect('showDetail', $call->CallID);
			}
			else
			{
				$this->flashMessage('Saving call failed.', 'error');
				$this->redirect('default', null, $entry['programID']);
			}
		}
		else
		{
			$this->flashMessage('Invalid form values.', 'error');
			$this->redirect('default', null, $entry['programID']);
		}
	}
	
	/**
	 * Processing of detail call form submitted by update button.
	 * @param SubmitButton $button
	 */
	public function detailCallFormSubmittedUpdate(SubmitButton $button)
	{
		if ($button->form->isValid())
		{
			$entry = $button->form->getValues();
			$call = $this->context->customerProgramCallRepository->find($entry['callID']);
			$call->setCall($entry['call']);
			$call->setRemarks($entry['remarks']);
			if($entry['open'] == '')
				$call->setOpeningDate(null);
			else
				$call->setOpeningDate($entry['open']);
			if($entry['close'] == '')
				$call->setClosingDate(null);
			else
				$call->setClosingDate($entry['close']);
			$call->setCostShare($entry['costShare']/100);
			$call->setResponsible($entry['responsible']);
			if ($this->context->customerProgramCallRepository->update($call))
			{
				$this->flashMessage('Program: "' . $call->Call . '" updated.', 'success');
				$this->redirect('showDetail', $call->CallID);
			}
			else
			{
				$this->flashMessage('Updating call failed.', 'error');
				$this->redirect('showDetail', $call->CallID);
			}
		}
		else
		{
			$this->flashMessage('Invalid form values.', 'error');
			$this->redirect('showDetail', $call->CallID);
		}
	}
	
	/**
	 * Processing of detail call form submitted by delete button.
	 * @param SubmitButton $button
	 */
	public function detailCallFormSubmittedDelete(SubmitButton $button)
	{
		if ($button->form->isValid())
		{
			$entry = $button->form->getValues();
			if ($this->context->customerProgramCallRepository->delete($entry['callID']))
			{
				$this->flashMessage('Call: "' . $entry['call'] . '" deleted.', 'success');
				$this->redirect('default', null, $entry['programID']);
			}
			else
			{
				$this->flashMessage('Call is assigned to project or pursuit. Deleting failed.', 'error');
				$this->redirect('showDetail', $entry['callID']);
			}
		}
		else
		{
			$this->flashMessage('Invalid form values.', 'error');
			$this->redirect('showDetail', $entry['callID']);
		}
	}
	
    /**
     * Go back button redirects back to :default.
     * 
     * @param SubmitButton $button Go back button.
     */
    public function backClicked(SubmitButton $button)
    {
		$entry = $button->getForm()->getValues();
		if(isset($entry['callID']))
		{
			$call = $this->context->customerProgramCallRepository->find($entry['callID']);
			$program = $this->context->customerProgramRepository->find($call->ProgramID);
			$customer = $this->context->customerRepository->find($program->CustomerID);
			$this->redirect('default', $customer->ID, $program->ProgramID);
		}
		elseif(isset($entry['programID']))
		{
			$program = $this->context->customerProgramRepository->find($entry['programID']);
			$customer = $this->context->customerRepository->find($program->CustomerID);
			$this->redirect('default', $customer->ID, $program->ProgramID);
		}
		else
		{
			$this->redirect('default');
		}
		
		
    }
	
	/**
	 * Helps to find responsible person
	 */
    public function handleAutoComplete()
    {
		$this->payload->autoComplete = array();

		$text = trim($_GET['q']);

		if ($text !== '')
		{
			$filter = new PersonFilter();
			$filter->setFirstname($text)->setSurname($text)->setID($text);
			$persons = $this->context->personRepository->getPersonsByOrFilter($filter);
			foreach ($persons as $person) 
			{
				$person_item = array($person->getReversedFullNameWithEID(), strtoupper(trim($person->ID)), $person->getReversedFullName());
				$this->payload->autoComplete[] = $person_item;
			}
		}

		$this->terminate();
	}
}