<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2012 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package presenters
 */

/**
 * Presenter for auto generation of STRAP Report.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class StrapReportAutoGenerationPresenter extends TokenAccessPresenter
{
	/* authentication token setup */
	const AUTH_TOKEN_NAME = 'token',
		  AUTH_TOKEN_KEY = 'STRAPReport.credentials.cronToken';
	
    /**
     * Returns http parameter name with authentication token.
     * 
     * @return string
     */
	protected function getAuthTokenName()
	{
		return self::AUTH_TOKEN_NAME;
	}

    /**
     * Returns http parameter name with authentication token.
	 * 
     * @return string
     */
	protected function getAuthTokenSettingsKey()
	{
		return self::AUTH_TOKEN_KEY;
	}
	
    /**
     * Nette default render method 
     */
	public function renderDefault()
	{
	}
    
	/**
     * Generate method 
     */
    public function renderGenerateReport()
    {
		$multilog = new MultiLogger();
		$batch_id = 'STRAP-'.time().'-'. rand(1, 9);
		$multilog->add($this->context->createLogger($batch_id, "STRAP auto generation"));
		$STRAPReportService = new STRAPReportService($this->context, $multilog);
		$importResult = true;
		try
		{
			$STRAPReportService->generateReport();
		}
		catch (Exception $e)
		{
			$importResult = false;
			Debugger::log('STRAP auto generation failed: ' . $e->getMessage(), Debugger::ERROR);
			$multilog->log('STRAP auto generation failed: ' . $e->getMessage(), ILogger::ERROR);
		}
		$this->template->result = $importResult;
		if($importResult)
		{
			$multilog->log('STRAP auto generation completed.', ILogger::NOTICE);
		}
    }
}

