<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2015 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * ActualsForIASAP repository access class.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class ActualsForIASAPRepository extends Object
{
    /** @var IActualsForIASAPMapper */
    private $mapper;

    public function __construct(IActualsForIASAPMapper $mapper)
    {
        $this->mapper = $mapper;
    }	

    /**
     * Deletes records from actuals by range (year & fiscal month) INCLUSIVELY.
	 * Dates are "rounded" to months, so all data for all complete and partial
	 * months within date range are included. 
	 * 
	 * Example of deleted data:
	 * $startDate is "2nd Feb 2012" and $endDate is "20th Feb 2012" => data for Feb 2012 are deleted
	 * $startDate is "1nd Feb 2012" and $endDate is "30th November 2012" => data from Feb 2012 to Nov 2012 are deleted
	 * $startDate is "3rd Feb 2012" and $endDate is "30th November 2013" => data from Feb 2012 to Dec 2012 and data from Jan 2013 to Nov 2013 are deleted
	 * $startDate is "3rd Feb 2012" and $endDate is "3rd Feb 2012" => data for Feb 2012 are deleted
	 * 
	 * @param DateTime $startDate
     * @param DateTime $endDate
     */
    public function deleteByRange(DateTime $startDate, DateTime $endDate)
    {
        return $this->mapper->deleteByRange($startDate, $endDate);
    }
	
    /**
     * Saves new Actuals record.
     * 
     * @param ActualsForIASAP $actual
     * @return boolean Returns true if save successfull, otherwiste returns false.
     */
    public function save(ActualsForIASAP $actual)
    {
        return $this->mapper->save($actual);
    }
	
    /**
     * Returns number all actuals.
     * 
     * @param DateTime $startDate
     * @param DateTime $endDate
     * @return int Number of stored actuals.
     */
    public function countActualsByRangeAndType(DateTime $startDate, DateTime $endDate)
    {
        return $this->mapper->countActualsByRangeAndType($startDate, $endDate);
    }
}
