<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2015 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * ActualsTemp repository access class.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class ActualsTempRepository extends Object
{
    /** @var IActualsTempMapper */
    private $mapper;

    public function __construct(IActualsTempMapper $mapper)
    {
        $this->mapper = $mapper;
    }	

    /**
     * Gets all actuals.
     * 
	 * @param int $source Should be in range of ActualsTemp::SOURCE_*
     * @return array array of Actuals
     */
    public function findAll($source)
    {
        return $this->mapper->findAll($source);
    }
	
    /**
     * Returns number all actuals.
     * 
     * @param DateTime $startDate
     * @param DateTime $endDate
	 * @param int $source Should be in range of ActualsTemp::SOURCE_*
     * @return int Number of stored actuals.
     */
    public function countActualsByRangeAndType(DateTime $startDate, DateTime $endDate, $source)
    {
        return $this->mapper->countActualsByRangeAndType($startDate, $endDate, $source);
    }
	
	/**
     * Moves actuals record.
     * 
	 * @param int $source Should be in range of ActualsTemp::SOURCE_*
     * @return boolean Returns true if move successfull, otherwiste returns false.
     */
    public function moveAll($source)
    {
        return $this->mapper->moveAll($source);
    }
	
    /**
     * Deletes all actuals.
     * 
	 * @param int $source Should be in range of ActualsTemp::SOURCE_*
	 * @return boolean
     */
    public function deleteAll($source)
    {
        return $this->mapper->deleteAll($source);
    }
    
    /**
     * Saves new Actuals record.
     * 
     * @param Actuals $actual
     * @return boolean Returns true if save successfull, otherwiste returns false.
     */
    public function save(ActualsTemp $actual)
    {
        return $this->mapper->save($actual);
    }
	
    /**
     * Adds new Actuals record.
     * If Actuals record does not exist, new one is inserted.
     * If Actuals record exists, it is updated (hours are added).
     * 
     * @param Actuals $actual
     * @return boolean Returns true if adding successfull, otherwiste returns false.
     */
    public function add(ActualsTemp $actual)
    {
        return $this->mapper->add($actual);
    }
}
