<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2011 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Repository of customers.
 *
 * @author Jiri Zajic <jiri.zajic@honeywell.com>
 */
class CustomerRepository extends Object
{
	/** @var ICustomerMapper */
    private $mapper;
	
	/** @var MultiLogger */
	private $multilog;

    public function __construct(ICustomerMapper $mapper)
    {
        $this->mapper = $mapper;
		$this->multilog = new MultiLogger();
		$batch_id = 'Customer-'.time().'-'.rand(1, 9);
		$this->multilog->add(Environment::getContext()->createLogger($batch_id, "Customer"));
    }
    
    /**
     * Saves Customer.
     * 
     * @param Customer $customer
     * @return boolean Returns true if update successfull, otherwiste returns false.
     */
    public function save(Customer $customer)
    {
		if($this->mapper->save($customer))
		{
			$this->multilog->log('Customer with ID: ' . $customer->ID . ' saved.', ILogger::INFO);
			return true;
		}
		else
		{
			return false;
		}
    }
    
    /**
     * Updates Customer.
     * 
     * @param Customer $customer
     * @return boolean Returns true if update successfull, otherwiste returns false.
     */
    public function update(Customer $customer)
    {
		$oldObject = $this->find($customer->ID);
		if($this->mapper->update($customer))
		{
			$this->multilog->log('Customer with ID: ' . $customer->ID . ' updated. ' . $this->multilog->differences($oldObject, $customer), ILogger::INFO);
			return true;
		}
		else
		{
			return false;
		}
    }
	
	/**
	 * Returns customer.
	 * 
	 * @param string $id Customer ID.
	 * @return Customer or NULL if not found.
	 */
	public function find($id)
	{
		return $this->mapper->findCustomer($id);
	}

	/**
	 * Returns all customers as an array sorted by name.
	 * 
	 * @return array associative array of Customer as value and its ID as a key
	 */
	public function findAll()
	{
		return $this->mapper->findAllCustomers();
	}

}
