<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2014 Honeywell International spol. s r.o.
 *
 * For the full copyright and licence information, please view
 * the file licence.txt that was distributed with this source code.
 * @package models
 */

/**
 * ECLicence repository access class.
 *
 * @author Vojtech Obrusnik <vojtech.obrusnik@honeywell.com>
 */
class ECLicenceRepository
{
	/** @var IECLicenceMapper */
 	private $mapper;
	
	/** @var MultiLogger */
	private $multilog;
	
	public function __construct(IECLicenceMapper $mapper)
    {
        $this->mapper = $mapper;
		$this->multilog = new MultiLogger();
		$batch_id = 'ExportControl-'.time().'-'.rand(1, 9);
		$this->multilog->add(Environment::getContext()->createLogger($batch_id, "ExportControl"));
    }
	
	/**
	 * Saves ECLicence.
	 * @param ECLicence $licence
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function save(ECLicence $licence)
	{
		if ($this->mapper->save($licence))
		{
			$this->multilog->log('ECLicence with ID: ' . $licence->ECLicenceID . ' saved.', ILogger::INFO);
			return TRUE;
		}
		
		return FALSE;
	}
	
	/**
	 * Updates ECLicence.
	 * @param ECLicence $licence
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function update(ECLicence $licence)
	{
		$oldObject = $this->find($licence->ECLicenceID);
		if ($this->mapper->update($licence))
		{
			$this->multilog->log('ECLicence with ID: ' . $licence->ECLicenceID . ' updated. ' . $this->multilog->differences($oldObject, $licence), ILogger::INFO);
			return TRUE;
		}
		
		return FALSE;
	}
	
	/**
	 * Deletes ECLicence.
	 * @param int $id ECLicence id.
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function delete($id)
	{
		if ($this->mapper->delete($id))
		{
			$this->multilog->log('ECLicence with ID: ' . $id . ' deleted.', ILogger::INFO);
			return TRUE;
		}
		
		return FALSE;
	}
	
	/**
	 * Finds ECLicence by id.
	 * @param int $id ECLicence id.
	 * @return ECLicence or NULL if not found.
	 */
	public function find($id)
	{
		return $this->mapper->find($id);
	}
	
	/**
	 * Finds all ECLicences.
	 * @return array Array of ECLicence or empty array.
	 */
	public function findAll()
	{
		return $this->mapper->findAll();
	}
	
	/**
	 * Finds ECLicence by name.
	 * @param string $name
	 * @return ECLicence or NULL if not found.
	 */
	public function findByName($name)
	{
		return $this->mapper->findByName($name);
	}
	
	/**
	 * Finds ECLicence by ECLicenceNamePrefix.
	 * @param string $prefix
	 * @return ECLicence or NULL if not found.
	 */
	public function findByECLicenceNamePrefix($prefix)
	{
		return $this->mapper->findByECLicenceNamePrefix($prefix);
	}
	
	/**
	 * Finds max value of attribute Value.
	 * @return int Or NULL if error occured.
	 */
	public function findMaxValue()
	{
		return $this->mapper->findMaxValue();
	}
}