<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2015 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Interface for accessing actuals for IASAP.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
interface IActualsForIASAPMapper
{
	/**
     * Deletes records from actuals by range (year & fiscal month) INCLUSIVELY.
	 * Dates are "rounded" to month indexes, so all data for all complete and partial
	 * months within date range are included. 
	 * 
	 * Methods translates $startDate and $endDate to indexes/numbers of months
	 * from year 0 using formula:
	 * (Year - 1) * 12 + Month 
	 * or (for fiscal months indexed in range <0,11> as in database
	 * (Year - 1) * 12 + FiscalMonth + 1
	 * 
	 * Examples of translation of date:
	 * "1st Jan 1" => 1
	 * "2nd Jan 1" => 1
	 * "5th May 10" => 113
	 * "30th Dec 2012" => 24144
	 * "1st Jan 2013" => 24145
	 * 
	 * Example of deleted data:
	 * $startDate is "2nd Feb 2012" and $endDate is "20th Feb 2012" => data for Feb 2012 are deleted
	 * $startDate is "1nd Feb 2012" and $endDate is "30th November 2012" => data from Feb 2012 to Nov 2012 are deleted
	 * $startDate is "3rd Feb 2012" and $endDate is "30th November 2013" => data from Feb 2012 to Dec 2012 and data from Jan 2013 to Nov 2013 are deleted
	 * $startDate is "3rd Feb 2012" and $endDate is "3rd Feb 2012" => data for Feb 2012 are deleted
     * 
     * @param DateTime $startDate
     * @param DateTime $endDate
     */    
    public function deleteByRange(DateTime $startDate, DateTime $endDate);

    /**
     * Saves new Actuals record.
     * 
     * @param Actuals $actual
     * @return boolean Returns true if save successfull, otherwiste returns false.
     */
    public function save(ActualsForIASAP $actual);
}