<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2014 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Interface for accessing task assignment.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
interface IAssignmentsCostMapper
{
	/**
	 * Saves costs task assignment.
	 * 
	 * @param AssignmentsCost $assignment
	 * @return	boolean Returns TRUE if success, otherwise false.
	 */
	public function save(AssignmentsCost $assignment);
	
	/**
	 * Finds month assignment by id of assignment.
	 * 
	 * @param int $id task assignment ID.
	 * @return	AssignmentsCost 
	 */
	public function find($id);

	/**
	 * Deletes assignment for task in given year.
	 * 
	 * @param int $task_id Task ID.
	 * @param int $year Year.
	 * @return bool TRUE on success, FALSE otherwise.
	 */
	public function deleteByYear($task_id, $year);
	
	/**
	 * Returns array of arrays of twelve task assigments 
	 * that is assigned to given task ID in given year.
	 * 
	 * Each assignment (inner array) corresponds to a fiscal month in a year.
	 * Month indexes are 1 (January) - 12 (December). 
	 * If month assignment is missing only empty object is available on index.
	 * 
	 * @param int $task_id Task ID.
	 * @param int $year year.
	 * @return	array or 12 AssignmentsCost 
	 *					where keys are month indexes from 0 to 11.
	 */
	public function findTaskYearAssignments($task_id, $year);
}
