<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2014 Honeywell International spol. s r.o.
 *
 * For the full copyright and licence information, please view
 * the file licence.txt that was distributed with this source code.
 * @package models
 */

/**
 * Interface for accessing ECLicence.
 *
 * @author Vojtech Obrusnik <vojtech.obrusnik@honeywell.com>
 */
interface IECLicenceMapper
{
	/**
	 * Saves ECLicence.
	 * @param ECLicence $licence
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function save(ECLicence $licence);
		
	/**
	 * Updates ECLicence.
	 * @param ECLicence $licence
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function update(ECLicence $licence);
	
	/**
	 * Deletes ECLicence.
	 * @param int $id ECLicence id.
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function delete($id);
	
	/**
	 * Finds ECLicence by id.
	 * @param int $id ECLicence id.
	 * @return ECLicence or NULL if not found.
	 */
	public function find($id);
	
	/**
	 * Finds all ECLicences.
	 * @return array Array of ECLicence or empty array.
	 */
	public function findAll();
	
	/**
	 * Finds ECLicence by name.
	 * @param string $name
	 * @return ECLicence or NULL if not found.
	 */
	public function findByName($name);
	
	/**
	 * Finds ECLicence by ECLicenceNamePrefix.
	 * @param string $prefix
	 * @return ECLicence or NULL if not found.
	 */
	public function findByECLicenceNamePrefix($prefix);
	
	/**
	 * Finds max value of attribute Value.
	 * @return int Or NULL if error occured.
	 */
	public function findMaxValue();
}