<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2014 Honeywell International spol. s r.o.
 *
 * For the full copyright and licence information, please view
 * the file licence.txt that was distributed with this source code.
 * @package models
 */

/**
 * Interface for accessing Nationality.
 *
 * @author Vojtech Obrusnik <vojtech.obrusnik@honeywell.com>
 */
interface INationalityMapper
{
	/**
	 * Saves Nationality.
	 * @param Nationality $nationality
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function save(Nationality $nationality);
	
	/**
	 * Updates Nationality.
	 * @param Nationality $nationality
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function update(Nationality $nationality);
	
	/**
	 * Deletes Nationality.
	 * @param int $id Nationality id.
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function delete($id);
	
	/**
	 * Finds Nationality by id.
	 * @param int $id Nationality id.
	 * @return Nationality or NULL if not found.
	 */
	public function find($id);
	
	/**
	 * Finds all Nationalities.
	 * @return array Array of Nationality or empty array.
	 */
	public function findAll();
	
	/**
	 * Finds Nationality by name.
	 * @param string $name
	 * @return Nationality or NULL if not found.
	 */
	public function findByName($name);
}