<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2011 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Interface for accessing news.
 *
 * @author Martin Kotlar <martin.kotlar@honeywell.com>
 */
interface INewsMapper
{
	/**
	 * Saves new news.
	 * 
	 * @param News $news News.
	 */
	public function save(News $news);

	/**
	 * Returns cost center labour rate by cost center id and year.
	 * 
	 * @param string $id Cost center ID.
	 * @param int $year Year of whitch rates should be found.
	 * @return	News or NULL if not found.
	 */
	public function find($id);
	
	/**
	 * Returns news that are were published before $date
	 * and max $count of news.
	 * 
	 * @param int $date Unix timestamp of date and time.
	 * @param int $count How many news should be returned.
	 * @return	array of News
	 */
	public function findLatestNews($date, $count);

	/**
	 * Returns all news published in given time range.
	 * 
	 * @param int $date_from Unix timestamp of from date and time.
	 * @param int $date_to Unix timestamp of from date and time.
	 * @return	array of News
	 */
	public function findNewsInRange($date_from, $date_to);

	/**
	 * Returns sum of costs on current task in month in a year.
	 * 
	 * @param array $filter Attributes to filter.
	 * @param int $count Count of news.
	 * @param int $offset Skip this number of news.
	 * @return	array of News 
	 */
	public function findNewsByFilter($filter, $count, $offset = 0);
	
}

