<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2014 Honeywell International spol. s r.o.
 *
 * For the full copyright and licence information, please view
 * the file licence.txt that was distributed with this source code.
 * @package models
 */

/**
 * Interface for accessing Project - ECLicenceName relation.
 *
 * @author Vojtech Obrusnik <vojtech.obrusnik@honeywell.com>
 */
interface IPersonECLicenceMapper
{
	/**
	 * Saves Person - ECLicence relation
	 * @param PersonECLicence $relation
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function save(PersonECLicence $relation);
	
	/**
	 * Updates Person - ECLicence relation
	 * @param PersonECLicence $relation
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function update(PersonECLicence $relation);
	
	/**
	 * Deletes Person - ECLicence relation
	 * @param string $eid Person id.
	 * @param int $licence_id ECLicence id.
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function delete($eid, $licence_id);
	
	/**
	 * Deletes Person - ECLicence relations for given eid. 
	 * @param string $eid Person id.
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function deleteByEID($eid);
	
	/**
	 * Finds Person - ECLicence relation by project id and ECLicence id.
	 * @param string $eid Person id.
	 * @param int $licence_id ECLicence id.
	 * @return PersonECLicence or NULL if not found.
	 */
	public function find($eid, $licence_id);
	
	/**
	 * Finds all Person - ECLicence relations
	 * @return array Array of PersonECLicence or empty array.
	 */
	public function findAll();
	
	/**
	 * Finds all Person - ECLicence relations by person id
	 * @param string $eid Person id.
	 * @return array Array of PersonECLicence or empty array.
	 */
	public function findByEID($eid);
	
	/**
	 * Finds all Person - ECLicence relations by ECLicence id
	 * @param int $licence_id ECLicence id.
	 * @return array Array of PersonECLicence or empty array.
	 */
	public function findByECLicenceID($licence_id);
}