<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2014 Honeywell International spol. s r.o.
 *
 * For the full copyright and licence information, please view
 * the file licence.txt that was distributed with this source code.
 * @package models
 */

/**
 * Interface for accessing Project - ECLicenceName relation.
 *
 * @author Vojtech Obrusnik <vojtech.obrusnik@honeywell.com>
 */
interface IProjectECLicenceNameMapper
{
	/**
	 * Saves Project - ECLicenceName relation
	 * @param ProjectECLicenceName $relation
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function save(ProjectECLicenceName $relation);
	
	/**
	 * Updates Project - ECLicenceName relation
	 * @param ProjectECLicenceName $relation
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function update(ProjectECLicenceName $relation);
	
	/**
	 * Deletes Project - ECLicenceName relation
	 * @param int $project_id Project id.
	 * @param int $licence_name_id ECLicenceName id.
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function delete($project_id, $licence_name_id);
	
	/**
	 * Deletes Project - ECLicenceName relations for given project. 
	 * @param int $project_id Should be project id.
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function deleteByProjectID($project_id);
	
	/**
	 * Finds Project - ECLicenceName relation by project id and ECLicenceName id.
	 * @param int $project_id Project id.
	 * @param int $licence_name_id ECLicenceName id.
	 * @return ProjectECLicenceName or NULL if not found.
	 */
	public function find($project_id, $licence_name_id);
	
	/**
	 * Finds all Project - ECLicenceName relations
	 * @return array Array of ProjectECLicenceName or empty array.
	 */
	public function findAll();
	
	/**
	 * Finds all Project - ECLicenceName relations by project id
	 * @param int $project_id Project id.
	 * @return array Array of ProjectECLicenceName or empty array.
	 */
	public function findByProjectID($project_id);
	
	/**
	 * Finds all Project - ECLicenceName relations by ECLicenceName id
	 * @param int $licence_name_id ECLicenceName id.
	 * @return array Array of ProjectECLicenceName or empty array.
	 */
	public function findByECLicenceNameID($licence_name_id);
}