<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2012 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Interface for mapper accessing projects.
 *
 * @author Martin Kotlar <martin.kotlar@honeywell.com>
 */
interface IProjectMapper
{

	/**
	 * Saves new project.
	 * 
	 * @param Project $project
	 * @return boolean
	 */
	public function save(Project $project);

	/**
	 * Updates existing project.
	 * 
	 * Updates only attributes that are updatable.
	 * 
	 * @param Project $project
	 * @return boolean
	 */
	public function update(Project $project);
	
	/**
	 * Deletes existing project.
	 * 
	 * @param int $project_id
	 * @return boolean
	 */
	public function delete($project_id);

	/**
	 * Gets project by id.
	 * 
	 * @param int $project_id
	 * @return Project
	 */
	public function find($project_id);

	/**
	 * Gets project by SAP ID.
	 * 
	 * @param string $sap_id
	 * @return Project
	 */
	public function findBySAPID($sap_id);

	/**
	 * Gets all Projects.
	 * 
	 * @return array Array of Projects where Project_ID is key.
	 */
	public function findAll();

	/**
	 * Gets project by task id.
	 * 
	 * @param int $task_id
	 * @return Project
	 */
	public function findProjectByTaskId($task_id);
	
}


