<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2014 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Interface for accessing TaskPONumbers.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
interface ITaskPONumberMapper
{
	/**
	 * Saves TaskPONumber.
	 * @param TaskPONumber $poAttr
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function save(TaskPONumber $poAttr);
	
	/**
	 * Updates TaskPONumber.
	 * @param TaskPONumber $poAttr
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function update(TaskPONumber $poAttr);
	
	/**
	 * Deletes existing TaskPONumber.
	 * @param int $id TaskPONumber ID.
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function delete($id);
	
	/**
	 * Finds TaskPONumber by ID.
	 * @param int $id TaskPONumber ID.
	 * @return TaskPONumber or NULL if not found.
	 */
	public function find($id);
	
	/**
	 * Finds all TaskPONumbers.
	 * @return array Array of TaskPONumber or empty array.
	 */
	public function findAll();
	
	/**
	 * Finds all TaskPONumbers for task.
	 * @param int $id Task ID
	 * @return array Array of TaskPONumber or empty array.
	 */
	public function findByTaskID($id);
	
	/**
	 * Find TaskPONumber for task and year.
	 * @param int $id Task ID
	 * @param int $year Year
	 * @return TaskPONumber or NULL if not found.
	 */
	public function findByTaskIDandYear($id, $year);
	
	/**
	 * Find TaskPONumber by PO number.
	 * @param int $po_number
	 * @return TaskPONumber or NULL if not found.
	 */
	public function findByPONumber($po_number);
	
	/**
	 * Find TaskPONumber by year.
	 * @param int $year
	 * @return array Array of TaskPONumber or empty array.
	 */
	public function findByYear($year);
	
	/**
	 * Finds relations between TaskPONumber, Task and Project by given PO numbers.
	 * @param array $po_numbers List of PO numbers
	 * @param int $year Year
	 * @return array
	 *     $array[PONumber] = array(Year => val, TaskSAP_ID => val, ProjectSAP_ID => val)
	 *     or NULL if not found.
	 */
	public function findIASAPActualsImportRelationsByPONumbers(array $po_numbers, $year );
}