<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2012 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models\Import
 */

/**
 * Handler of ECharge password which uses AES (Rijndael) algorithm to encrypt/decrypt password.
 * 
 * Encrypts/decrypts ECharge password so it does not have to be stored
 * in plain text in database. However the key used for password encryption in
 * the plain text which gives anyone having access to the source code
 * the possibility to decrypt the password. This solution is not good
 * but better than storing plain text password in database 
 * which is accessible to more people.
 *
 * @author Martin Kotlar <martin.kotlar@honeywell.com>
 * @todo This class can be redesigned to use mcrypt library directly after we have it available.
 */
class EChargePasswordHandler extends Object
{
    const KEY = 'faddf4ad6f5aa9d8m99dQF7d5Dfff547s6ds6df13sd8799sdq621611fa6df8va3a5fg796jk4d56f7';
    
    /**
     * Decrypts echarge access password.
     * 
     * @param string $text Encrypted text.
     * @return string 
     */
    static function decrypt($text)
    {
        $aes = new Crypt_AES();
        $aes->setKey(EChargePasswordHandler::KEY);
        return $aes->decrypt(base64_decode($text));
    }
    
    /**
     * Encrypts echarge access password.
     * 
     * @param string $plaintext Plain text with password.
     * @return string Returns Base64 version of encrypted string.
     */
    static function encrypt($plaintext)
    {
        $aes = new Crypt_AES();
        $aes->setKey(EChargePasswordHandler::KEY);
        return base64_encode($aes->encrypt($plaintext));
    }
    
}
