<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2013 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * LDAP Personal info definition.
 *
 * @author Vojtech Obrusnik <vojtech.obrusnik@honeywell.com>
 */
class LDAPPersonalInfo extends Object
{
	/** @var string Person identification in Honeywell company */
	private $eid;
	/** @var string First name */
	private $name;
	/** @var string Surname */
	private $surname;
	/** @var string Email address */
	private $email;
	/** @var string Phone number */
	private $phoneNumber;
	/** @var string Employer name */
	private $employer;
	/** @var string Department number */
	private $departmentNumber;
	
	/**
     * Sets EID of person.
     * @param string $eid Should be person identification in Honeywell company.
     */
	public function setEID($eid)
	{
		$this->eid = Person::processEID($eid);
	}
	
	/**
     * Gets EID of person.
     * @return string
     */
	public function getEID()
	{
		return $this->eid;
	}
	
	/**
     * Sets first name.
     * @param string $name
     */
	public function setName($name)
	{
		$this->name = $name;
	}
	
	/**
     * Gets first name.
     * @return string
     */
	public function getName()
	{
		return $this->name;
	}
	
	/**
     * Sets surname.
     * @param string $surname
     */
	public function setSurname($surname)
	{
		$this->surname = $surname;
	}
	
	/**
     * Gets surname.
     * @return string
     */
	public function getSurname()
	{
		return $this->surname;
	}
	
	/**
     * Sets email.
     * @param string $email
     */
	public function setEmail($email)
	{
		$this->email = strtolower($email);
	}
	
	/**
     * Gets email.
     * @return string
     */
	public function getEmail()
	{
		return $this->email;
	}
	
	/**
     * Sets phone number.
     * @param string $number
     */
	public function setPhoneNumber($number)
	{
		$this->phoneNumber = $number;
	}
	
	/**
     * Gets phone number.
     * @return string
     */
	public function getPhoneNumber()
	{
		return $this->phoneNumber;
	}
	
	/**
     * Sets employer name.
     * @param string $name
     */
	public function setEmployer($name)
	{
		$this->employer = $name;
	}
	
	/**
     * Gets employer name.
     * @return string
     */
	public function getEmployer()
	{
		return $this->employer;
	}
	
	/**
     * Sets department number.
     * @param string $number
     */
	public function setDepartmentNumber($number)
	{
		$this->departmentNumber = $number;
	}
	
	/**
     * Gets department number.
     * @return string
     */
	public function getDepartmentNumber()
	{
		return $this->departmentNumber;
	}
	
	/**
	 * Gets full name if first name and surname are filled simultaneously.
	 * @return string Full name in format "surname, firstname" empty string otherwise.
	 */
	public function getFullName()
	{
		if ($this->name && $this->surname)
			return $this->surname . ', ' . $this->name;
        
		return '';
	}
}
