<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2014 Honeywell International spol. s r.o.
 *
 * For the full copyright and licence information, please view
 * the file licence.txt that was distributed with this source code.
 * @package models
 */

/**
 * Person - ECLicence relation repository access class.
 *
 * @author Vojtech Obrusnik <vojtech.obrusnik@honeywell.com>
 */
class PersonECLicenceRepository
{
	/** @var IPersonECLicenceMapper */
 	private $mapper;
	
	/** @var MultiLogger */
	private $multilog;
	
	public function __construct(IPersonECLicenceMapper $mapper)
    {
        $this->mapper = $mapper;
		$this->multilog = new MultiLogger();
		$batch_id = 'ExportControl-'.time().'-'.rand(1, 9);
		$this->multilog->add(Environment::getContext()->createLogger($batch_id, "ExportControl"));
    }
	
	/**
	 * Saves Person - ECLicence relation
	 * @param PersonECLicence $relation
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function save(PersonECLicence $relation)
	{
		if ($this->mapper->save($relation))
		{
			$this->multilog->log('PersonECLicence relation: ' . $relation->EID . '-' . $relation->ECLicenceID . ' saved.', ILogger::INFO);
			return TRUE;
		}
		
		return FALSE;
	}
    
    /**
	 * Saves PersonECLicence if not exists.
	 * @param PersonECLicence $relation
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function add(PersonECLicence $relation)
	{
		$old = $this->find($relation->EID, $relation->ECLicenceID);
		if (!$old)
		{
            return $this->save($relation);
		}
		
		return TRUE;
	}
	
	/**
	 * Updates Person - ECLicence relation
	 * @param PersonECLicence $relation
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function update(PersonECLicence $relation)
	{
		$oldObject = $this->find($relation->EID, $relation->ECLicenceID);
		if ($this->mapper->update($relation))
		{
			$this->multilog->log('PersonECLicence relation: ' . $relation->EID . '-' . $relation->ECLicenceID . ' updated. ' . $this->multilog->differences($oldObject, $relation), ILogger::INFO);
			return TRUE;
		}
		
		return FALSE;
	}
	
	/**
	 * Deletes Person - ECLicence relation
	 * @param string $eid Person id.
	 * @param int $licence_id ECLicence id.
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function delete($eid, $licence_id)
	{
		if ($this->mapper->delete($eid, $licence_id))
		{
			$this->multilog->log('PersonECLicence relation: ' . $eid . '-' . $licence_id . ' deleted.', ILogger::INFO);
			return TRUE;
		}
		
		return FALSE;
	}
	
	/**
	 * Deletes Person - ECLicence relations for given eid. 
	 * @param string $eid Person id.
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function deleteByEID($eid)
	{
		if ($this->mapper->deleteByEID($eid))
		{
			$this->multilog->log('PersonECLicence relations for project with ID = ' . $eid . ' deleted.', ILogger::INFO);
			return TRUE;
		}
		
		return FALSE;
	}
	
	/**
	 * Finds Person - ECLicence relation by project id and ECLicence id.
	 * @param string $eid Person id.
	 * @param int $licence_id ECLicence id.
	 * @return PersonECLicence or NULL if not found.
	 */
	public function find($eid, $licence_id)
	{
		return $this->mapper->find($eid, $licence_id);
	}
	
	/**
	 * Finds all Person - ECLicence relations
	 * @return array Array of PersonECLicence or empty array.
	 */
	public function findAll()
	{
		return $this->mapper->findAll();
	}
	
	/**
	 * Finds all Person - ECLicence relations by person id
	 * @param string $eid Person id.
	 * @return array Array of PersonECLicence or empty array.
	 */
	public function findByEID($eid)
	{
		return $this->mapper->findByEID($eid);
	}
	
	/**
	 * Finds all Person - ECLicence relations by ECLicence id
	 * @param int $licence_id ECLicence id.
	 * @return array Array of PersonECLicence or empty array.
	 */
	public function findByECLicenceID($licence_id)
	{
		return $this->mapper->findByECLicenceID($licence_id);
	}
}