<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2013 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Mapper for accessing project charter approver from database using dibi.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 * @author Vojtech Obrusnik <vojtech.obrusnik@honeywell.com>
 */
class ProjectCharterApproverDibiMapper extends DibiMapper implements IProjectCharterApproverMapper
{
    /**
     * Creates ProjectCharterApprover instance from DibiRow. 
     * @param DibiRow $row
     * @return	ProjectCharterApprover
     */
    private function load(DibiRow $row)
    {
        $projectCharterApprover = new ProjectCharterApprover();
        $projectCharterApprover->ProjectCharterApproverID = $row->ProjectCharterApprover_ID;
        $projectCharterApprover->ProjectCharterID = $row->ProjectCharter_ID;
        $projectCharterApprover->Version = $row->Version;
        $projectCharterApprover->Role = $row->Role;
		$projectCharterApprover->ApproverEID = $row->Approver_EID;
		$projectCharterApprover->Surname = $row->Surname;
		$projectCharterApprover->Name = $row->Name;
		$projectCharterApprover->Email = $row->Email;
        $projectCharterApprover->Approval = $row->Approval;
        $projectCharterApprover->DecisionDateTime = $row->DecisionDateTime;
        $projectCharterApprover->Comment = $row->Comment;
        $projectCharterApprover->AutoApproved = $row->AutoApproved;
        return $projectCharterApprover;
    }	

	/**
	 * Saves project charter approver.
	 * 
	 * @param ProjectCharterApprover $projectCharterApprover
	 * @return boolean
	 */
	public function save(ProjectCharterApprover $projectCharterApprover)
	{
		try
		{
			$array = array();
			$array['ProjectCharter_ID'] = $projectCharterApprover->getProjectCharterID();
			$array['Version'] = $projectCharterApprover->getVersion();
			$array['Role'] = $projectCharterApprover->getRole();
			$array['Approver_EID'] = $projectCharterApprover->getApproverEID();
			$array['Surname'] = $projectCharterApprover->getSurname();
			$array['Name'] = $projectCharterApprover->getName();
			$array['Email'] = $projectCharterApprover->getEmail();
			$array['Approval'] = $projectCharterApprover->getApproval();
			$array['DecisionDateTime'] = $projectCharterApprover->getDecisionDateTime();
			$array['Comment'] = $projectCharterApprover->getComment();
			$array['AutoApproved'] = $projectCharterApprover->getAutoApproved();
			$this->conn->insert('ProjectCharterApprover', $array)->execute();
			$projectCharterApprover->setProjectCharterApproverID($this->conn->insertId());
			return true;
		}
		catch (DibiException $e)
		{
			Debugger::log("Saving project charter approver with ProjectCharter_ID = " . $projectCharterApprover->getProjectCharterID() . " and version = " . $projectCharterApprover->getVersion() . " and Approver_EID = " . $projectCharterApprover->getApproverEID() . " failed. " . $e->getMessage(), Debugger::ERROR);
			return false;
		}
	}

	/**
	 * Updates project charter approver.
	 * 
	 * @param ProjectCharterApprover $projectCharterApprover
         * @return boolean
	 */
	public function update(ProjectCharterApprover $projectCharterApprover)
	{
		try
		{
			$array = array();
			$array['ProjectCharter_ID'] = $projectCharterApprover->getProjectCharterID();
			$array['Version'] = $projectCharterApprover->getVersion();
			$array['Role'] = $projectCharterApprover->getRole();
			$array['Approver_EID'] = $projectCharterApprover->getApproverEID();
			$array['Surname'] = $projectCharterApprover->getSurname();
			$array['Name'] = $projectCharterApprover->getName();
			$array['Email'] = $projectCharterApprover->getEmail();
			$array['Approval'] = $projectCharterApprover->getApproval();
			$array['DecisionDateTime'] = $projectCharterApprover->getDecisionDateTime();
			$array['Comment'] = $projectCharterApprover->getComment();
			$array['AutoApproved'] = $projectCharterApprover->getAutoApproved();
			$this->conn->update('ProjectCharterApprover', $array)->where('[ProjectCharterApprover_ID] = %i', $projectCharterApprover->getProjectCharterApproverID())->execute();
			return true;
		}
		catch (DibiException $e)
		{
			Debugger::log("Project charter approver update with projectCharterApprover_ID = " . $projectCharterApprover->getProjectCharterApproverID() . " failed. ".$e->getMessage());
			return false;
		}
	}
	
	/**
	 * Deletes existing project charter approver.
	 * 
	 * @param int $projectCharterApprover_id ProjectCharterApprover ID.
	 * @return boolean
	 */
	public function delete($projectCharterApprover_id)
	{
		try
		{
		    $result = $this->conn->delete('ProjectCharterApprover')->where('[ProjectCharterApprover_ID] = %i', $projectCharterApprover_id)->execute();
			if ($result)
				Debugger::log("Project charter approver with ProjectCharterApprover_ID = " . $projectCharterApprover_id . " was deleted.", Debugger::INFO);
			else
				Debugger::log("Deleting of project charter approver with ProjectCharterApprover_ID = " . $projectCharterApprover_id . " failed.", Debugger::ERROR);
			return $result;
		}
		catch (DibiException $e)
		{
			Debugger::log("Deleting of project charter approver with ProjectCharterApprover_ID = " . $projectCharterApprover_id . " failed: ".$e->getMessage(), Debugger::ERROR);
			return false;
		}
	}
    
	/**
	 * Finds project charter approver by  project charter id.
	 * 
	 * @param int $projectCharterApprover_id ProjectCharter ID.
	 * @return	ProjectCharterApprover or NULL if not found.
	 */
	public function find($projectCharterApprover_id)
	{
		$projectCharterApprover_db_result = $this->conn->select('*')->from('ProjectCharterApprover')->where('[ProjectCharterApprover_ID] = %i', $projectCharterApprover_id)->fetch();
		if ($projectCharterApprover_db_result !== FALSE)
			return $this->load($projectCharterApprover_db_result);
		else
			return NULL;
	}
    
	/**
	 * Finds all project charter approver by project charter id and version.
	 * 
	 * @param int $projectCharter_id ProjectCharter ID.
     * @param int $version Version of round of approval.
	 * @return	array Associative array of ProjectCharterApprover where key is approver eid or NULL if not found.
	 */
	public function findAllApprover($projectCharter_id, $version)
	{
		$projectCharterApprover_db_result = $this->conn->select('*')->from('ProjectCharterApprover')->where('[ProjectCharter_ID] = %i AND [Version] = %i', $projectCharter_id, $version)->fetchAll();
		$projectCharterApprover_array = array();
		if ($projectCharterApprover_db_result !== FALSE)
		{
			foreach ($projectCharterApprover_db_result as $projectCharterApprover)
				$projectCharterApprover_array[$projectCharterApprover->ProjectCharterApprover_ID] = $this->load($projectCharterApprover);
			return $projectCharterApprover_array;
		}
		else
			return null;
	}
    
	/**
	 * Finds all latest version project charter approver by approver eid.
	 * 
     * @param string $eid Approver EID.
	 * @return	array Associative array of ProjectCharterApprover where key is approver eid or NULL if not found.
	 */
	public function findAllProjectCharterByApprover($eid)
	{
		$projectCharterApprover_db_result = $this->conn->query('SELECT * FROM [ProjectCharterApprover]
                                                                    WHERE [Approver_EID] = %s AND [Version] = 
                                                                        (SELECT [Version] FROM [ProjectCharterApproverHistory] 
                                                                            WHERE [ProjectCharterApprover].[ProjectCharter_ID] = [ProjectCharterApproverHistory].[ProjectCharter_ID] 
                                                                                AND [LatestVersion] = 1)', $eid)->fetchAll();
                $projectCharterApprover_array = array();
                if ($projectCharterApprover_db_result !== FALSE)
                {
                    foreach ($projectCharterApprover_db_result as $projectCharterApprover)
                        $projectCharterApprover_array[$projectCharterApprover->ProjectCharterApprover_ID] = $this->load($projectCharterApprover);
                    return $projectCharterApprover_array;
                }
                else
                    return null;
	}
    
    /**
	 * Find out if project charter is approved by all approvers.
	 * Returns TRUE if there are no approvers defined for the charter.
	 * 
	 * @param int $projectCharter_id ProjectCharter ID.
     * @param int $version Version of round of approval.
	 * @return	boolean True if project charter is approved otherwise false.
	 */
	public function isApproved($projectCharter_id, $version)
	{
		$db_result = $this->conn->select('*')->from('ProjectCharterApprover')->where('[ProjectCharter_ID] = %i AND [Version] = %i AND ([Approval] = %i OR [Approval] = %i)', $projectCharter_id, $version, ProjectCharterApprover::DECISION_PENDING, ProjectCharterApprover::DECISION_DISAPPROVED)->fetch();
		if ($db_result !== FALSE)
			return false;
		else
			return true;
	}
    
    
	/**
	 * Finds project charter approver by approver EID.
	 * 
	 * @param int $projectCharter_id ProjectCharter ID.
     * @param int $version Version of round of approval.
	 * @param String $eid Approver EID.
	 * @return	ProjectCharterApprover or NULL if not found.
	 */
    public function findByApprover($projectCharter_id, $version, $eid)
	{
		$projectCharterApprover_db_result = $this->conn->select('*')->from('ProjectCharterApprover')->where('[ProjectCharter_ID] = %i AND [Version] = %i AND [Approver_EID] = %s', $projectCharter_id, $version, $eid)->fetchAll();
		$projectCharterApprover_array = array();
		if ($projectCharterApprover_db_result !== FALSE)
		{
			foreach ($projectCharterApprover_db_result as $projectCharterApprover)
			{
				$projectCharterApprover_array[$projectCharterApprover->ProjectCharterApprover_ID] = $this->load($projectCharterApprover);
			}
			return $projectCharterApprover_array;
		}
		else
			return NULL;
	}
	
	/**
	 * Finds project charter approver by role of approver.
	 * 
	 * @param int $projectCharter_id ProjectCharter ID.
     * @param int $version Version of round of approval.
	 * @param string $role Role of approver in company structure.
	 * @return	ProjectCharterApprover or NULL if not found.
	 */
    public function findByRole($projectCharter_id, $version, $role)
	{
		$projectCharterApprover_db_result = $this->conn->select('*')->from('ProjectCharterApprover')->where('[ProjectCharter_ID] = %i AND [Version] = %i AND [Role] = %s', $projectCharter_id, $version, $role)->fetchAll();
		$projectCharterApprover_array = array();
		if ($projectCharterApprover_db_result !== FALSE)
		{
			foreach ($projectCharterApprover_db_result as $projectCharterApprover)
				$projectCharterApprover_array[$projectCharterApprover->ProjectCharterApprover_ID] = $this->load($projectCharterApprover);
			return $projectCharterApprover_array;
		}
		else
			return null;
	}
}
