<?php

/**
 * This file is part of the HON Tool
 *
 * Copyright (c) 2009, 2016 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Project charter checklist definition.
 *
 * @author Leos Navratil <leos.navratil@honeywell.com>
 */
class ProjectCharterChecklist extends Object
{
	/** @const Definition of project charter checklist titles */
    const PROJECT_CHARTER_CHECKLIST_TITLE_HONEYWELL_AC = 'Honeywell AC',
		  PROJECT_CHARTER_CHECKLIST_TITLE_OTHER_AIRCRAFT = 'Other (external, customer) aircraft';
	
	/** @var int ID */
    private $id;
	/** @var int Related Project Charter's ID */
	private $projectCharterID;
	/** @var string Title of the question */
	private $title;
	/** @var array of Answers for charter's year, +1, +2, +3, .. - each of them could
	 * be either 'Yes' or 'No' (GUI), TRUE or FALSE in the app and DB.
	 * 
	 * Indexed from 1 to 5.
	 */
	private $neededArray;
	
	public function __construct()
	{
		$this->neededArray = array();
	}
	
   /**
     * Sets ID of project charter checklist.
     * @param int $id Must be positive integer.
     */
	public function setID($id)
	{
		if ($id > 0)
			$this->id = $id;
		else
			throw new InvalidArgumentException('Project charter checklist ID must be an integer greater than 0. Wrong param: ' . $id);
	}
	
    /**
     * Gets ID of project charter checklist.
     * @return int
     */
	public function getID()
	{
		return $this->id;
	}
	
   /**
     * Sets ID of project charter.
     * @param int $projectCharterID Must be positive integer.
     */
	public function setProjectCharterID($projectCharterID)
	{
		if ($projectCharterID > 0)
			$this->projectCharterID = $projectCharterID;
		else
			throw new InvalidArgumentException('Project charter ID must be an integer greater than 0. Wrong param: ' . $projectCharterID);
	}
	
    /**
     * Gets ID of project charter.
     * @return int
     */
	public function getProjectCharterID()
	{
		return $this->projectCharterID;
	}
	
	/**
	 * Sets the title of the question in checklist chart.
	 * @param string $title
	 */
	public function setTitle($title)
	{
		$this->title = $title;
	}
	
	/**
	 * Gets the title of the question in checklist chart.
	 * @return string
	 */
	public function getTitle()
	{
		return $this->title;
	}
	
	/**
	 * Sets the array containing TRUE or FALSE answers to some question with a title
	 * in checklist chart.
	 * @param array $neededArray
	 */
	public function setNeededArray($neededArray)
	{
		if (count($neededArray) !== 5)
			throw new InvalidArgumentException('Needed array must contain exactly 5 items. Wrong param count: ' . count($neededArray));

			$this->neededArray = $neededArray;
	}
	
	/**
	 * Sets the array containing TRUE or FALSE answers to a question with a title
	 * in the checklist chart.
	 * @return array
	 */
	public function getNeededArray()
	{
		return $this->neededArray;
	}
}