<?php

/**
 * This file is part of the HON Tool
 *
 * Copyright (c) 2009, 2016 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Mapper for accessing project charter checklist from database using dibi.
 *
 * @author Leos Navratil <leos.navratil@honeywell.com>
 */
class ProjectCharterChecklistDibiMapper extends DibiMapper implements IProjectCharterChecklistMapper
{
	/**
	 * Creates ProjectCharterChecklist instance from DibiRow.
	 * 
	 * @param DibiRow $row
	 * @return ProjectCharterChecklist
	 */
	private function load(DibiRow $row)
	{
		$projectCharterChecklist = new ProjectCharterChecklist();
		$projectCharterChecklist->ID = $row->ProjectCharterChecklist_ID;
		$projectCharterChecklist->ProjectCharterID = $row->ProjectCharter_ID;
		$projectCharterChecklist->Title = $row->Title;
		$neededArray = array();
			$neededArray[1] = $row->Needed1;
			$neededArray[2] = $row->Needed2;
			$neededArray[3] = $row->Needed3;
			$neededArray[4] = $row->Needed4;
			$neededArray[5] = $row->Needed5;
		$projectCharterChecklist->NeededArray = $neededArray;
		return $projectCharterChecklist;
	}
	
	/**
	 * Finds all checklist records related to certain Project Charter ID.
	 * 
	 * @param int $projectCharterID
	 * @return array of ProjectCharterChecklist objects.
	 */
	public function findByProjectCharterID($projectCharterID)
	{
		$checklist_db_result = $this->conn->select('*')->from('ProjectCharterChecklist')->where('[ProjectCharter_ID] = %i', $projectCharterID)->fetchAll();
		$checklist_array = array();
		if ($checklist_db_result !== FALSE)
		{
			foreach ($checklist_db_result as $checklist)
				$checklist_array[$checklist->Title] = $this->load($checklist);
			return $checklist_array;
		}
		else
			return null;
	}
	
	/**
	 * Saves a ProjectCharterChecklist object into the DB.
	 * 
	 * @param ProjectCharterChecklist $projectCharterChecklist
	 * @return bool True on successful insertion.
	 */
	public function save(ProjectCharterChecklist $projectCharterChecklist)
	{
		try
		{
			$array = array();
			$array['ProjectCharter_ID'] = $projectCharterChecklist->ProjectCharterID;
			$array['Title'] = $projectCharterChecklist->Title;
			$array['Needed1'] = $projectCharterChecklist->NeededArray[1];
			$array['Needed2'] = $projectCharterChecklist->NeededArray[2];
			$array['Needed3'] = $projectCharterChecklist->NeededArray[3];
			$array['Needed4'] = $projectCharterChecklist->NeededArray[4];
			$array['Needed5'] = $projectCharterChecklist->NeededArray[5];

			$charter_db_result = $this->conn->insert('ProjectCharterChecklist', $array)->execute();
						$projectCharterChecklist->setID($this->conn->insertId());
			return true;
		}
		catch (DibiException $e)
		{
			Debugger::log("Saving project charter checklist with ProjectCharter_ID = " . $projectCharterChecklist->ProjectCharterID . " failed. " . $e->getMessage(), Debugger::ERROR);
			return false;
		}
	}
	
	/**
	 * Updates a ProjectCharterChecklist object in the DB.
	 * 
	 * @param ProjectCharterChecklist $projectCharterChecklist
	 * @return bool True on successful update.
	 */
	public function update(ProjectCharterChecklist $projectCharterChecklist)
	{
		try
		{
			$array = array();
			$array['ProjectCharter_ID'] = $projectCharterChecklist->ProjectCharterID;
			$array['Title'] = $projectCharterChecklist->Title;
			$array['Needed1'] = $projectCharterChecklist->NeededArray[1];
			$array['Needed2'] = $projectCharterChecklist->NeededArray[2];
			$array['Needed3'] = $projectCharterChecklist->NeededArray[3];
			$array['Needed4'] = $projectCharterChecklist->NeededArray[4];
			$array['Needed5'] = $projectCharterChecklist->NeededArray[5];

			$charter_db_result = $this->conn->update('ProjectCharterChecklist', $array)->where('[ProjectCharterChecklist_ID] = %i', $projectCharterChecklist->ID)->execute();
			return true;
		}
		catch (DibiException $e)
		{
			Debugger::log("Saving project charter checklist with ProjectCharter_ID = " . $projectCharterChecklist->ProjectCharterID . " failed. " . $e->getMessage(), Debugger::ERROR);
			return false;
		}
	}
}