<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2013 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package presenters
 */

/**
 * ProjectCharterFilter defines structure to filter Project charters.
 *
 * @author Vojtech Obrusnik <vojtech.obrusnik@honeywell.com>
 */
class ProjectCharterFilter extends Object
{
    /** @var string Name of Project */
    private $name;
    /** @var string EID of Owner */
    private $owner;
    /** @var string SAP ID of Project*/
    private $sapID;
    /** @var string EID of Line manager */
    private $lineManager;
    /** @var array Statuses of project charter */
    private $status;
    /** @var int */
    private $customerID;
    /** @var int */
    private $programID;
    /** @var int */
    private $callID;
    /** @var int */
    private $responsibilityID;
	/** @var int|array */
	private $year;
    
    /**
     * Sets name.
     * 
     * @param string $name
     */
	public function setName($name)
	{
		$this->name = $name;
	}
        
    /**
     * Gets name.
     * 
     * @return string
     */
	public function getName()
	{
		return $this->name;
	}
    
    /**
     * Sets owner.
     * 
     * @param string $owner
     */
	public function setOwner($owner)
	{
		$this->owner = $owner;
	}
        
    /**
     * Gets owner.
     * 
     * @return string
     */
	public function getOwner()
	{
		return $this->owner;
	}
    
    /**
     * Sets sapID.
     * 
     * @param string $sapID
     */
	public function setSapID($sapID)
	{
		$this->sapID = $sapID;
	}
        
    /**
     * Gets sapID.
     * 
     * @return string
     */
	public function getSapID()
	{
		return $this->sapID;
	}
    
    /**
     * Sets lineManager.
     * 
     * @param string $lineManager
     */
	public function setLineManager($lineManager)
	{
		$this->lineManager = $lineManager;
	}
        
    /**
     * Gets lineManager.
     * 
     * @return string
     */
	public function getLineManager()
	{
		return $this->lineManager;
	}
    
    /**
     * Sets status.
     * 
     * @param string $status
     */
	public function setStatus($status)
	{
		$this->status = $status;
	}
        
    /**
     * Gets status.
     * 
     * @return string
     */
	public function getStatus()
	{
		return $this->status;
	}
    
    /**
     * Sets customerID.
     * 
     * @param int $customerID
     */
	public function setCustomerID($customerID)
	{
		$this->customerID = $customerID;
	}
        
    /**
     * Gets customerID.
     * 
     * @return int
     */
	public function getCustomerID()
	{
		return $this->customerID;
	}
	
	/**
     * Sets ID of program.
     * @param int $id Must be positive integer.
	 * @throws InvalidArgumentException
     */
	public function setProgramID($id)
	{
		if (($id > 0) || ($id === NULL))
			$this->programID = $id;
		else
			throw new InvalidArgumentException('Program ID must be integer greater than 0. Wrong param: ' . $id);
	}
	
    /**
     * Gets ID of program.
     * @return int
     */
	public function getProgramID()
	{
		return $this->programID;
	}
	
	/**
     * Sets ID of call.
     * @param int $id Must be positive integer.
	 * @throws InvalidArgumentException
     */
	public function setCallID($id)
	{
		if (($id > 0) || ($id === NULL))
			$this->callID = $id;
		else
			throw new InvalidArgumentException('Call ID must be integer greater than 0. Wrong param: ' . $id);
	}
	
    /**
     * Gets ID of call.
     * @return int
     */
	public function getCallID()
	{
		return $this->callID;
	}
    
    /**
     * Sets responsibilityID.
     * 
     * @param int $responsibilityID
     */
	public function setResponsibilityID($responsibilityID)
	{
		$this->responsibilityID = $responsibilityID;
	}
        
    /**
     * Gets responsibilityID.
     * 
     * @return int
     */
	public function getResponsibilityID()
	{
		return $this->responsibilityID;
	}
    
    /**
     * Sets year.
     * 
     * @param int|array $year
     */
	public function setYear($year)
	{
		if(is_array($year))
			$this->year = array($year);
		else
			$this->year = $year;
	}
        
    /**
     * Gets year.
     * 
     * @return int|array
     */
	public function getYear()
	{
		return $this->year;
	}
}
