<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2016 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * ProjectPlanningCharterItemBudget represents basic object for project planning charter item budget.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class ProjectPlanningCharterItemBudget extends Object
{
	/* possible ProjectPlanningCharterItemBudget types */
	const PROJECT_PLANNING_CHARTER_ITEM_BUDGET_TYPE_HRS = 'HRS';
	const PROJECT_PLANNING_CHARTER_ITEM_BUDGET_TYPE_USD = 'USD';
	
	/** @var int ProjectPlanningCharterItemBudget ID */
	private $id;
	
	/** @var int ProjectPlanningCharterItem ID */
	private $projectPlanningCharterItemID;
	
	/** @var int Must be number from 1 to 12 */
	private $month;
	
	/** @var int Must be non-negative integer */
	private $budget = 0;
	
	/** @var string BudgetType */
	private $budgetType;
	
	public function __construct()
	{
		
	}

	/**
	 * Sets ProjectPlanningCharterItemBudget ID.
	 * 
	 * @param int $id
	 */
	public function setID($id)
	{
		if (is_int($id + 0))
		{
			$this->id = $id;
		}
		else
		{
			throw new InvalidArgumentException('ID must be integer. Wrong param: ' . $id);
		}
	}

	/**
	 * Gets ProjectPlanningCharterItemBudget ID.
	 * 
	 * @return int
	 */
	public function getID()
	{
		return $this->id;
	}
	
	/**
	 * Sets ProjectPlanningCharterItemID.
	 * 
	 * @param int $projectPlanningCharterItemID
	 */
	public function setProjectPlanningCharterItemID($projectPlanningCharterItemID)
	{
		if (is_int($projectPlanningCharterItemID + 0))
		{
			$this->projectPlanningCharterItemID = $projectPlanningCharterItemID;
		}
		else
		{
			throw new InvalidArgumentException('ProjectPlanningCharterItemID must be integer. Wrong param: ' . $projectPlanningCharterItemID);
		}
	}

	/**
	 * Gets ProjectPlanningCharterItemID.
	 * 
	 * @return int
	 */
	public function getProjectPlanningCharterItemID()
	{
		return $this->projectPlanningCharterItemID;
	}
	
   /**
     * Sets month.
     * Must be number in range <1,12>.
     * 
     * @param int $month 
     */
	public function setMonth($month)
	{
		if (is_int($month + 0) && (($month >= 1) && ($month <= 12)))
			$this->month = $month;
		else
			throw new InvalidArgumentException('Month must be integer in range <1,12>. Wrong param: '.$month);
	}
	
    /**
     * Gets month.
     * 
     * @return int
     */
	public function getMonth()
	{
		return $this->month;
	}
	
   /**
     * Sets budget.
     * 
     * @param int $budget Must be positive integer.
     */
	public function setBudget($budget)
	{
		if (is_float($budget + 0.0) && ($budget >= 0.0))
			$this->budget = $budget;
		else
			throw new InvalidArgumentException('Budget must be integer greater or equal to 0. Wrong param: '.$budget);
	}
	
    /**
     * Gets budget.
     * 
     * @return int
     */
	public function getBudget()
	{
		return $this->budget;
	}
	
	/**
	 * Sets BudgetType.
	 * 
	 * @param string $budgetType
	 */
	public function setBudgetType($budgetType)
	{
		if (in_array($budgetType, array_keys(ProjectPlanningCharterItemBudget::getBudgetTypes())))
		{
			$this->budgetType = $budgetType;
		}
		else
		{
			throw new InvalidArgumentException('BudgetType must be enum. Wrong param: ' . $budgetType);
		}
	}

	/**
	 * Gets BudgetType.
	 * 
	 * @return string
	 */
	public function getBudgetType()
	{
		return $this->budgetType;
	}

	/**
	 * Returns array of available BudgetType.
	 * 
	 * @return array
	 */
	public static function getBudgetTypes()
	{
		return array(
			self::PROJECT_PLANNING_CHARTER_ITEM_BUDGET_TYPE_HRS => self::PROJECT_PLANNING_CHARTER_ITEM_BUDGET_TYPE_HRS,
			self::PROJECT_PLANNING_CHARTER_ITEM_BUDGET_TYPE_USD => self::PROJECT_PLANNING_CHARTER_ITEM_BUDGET_TYPE_USD
		);
	}
}
