<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2014 Honeywell International spol. s r.o.
 *
 * For the full copyright and licence information, please view
 * the file licence.txt that was distributed with this source code.
 * @package models
 */

/**
 * Project - ECLicenceName relation repository access class.
 *
 * @author Vojtech Obrusnik <vojtech.obrusnik@honeywell.com>
 */
class ProjectECLicenceNameRepository
{
	/** @var IProjectECLicenceNameMapper */
 	private $mapper;
	
	/** @var MultiLogger */
	private $multilog;
	
	public function __construct(IProjectECLicenceNameMapper $mapper)
    {
        $this->mapper = $mapper;
		$this->multilog = new MultiLogger();
		$batch_id = 'ExportControl-'.time().'-'.rand(1, 9);
		$this->multilog->add(Environment::getContext()->createLogger($batch_id, "ExportControl"));
    }
	
	/**
	 * Saves Project - ECLicenceName relation
	 * @param ProjectECLicenceName $relation
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function save(ProjectECLicenceName $relation)
	{
		if ($this->mapper->save($relation))
		{
			$this->multilog->log('ProjectECLicenceName relation: ' . $relation->ProjectID . '-' . $relation->ECLicenceNameID . ' saved.', ILogger::INFO);
			return TRUE;
		}
		
		return FALSE;
	}
	
	/**
	 * Updates Project - ECLicenceName relation
	 * @param ProjectECLicenceName $relation
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function update(ProjectECLicenceName $relation)
	{
		$oldObject = $this->find($relation->ProjectID, $relation->ECLicenceNameID);
		if ($this->mapper->update($relation))
		{
			$this->multilog->log('ProjectECLicenceName relation: ' . $relation->ProjectID . '-' . $relation->ECLicenceNameID . ' updated. ' . $this->multilog->differences($oldObject, $relation), ILogger::INFO);
			return TRUE;
		}
		
		return FALSE;
	}
	
	/**
	 * Deletes Project - ECLicenceName relation
	 * @param int $project_id Project id.
	 * @param int $licence_name_id ECLicenceName id.
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function delete($project_id, $licence_name_id)
	{
		if ($this->mapper->delete($project_id, $licence_name_id))
		{
			$this->multilog->log('ProjectECLicenceName relation: ' . $project_id . '-' . $licence_name_id . ' deleted.', ILogger::INFO);
			return TRUE;
		}
		
		return FALSE;
	}
	
	/**
	 * Deletes Project - ECLicenceName relations for given project. 
	 * @param int $project_id Should be project id.
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function deleteByProjectID($project_id)
	{
		if ($this->mapper->deleteByProjectID($project_id))
		{
			$this->multilog->log('ProjectECLicenceName relations for project with ID = ' . $project_id . ' deleted.', ILogger::INFO);
			return TRUE;
		}
		
		return FALSE;
	}
	
	/**
	 * Finds Project - ECLicenceName relation by project id and ECLicenceName id.
	 * @param int $project_id Project id.
	 * @param int $licence_name_id ECLicenceName id.
	 * @return ProjectECLicenceName or NULL if not found.
	 */
	public function find($project_id, $licence_name_id)
	{
		return $this->mapper->find($project_id, $licence_name_id);
	}
	
	/**
	 * Finds all Project - ECLicenceName relations
	 * @return array Array of ProjectECLicenceName or empty array.
	 */
	public function findAll()
	{
		return $this->mapper->findAll();
	}
	
	/**
	 * Finds all Project - ECLicenceName relations by project id
	 * @param int $project_id Project id.
	 * @return array Array of ProjectECLicenceName or empty array.
	 */
	public function findByProjectID($project_id)
	{
		return $this->mapper->findByProjectID($project_id);
	}
	
	/**
	 * Finds all Project - ECLicenceName relations by ECLicenceName id
	 * @param int $licence_name_id ECLicenceName id.
	 * @return array Array of ProjectECLicenceName or empty array.
	 */
	public function findByECLicenceNameID($licence_name_id)
	{
		return $this->mapper->findByECLicenceNameID($licence_name_id);
	}
}