<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2013 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package presenters
 */

/**
 * ProjectFilter defines structure to filter Projects.
 *
 * @author Vojtech Obrusnik <vojtech.obrusnik@honeywell.com>
 */
class ProjectFilter extends Object
{
	/** @var string Project name */
	private $name;
	/** @var string Project SAP ID */
	private $sapID;
	/** @var string */
	private $keyCode;
	/** @var float Minimal value of POValue */
	private $poValueMin;
	/** @var float Maximal value of POValue */
	private $poValueMax;
	/** @var string */
	private $poNumber;
	/** @var string Project start date */
	private $start;
	/** @var string Project end date */
	private $end;
	/** @var string Person EID */
	private $pipm;
	/** @var string Person EID */
	private $tm;
	/** @var string Person EID */
	private $pmoe;
	/** @var string Person EID */
	private $ppac;
	/** @var string PMO support level */
	private $pmo;
	/** @var int Customer ID */
	private $customer;
	/** @var int Program ID */
	private $program;
	/** @var int Call ID */
	private $call;
	/** @var int ID of responsible subject */
	private $responsibility;
	/** @var array Project type */
	private $type;
	/** @var array Project phase */
	private $phase;
	/** @var int Identifier of state */
	private $state;	
	/** @var int Fake if project is fake or not. */ 
	private $fake;
    /** @var array ResponsibleUnit */
    private $responsibleUnit;
	/** @var string Charge Number - Task SAP ID */
	private $chargeNumber;
	
	/**
     * Sets name
     * @param string $name
     */
	public function setName($name)
	{
		$this->name = $name;
	}
	
	/**
     * Gets name
     * @return string
     */
	public function getName()
	{
		return $this->name;
	}
	
	/**
     * Sets SAP ID
     * @param string $id
     */
	public function setSAPID($id)
	{
		$this->sapID = $id;
	}
	
	/**
     * Gets SAP ID
     * @return string
     */
	public function getSAPID()
	{
		return $this->sapID;
	}
	
	/**
     * Sets KeyCode
     * @param string $code
     */
	public function setKeyCode($code)
	{
		$this->keyCode = $code;
	}
	
	/**
     * Gets KeyCode
     * @return string
     */
	public function getKeyCode()
	{
		return $this->keyCode;
	}
	
	/**
     * Sets PO value
     * @param string $value
     */
	public function setPOValueMin($value)
	{
		$this->poValueMin = $value;
	}
	
	/**
     * Gets PO value
     * @return string
     */
	public function getPOValueMin()
	{
		return $this->poValueMin;
	}
	
	/**
     * Sets PO value
     * @param string $value
     */
	public function setPOValueMax($value)
	{
		$this->poValueMax = $value;
	}
	
	/**
     * Gets PO value
     * @return string
     */
	public function getPOValueMax()
	{
		return $this->poValueMax;
	}
	
	/**
     * Sets PO number
     * @param string $number
     */
	public function setPONumber($number)
	{
		$this->poNumber = $number;
	}
	
	/**
     * Gets PO number
     * @return string
     */
	public function getPONumber()
	{
		return $this->poNumber;
	}
	
	/**
     * Sets Start
     * @param string $date
     */
	public function setStart($date)
	{
		$this->start = $date;
	}
	
	/**
     * Gets Start
     * @return string
     */
	public function getStart()
	{
		return $this->start;
	}
	
	/**
     * Sets End
     * @param string $date
     */
	public function setEnd($date)
	{
		$this->end = $date;
	}
	
	/**
     * Gets End
     * @return string
     */
	public function getEnd()
	{
		return $this->end;
	}
	
	/**
     * Sets PIPM
     * @param string $eid
     */
	public function setPIPM($eid)
	{
		$this->pipm = $eid;
	}
	
	/**
     * Gets PIPM
     * @return string
     */
	public function getPIPM()
	{
		return $this->pipm;
	}
	
	/**
     * Sets TM
     * @param string $eid
     */
	public function setTM($eid)
	{
		$this->tm = $eid;
	}
	
	/**
     * Gets TM
     * @return string
     */
	public function getTM()
	{
		return $this->tm;
	}
	
	/**
     * Sets PMOE
     * @param string $eid
     */
	public function setPMOE($eid)
	{
		$this->pmoe = $eid;
	}
	
	/**
     * Gets PMOE
     * @return string
     */
	public function getPMOE()
	{
		return $this->pmoe;
	}
	
	/**
     * Sets PPaC
     * @param string $eid
     */
	public function setPPaC($eid)
	{
		$this->ppac = $eid;
	}
	
	/**
     * Gets PPaC
     * @return string
     */
	public function getPPaC()
	{
		return $this->ppac;
	}
	
	/**
     * Sets PMO
     * @param string $level
     */
	public function setPMO($level)
	{
		$this->pmo = $level;
	}
	
	/**
     * Gets PMO
     * @return string
     */
	public function getPMO()
	{
		return $this->pmo;
	}
	
	/**
     * Sets Customer
     * @param int $id
     */
	public function setCustomer($id)
	{
		$this->customer = $id;
	}
	
	/**
     * Gets Customer
     * @return int
     */
	public function getCustomer()
	{
		return $this->customer;
	}
	
	/**
     * Sets Program
     * @param int $id
     */
	public function setProgram($id)
	{
		$this->program = $id;
	}
	
	/**
     * Gets Program
     * @return int
     */
	public function getProgram()
	{
		return $this->program;
	}
	
	/**
     * Sets Call
     * @param int $id
     */
	public function setCall($id)
	{
		$this->call = $id;
	}
	
	/**
     * Gets Call
     * @return int
     */
	public function getCall()
	{
		return $this->call;
	}
	
	/**
     * Sets Responsibility
     * @param int $id
     */
	public function setResponsibility($id)
	{
		$this->responsibility = $id;
	}
	
	/**
     * Gets Responsibility
     * @return int
     */
	public function getResponsibility()
	{
		return $this->responsibility;
	}
	
	/**
     * Sets Type
     * @param array $type
     */
	public function setType($type)
	{
		$this->type = $type;
	}
	
	/**
     * Gets Type
     * @return array
     */
	public function getType()
	{
		return ($this->type) ? $this->type : array();
	}
	
	/**
     * Sets Phase
     * @param array $phase
     */
	public function setPhase($phase)
	{
		$this->phase = $phase;
	}
	
	/**
     * Gets Phase
     * @return array
     */
	public function getPhase()
	{
		return ($this->phase) ? $this->phase : array();
	}
	
	/**
     * Sets State
     * @param string $state
     */
	public function setState($state)
	{
		$this->state = $state;
	}
	
	/**
     * Gets State
     * @return string
     */
	public function getState()
	{
		return $this->state;
	}
	
	/** 
	* Sets fake flag. 
	* @param boolean $fake 
	*/ 
	public function setFake($fake) 
	{ 
		$this->fake = $fake; 
	} 

	/** 
	* Gets fake flag. 
	* @return boolean 
	*/ 
	public function getFake() 
	{ 
		return ($this->fake) ? $this->fake : array(); 
	} 
	
	/** 
	* Sets responsible unit. 
	* @param array $unit 
	*/ 
	public function setResponsibleUnit($unit) 
	{ 
		$this->responsibleUnit = $unit; 
	} 

	/** 
	* Gets responsible unit. 
	* @return array
	*/ 
	public function getResponsibleUnit() 
	{ 
		return ($this->responsibleUnit) ? $this->responsibleUnit : array();
	}

	/**
     * Sets ChargeNumber
     * @param string $chargeNumber
     */
	public function setChargeNumber($chargeNumber)
	{
		$this->chargeNumber = $chargeNumber;
	}
	
	/**
     * Gets ChargeNumber
     * @return string
     */
	public function getChargeNumber()
	{
		return $this->chargeNumber;
	}
}
