<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2016 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models\Import
 */

/**
 * Service for workPackage report.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class WorkPackageReportService extends ProjectEACReportService
{
	/** @var int Workpackeage ID */
	private $workPackageID;
	
	/** @var array WP to report */
	private $wpToReport = array();
	
	/**
	 * 
	 * @param int $workPackageID
	 * @param DIContainer $context
	 * @param ILogger $logger
	 * @param array $year
	 * @param int $uiFreezeToken
	 */
	public function __construct($workPackageID, DIContainer $context, ILogger $logger, $year, $uiFreezeToken = null)
	{
		parent::__construct($context, $logger, $year, "Work Package", $uiFreezeToken);
		$this->workPackageID = $workPackageID;
	}
	
	public function runWorkPackageReportGeneration()
	{
		$this->logger->log('WorkPackage Report generation start: ' . date('m-d-Y H:i:s'), ILogger::INFO);

		// Data preperation
		// get workPackage
		$worpackage = $this->context->workPackageRepository->find($this->workPackageID);
		$tasks = array();
		if ($worpackage == null)
		{
			throw new WorkPackageReportServiceException('WorkPackage with id: ' . $this->workPackageID . ' not found.');
		}
		
		$this->wpToReport[] = $worpackage;
		$this->findAllWPToReport($this->workPackageID);
		
		// get WorkPackages year or end report generation if there is no data
		$oneYearReport = false;
		if($this->year != null)
			$oneYearReport = true;
		foreach($this->wpToReport as $wp)
		{
			$tempTasks = array();
			if (!$oneYearReport)
			{
				if(is_null($this->year))
					$this->year = array();
				$this->year = array_unique(array_merge($this->year, $this->context->workPackageRepository->findWorkPackageYears($wp->ID)));
				$tempTasks = $this->context->taskRepository->findAllWorkPackageTasks($wp->ID);
				$tasks = array_merge($tasks, $tempTasks);
			}
			else
			{
				$allTasks = $this->context->taskRepository->findAllWorkPackageTasks($wp->ID);
				//check every task if he has some data to report. 
				foreach($allTasks as $task)
				{
					//has some plan
					if($this->context->taskPlanRepository->findTaskYearPlan($task->ID, $this->year[0]))
					{
						$tasks[$task->ID] = $task;
						continue;
					}
					//has some actuals
					if($task->isLabourTask())
					{
						if($this->context->workRepository->findPeopleWorkingOnTaskInYear($task->ID, $this->year[0]))
						{
							$tasks[$task->ID] = $task;
						}
					}
					else
					{
						if($this->context->costCenterRepository->findActualCostsYearSummary($task->ID, $this->year[0], 'USD')->sum() != 0)
						{
							$tasks[$task->ID] = $task;
						}
					}
				}
			}
		}
		if(empty($tasks))
		{
			throw new WorkPackageReportServiceException("There is no data to report.");
		}
		$this->runProjectEACReportGeneration($tasks, $oneYearReport, $worpackage->Name, $worpackage->SAPID);
	}
	
	/**
	 * Recursive function gets all wp to report
	 * 
	 * @param int $workPackageID
	 */
	private function findAllWPToReport($workPackageID)
	{
		$wpChildren = $this->context->workPackageRepository->findByParentID($workPackageID);
		$this->wpToReport = array_merge($this->wpToReport, $wpChildren);
		foreach ($wpChildren as $wp)
		{
			$this->findAllWPToReport($wp->ID);
		}
	}
}

class WorkPackageReportServiceException extends Exception
{
	
}
