<?php

/**
 * This file is part of the ATE Tool - STRAP addon
 *
 * Copyright (c) 2009, 2013 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Repository of STRAP Advisor.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class AdvisorRepository extends Object
{
	/** @var IAdvisorMapper */
    private $mapper;

	/** @var MultiLogger */
	private $multilog;
	
    public function __construct(IAdvisorMapper $mapper)
    {
        $this->mapper = $mapper;
		$this->multilog = new MultiLogger();
		$batch_id = 'Advisor-'.time().'-'.rand(1, 9);
		$this->multilog->add(Environment::getContext()->createLogger($batch_id, "STRAP Advisor"));
    }
    
	/**
	 * Saves new STRAP Advisor.
	 * 
	 * @param Advisor $advisor
	 * @return boolean
	 */
	public function save(Advisor $advisor)
	{
		if($this->mapper->save($advisor))
		{
			$this->multilog->log('Strap Advisor with ID: ' . $advisor->ID . ' saved.', ILogger::INFO);
			return true;
		}
		else
		{
			return false;
		}
	}
	
	/**
	 * Updates existing STRAP Advisor.
	 * 
	 * @param Advisor $advisor
	 * @return boolean
	 */
	public function update(Advisor $advisor)
	{
		$oldObject = $this->find($advisor->ID);
		if($this->mapper->update($advisor))
		{
			$this->multilog->log('Strap Advisor with ID: ' . $advisor->ID . ' updated. ' . $this->multilog->differences($oldObject, $advisor), ILogger::INFO);
			return true;
		}
		else
		{
			return false;
		}
	}
	
	/**
	 * Deletes existing STRAP Advisor.
	 * 
	 * @param string $id
	 * @return boolean
	 */
	public function delete($id)
	{
		if($this->mapper->delete($id))
		{
			$this->multilog->log('Strap Advisor with ID: ' . $id . ' deleted.', ILogger::INFO);
			return true;
		}
		else
		{
			return false;
		}
	}

	/**
	 * Gets STRAP Advisor by id.
	 * 
	 * @param int $item
	 * @return Item or null if not found
	 */
	public function find($id)
	{
		return $this->mapper->find($id);
	}
	
	/**
	 * Gets all STRAP Advisors by type.
	 * @param String $type
	 * 
	 * @return array Array of Advisor or null if not found.
	 */
	public function findAllByType($type)
	{
		return $this->mapper->findAllByType($type);
	}
	
    /**
	 * Finds all children nodes of advisor by id.
	 * 
	 * @param int $id advisor ID.
	 * @return	array of Advisor where id is key or NULL if not found.
	 */
	public function findAllChildren($id)
	{
		return $this->mapper->findAllChildren($id);
	}
}