<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2013 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Interface for accessing CustomerProgram.
 *
 * @author Vojtech Obrusnik <vojtech.obrusnik@honeywell.com>
 */
interface ICustomerProgramMapper
{
	/**
	 * Saves program.
	 * @param CustomerProgram $program
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function save(CustomerProgram $program);
    
	/**
	 * Updates program.
	 * @param CustomerProgram $program
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function update(CustomerProgram $program);
    
	/**
	 * Deletes program.
	 * @param int $id program ID.
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function delete($id);
	
	/**
	 * Finds program by ID.
	 * @param int $id program ID.
	 * @return	CustomerProgram or NULL if not found.
	 */
	public function find($id);
	
	/** 
	 * Finds all programs.
	 * @return array Array of CustomerProgram or empty array.	
	 */
	public function findAll();
	
	/** 
	 * Finds programs by customer ID.
	 * @param int $id customer ID.
	 * @return array Array of CustomerProgram or empty array.	
	 */
	public function findByCustomer($id);
}