<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2013 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Interface for accessing Pursuit.
 *
 * @author Vojtech Obrusnik <vojtech.obrusnik@honeywell.com>
 */
interface IPursuitMapper
{
	/**
	 * Saves pursuit.
	 * @param Pursuit $pursuit
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function save(Pursuit $pursuit);
    
	/**
	 * Updates pursuit.
	 * @param Pursuit $pursuit
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function update(Pursuit $pursuit);
    
	/**
	 * Deletes pursuit.
	 * @param int $id pursuit ID.
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function delete($id);
	
	/**
	 * Finds pursuit by ID.
	 * @param int $id pursuit ID.
	 * @return	Pursuit or NULL if not found.
	 */
	public function find($id);
	
	/**
	 * Finds all pursuits.
	 * @return array Array of Pursuit or empty array.
	 */
	public function findAll();
	
	/**
	 * Finds pursuits according to filter.
	 * @param PursuitFilter $filter
	 * @return array Array of Pursuit or empty array.
	 */
	public function findByFilter(PursuitFilter $filter);
}