<?php

/**
 * This file is part of the ATE Tool - STRAP addon
 *
 * Copyright (c) 2009, 2011 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Class for accessing STRAP NeedToPursue from database using dibi.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class NeedToPursueDibiMapper extends DibiMapper implements INeedToPursueMapper
{
	/**
	 * Creates NeedToPursue instance from DibiRow.
	 * 
	 * @param DibiRow $row
	 * @return	NeedToPursue 
	 */
    private function load(DibiRow $row)
    {
		$needToPursue = new NeedToPursue();
		$needToPursue->ID = $row->NeedToPursue_ID;
		$needToPursue->Name = $row->Name;
		$needToPursue->PotentialCustomer = $row->PotentialCustomer;
		return $needToPursue;
    }
	
	/**
	 * Saves new STRAP NeedToPursue.
	 * 
	 * @param NeedToPursue $needToPursue
	 * @return boolean
	 */
	public function save(NeedToPursue $needToPursue)
	{
        try
        {
            $array = array();
			$array['Name'] = $needToPursue->Name;
			$array['PotentialCustomer'] = $needToPursue->PotentialCustomer;
            $this->conn->insert('NeedToPursue', $array)->execute();
			return true;
        }
        catch (DibiException $e)
        {
            Debugger::log("Insert new STRAP NeedToPursue with name: " . $needToPursue->Name . " failed: " . $e->getMessage(), Debugger::ERROR);
            return false;
        }
	}
	
	/**
	 * Updates existing STRAP NeedToPursue.
	 * 
	 * @param NeedToPursue $needToPursue
	 * @return boolean
	 */
	public function update(NeedToPursue $needToPursue)
	{
        try
        {
            $array = array();
			$array['Name'] = $needToPursue->Name;
			$array['PotentialCustomer'] = $needToPursue->PotencialCustomer;
            $this->conn->update('NeedToPursue', $array)->where('[NeedToPursue_ID] = %i', $needToPursue->ID)->execute();
			return true;
        }
        catch (DibiException $e)
        {
            Debugger::log("Update of STRAP NeedToPursue with ID = " . $needToPursue->ID . " failed: " . $e->getMessage(), Debugger::ERROR);
            return false;
        }
	}
	
	/**
	 * Deletes existing STRAP Item.
	 * 
	 * @param int $needToPursue_id
	 * @return boolean
	 */
	public function delete($needToPursue_id)
	{
		try
		{
		    $result = $this->conn->delete('NeedToPursue')->where('[NeedToPursue_ID] = %i', $needToPursue_id)->execute();
			if ($result)
				Debugger::log("Strap NeedToPursue with ID = " . $needToPursue_id . " was deleted.", Debugger::INFO);
			else
				Debugger::log("Deleting of STRAP NeedToPursue with ID = " . $needToPursue_id . " failed.", Debugger::ERROR);
			return $result;
		}
        catch (DibiException $e)
        {
            Debugger::log("Deleting of STRAP NeedToPursue with ID = " . $needToPursue_id . " failed: ".$e->getMessage(), Debugger::ERROR);
            return false;
        }
	}

	/**
	 * Gets STRAP NeedToPursue by id.
	 * 
	 * @param int $needToPursue_id
	 * @return NeedToPursue or null if not found
	 */
	public function find($needToPursue_id)
	{
		$needToPursue_db_result = $this->conn->select('*')->from('NeedToPursue')->where('[NeedToPursue_ID] = %u', $needToPursue_id)->fetch();
		if ($needToPursue_db_result !== FALSE)
			return $this->load($needToPursue_db_result);
		else
			return NULL;
	}

	/**
	 * Gets all STRAP NeedToPursue.
	 * 
	 * @return array Array of NeedToPursue where NeedToPursue_ID is key or null if not found.
	 */
	public function findAll()
	{
        $needToPursue_array = array();
		$needToPursue_db_result = $this->conn->select('*')->from('NeedToPursue')->fetchAll();        
		if ($needToPursue_db_result !== FALSE)			
		{
			foreach ($needToPursue_db_result as $item)
				$needToPursue_array[$item->NeedToPursue_ID] = $this->load($item);
			return $needToPursue_array;
		}
		else
			return null;
	}
}
