<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2013 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * PursuitPlan object class.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class PursuitPlan extends Object
{
    /* possible pursuit plan milestones */
    const MILESTONE_PRESCREEN = 'Prescreen';
    const MILESTONE_PNP = 'PnP';
	const MILESTONE_BNB = 'BnB';
	const MILESTONE_PRICING = 'Pricing';
	const MILESTONE_MARKETING_STUDY = 'Marketing Study';
	const MILESTONE_GREEN_TEAM_REVIEW = 'GREEN Team Review';
	const MILESTONE_RED_TEAM_REVIEW = 'RED Team Review';
	const MILESTONE_PROPOSAL_SUBMISSION = 'Proposal Submission';
	
	/** @var int ID of pursuit */
	private $pursuitID;
	
	/** @var string Milestone of pursuit plan */
	private $milestone;
	
	/** @var datetime Planned date */
	private $plannedDate;
	
	/** @var datetime Actual date */
	private $actualDate;
	
	/** @var string Link adress to sharepoint */
	private $link;
	
	/** @var int $BnPPlan of pursuit plan */
	private $BnPPlan = 0;
	
	/** @var int $BnPActuals of pursuit plan */
	private $BnPActuals = 0;
	
	/** @var string Remarks of pursuit plan */
	private $remarks;
	
    public function  __construct() 
    {
    }
	
	/**
     * Sets ID of pursuit.
     * @param int $id Must be positive integer.
	 * @throws InvalidArgumentException
     */
	public function setPursuitID($id)
	{
		if ($id > 0)
			$this->pursuitID = $id;
		else
			throw new InvalidArgumentException('Pursuit ID must be integer greater than 0. Wrong param: ' . $id);
	}
	
    /**
     * Gets ID of pursuit.
     * @return int
     */
	public function getPursuitID()
	{
		return $this->pursuitID;
	}
	
	/**
     * Sets milestone of pursuit plan.
	 * @param string Milestone of pursuit plan.
	 * @throws InvalidArgumentException
     */
	public function setMilestone($milestone)
	{
	    if (in_array($milestone, self::getMilestones()))
			$this->milestone = $milestone;
		else
			throw new InvalidArgumentException('Pursuit plan milestone must be in set of pre defined milestones. Wrong param: ' . $status);
	}
    
    /**
     * Gets milestone of pursuit plan.
     * @return string
     */
	public function getMilestone()
	{
		return $this->milestone;
	}
	
	/**
	 * Sets Planned date.
	 * @param string $datetime
	 */
	public function setPlannedDate($datetime)
	{
		$this->plannedDate = $datetime;
	}
	
	/**
	 * Gets Planned date.
	 * @return string
	 */
	public function getPlannedDate()
	{
		return $this->plannedDate;
	}
	
	/**
	 * Sets actual date.
	 * @param string $datetime
	 */
	public function setActualDate($datetime)
	{
		$this->actualDate = $datetime;
	}
	
	/**
	 * Gets actual date.
	 * @return string
	 */
	public function getActualDate()
	{
		return $this->actualDate;
	}
	
	/**
     * Sets Link to pursuit plan sharepoint.
	 * @param string Link  to pursuit plan sharepoint.
     */
	public function setLink($link)
	{
	    $this->link = $link;
	}
    
    /**
     * Gets Link to pursuit plan sharepoint.
     * @return string
     */
	public function getLink()
	{
		return $this->link;
	}
	
    /**
     * Sets BnPPlan.
     * @param int $value Must be positive integer or NULL.
     */
    public function setBnPPlan($value)
    {
		if ($value === NULL)
			$this->BnPPlan = 0;
		else if (NumericUtils::isNonNegativeInteger($value))
			$this->BnPPlan = 0 + $value;
		else
			throw new InvalidArgumentException('Value must be integer number.');
    }
    
    /**
     * Gets BnPPlan.
     * @return int
     */
    public function getBnPPlan()
    {
        return $this->BnPPlan;
    }
	
    /**
     * Sets BnPActuals.
     * @param int $value Must be positive integer or NULL.
     */
    public function setBnPActuals($value)
    {
		if ($value === NULL)
			$this->BnPActuals = 0;
		else if (NumericUtils::isNonNegativeInteger($value))
			$this->BnPActuals = 0 + $value;
		else
			throw new InvalidArgumentException('Value must be integer number.');
    }
    
    /**
     * Gets BnPActuals.
     * @return int
     */
    public function getBnPActuals()
    {
        return $this->BnPActuals;
    }
	
    /** 
     * Sets remarks. 
     *  
     * @param string $remarks  
     */ 
    public function setRemarks($remarks) 
    { 
            $this->remarks = $remarks; 
    } 

    /** 
     * Gets remakrs. 
     *  
     * @return string 
     */ 
    public function getRemarks() 
    { 
            return $this->remarks; 
    } 
	
    /**
     * Returns array of available milestones.
     * 
     * @return array
     */
	public static function getMilestones()
	{
		return array(
			self::MILESTONE_PRESCREEN => self::MILESTONE_PRESCREEN,
			self::MILESTONE_PNP => self::MILESTONE_PNP,
			self::MILESTONE_BNB => self::MILESTONE_BNB,
			self::MILESTONE_PRICING => self::MILESTONE_PRICING,
			self::MILESTONE_MARKETING_STUDY => self::MILESTONE_MARKETING_STUDY,
			self::MILESTONE_GREEN_TEAM_REVIEW => self::MILESTONE_GREEN_TEAM_REVIEW,
			self::MILESTONE_RED_TEAM_REVIEW => self::MILESTONE_RED_TEAM_REVIEW,
			self::MILESTONE_PROPOSAL_SUBMISSION => self::MILESTONE_PROPOSAL_SUBMISSION
		);
	}
	
    /**
     * Returns array of available milestones as strings suitable for use in html attribute name of form items.
     * 
     * @return array Keys are original names of milestones and values are webalized names.
     */
	public static function getWebalizedMilestones()
	{
		$webalized = array();
		foreach (self::getMilestones() as $milestone)
		{
			$webalized[$milestone] = preg_replace('/ /', '', $milestone);
		}
		return $webalized;
	}
}
