<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2013 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * PursuitRisk object class.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class PursuitRisk extends Object
{
    /* possible pursuit risk statuses */
    const PURSUIT_RISK_STATUS_NOT_MITIGATE = 'Mitigate';
    const PURSUIT_RISK_STATUS_WATCH = 'Watch';
	const PURSUIT_RISK_STATUS_CLOSED = 'Closed';
	
	/** @var int ID of PursuitRisk */
	private $id;
	
	/** @var int ID of pursuit */
	private $pursuitID;
	
	/** @var string Name of pursuit risk */
	private $risk;
	
	/** @var string EID of pursuit risk owner */
	private $owner;
	
	/** @var datetime Deadline date */
	private $deadline;
	
	/** @var string Current status of pursuit risk */
	private $status;
	
	/** @var string Remarks of pursuit plan */
	private $remarks;
	
    public function  __construct() 
    {
    }
	
	/**
     * Sets ID of pursuit risk.
     * @param int $id Must be positive integer.
	 * @throws InvalidArgumentException
     */
	public function setID($id)
	{
		if ($id > 0)
			$this->id = $id;
		else
			throw new InvalidArgumentException('PursuitRisk ID must be integer greater than 0. Wrong param: ' . $id);
	}
	
    /**
     * Gets ID of pursuit risk.
     * @return int
     */
	public function getID()
	{
		return $this->id;
	}
	
	/**
     * Sets ID of pursuit.
     * @param int $id Must be positive integer.
	 * @throws InvalidArgumentException
     */
	public function setPursuitID($id)
	{
		if ($id > 0)
			$this->pursuitID = $id;
		else
			throw new InvalidArgumentException('Pursuit ID must be integer greater than 0. Wrong param: ' . $id);
	}
	
    /**
     * Gets ID of pursuit.
     * @return int
     */
	public function getPursuitID()
	{
		return $this->pursuitID;
	}
	
	/**
     * Sets name of pursuit risk.
	 * @param string Pursuit risk name.
     */
	public function setRisk($risk)
	{
	    $this->risk = $risk;
	}
    
    /**
     * Gets name of pursuit risk.
     * @return string
     */
	public function getRisk()
	{
		return $this->risk;
	}
	
	/**
	 * Sets pursuit risk owner.
	 * @param string $eid
	 */
	public function setOwner($eid)
	{
		$this->owner = Person::processEID($eid);
	}
	
	/**
	 * Gets pursuit risk owner.
	 * @return string
	 */
	public function getOwner()
	{
		return $this->owner;
	}
	
	/**
	 * Sets deadline date.
	 * @param string $datetime
	 */
	public function setDeadline($datetime)
	{
		$this->deadline = $datetime;
	}
	
	/**
	 * Gets deadline date.
	 * @return string
	 */
	public function getDeadline()
	{
		return $this->deadline;
	}
	
	/**
     * Sets status of pursuit risk.
	 * @param string Status of pursuit risk.
	 * @throws InvalidArgumentException
     */
	public function setStatus($status)
	{
	    if (in_array($status, self::getStatuses()) || ($status === NULL))
			$this->status = $status;
		else
			throw new InvalidArgumentException('Pursuit risk status must be in set of pre defined statuses. Wrong param: ' . $status);
	}
    
    /**
     * Gets status of pursuit risk.
     * @return string
     */
	public function getStatus()
	{
		return $this->status;
	}
	
    /** 
     * Sets remarks. 
     *  
     * @param string $remarks  
     */ 
    public function setRemarks($remarks) 
    { 
            $this->remarks = $remarks; 
    } 

    /** 
     * Gets remakrs. 
     *  
     * @return string 
     */ 
    public function getRemarks() 
    { 
            return $this->remarks; 
    }
	
    /**
     * Returns array of available statuses.
     * 
     * @return array
     */
	public static function getStatuses()
	{
		return array(	self::PURSUIT_RISK_STATUS_NOT_MITIGATE => self::PURSUIT_RISK_STATUS_NOT_MITIGATE,
						self::PURSUIT_RISK_STATUS_WATCH => self::PURSUIT_RISK_STATUS_WATCH,
						self::PURSUIT_RISK_STATUS_CLOSED => self::PURSUIT_RISK_STATUS_CLOSED
					);
	}
}
