<?php

/**
 * This file is part of the ATE Tool - STRAP addon
 *
 * Copyright (c) 2009, 2011 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Class for accessing Red Team from database using dibi.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class RedTeamDibiMapper extends DibiMapper implements IRedTeamMapper
{
	/**
	 * Creates RedTeam instance from DibiRow.
	 * 
	 * @param DibiRow $row
	 * @return	RedTeam 
	 */
    private function load(DibiRow $row)
    {
		$redTeam = new RedTeam();
		$redTeam->ID = $row->EID;
		$redTeam->PursuitID = $row->Pursuit_ID;
		return $redTeam;
    }
	
	/**
	 * Saves new RedTeam.
	 * 
	 * @param RedTeam $redTeam
	 * @return boolean
	 */
	public function save(RedTeam $redTeam)
	{
        try
        {
            $array = array();
			$array['EID'] = $redTeam->ID;
			$array['Pursuit_ID'] = $redTeam->PursuitID;
            $this->conn->insert('RedTeam', $array)->execute();
			return true;
        }
        catch (DibiException $e)
        {
            Debugger::log("Insert new RedTeam with eid: " . $redTeam->ID . " failed: " . $e->getMessage(), Debugger::ERROR);
            return false;
        }
	}
	
	/**
	 * Updates RedTeam.
	 * 
	 * @param RedTeam $redTeam
	 * @return boolean
	 */
	public function update(RedTeam $redTeam)
	{
        try
        {
            $array = array();
			$array['EID'] = $redTeam->ID;
			$array['Pursuit_ID'] = $redTeam->PursuitID;
            $this->conn->update('RedTeam', $array)->where('[EID] = %s AND [Pursuit_ID] = %i', $redTeam->ID, $redTeam->PursuitID)->execute();
			return true;
        }
        catch (DibiException $e)
        {
            Debugger::log("Update of RedTeam with EID = " . $redTeam->ID . " failed: " . $e->getMessage(), Debugger::ERROR);
            return false;
        }
	}
	
	/**
	 * Deletes existing RedTeam member.
	 * 
	 * @param string $eid PersonEID
	 * @param int $pursuit Pursuit ID
	 * @return boolean
	 */
	public function delete($eid, $pursuitID)
	{
		try
		{
		    $result = $this->conn->delete('RedTeam')->where('[EID] = %s AND [Pursuit_ID] = %i', $eid, $pursuitID)->execute();
			if ($result)
				Debugger::log("RedTeam with ID = " . $eid . " was deleted.", Debugger::INFO);
			else
				Debugger::log("Deleting of RedTeam with ID = " . $eid . " failed.", Debugger::ERROR);
			return $result;
		}
        catch (DibiException $e)
        {
            Debugger::log("Deleting of RedTeam with ID = " . $eid . " failed: ".$e->getMessage(), Debugger::ERROR);
            return false;
        }
	}

	/**
	 * Gets redteam memeber by eid and purusit ID.
	 * 
	 * @param string $eid PersonEID
	 * @param int $pursuit Pursuit ID
	 * @return RedTeam or null if not found
	 */
	public function find($eid, $pursuitID)
	{
		$redTeam_db_result = $this->conn->select('*')->from('RedTeam')->where('[EID] = %s AND [Pursuit_ID] = %i', $eid, $pursuitID)->fetch();
		if ($redTeam_db_result !== FALSE)
			return $this->load($redTeam_db_result);
		else
			return NULL;
	}
	
	/**
	 * Gets RedTeam by purusit ID.
	 * 
	 * @param int $pursuitID Pursuit ID
	 * @return array Of RedTeam or empty array if not found
	 */
	public function findByPursuitID($pursuitID)
	{
		$redTeam_db_result = $this->conn->select('*')->from('RedTeam')->where('[Pursuit_ID] = %i', $pursuitID)->fetchAll();
		
		$redTeam_array = array();
		if ($redTeam_db_result !== FALSE)
		{
			foreach ($redTeam_db_result as $row)
				$redTeam_array[] = $this->load($row);
		}
		return $redTeam_array;
	}
}
