<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2015 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Statistics single record
 *
 * @author Vojtech Obrusnik <vojtech.obrusnik@honeywell.com>
 */
class Statistics extends Object
{	
    /** @var int Id of record */
    private $id;
    /** @var int Type of action */
    private $action;
    /** @var string Details of action */
    private $detail;
    /** @var int Number of action occurrence */
    private $counter;
    /** @var string Id of user who triggered action */
    private $user;

    public function  __construct() 
    {}

    /**
     * Sets id
     *
     * @param int $id
     * @throws InvalidArgumentException
     */
    public function setId($id)
    {
        if (!is_numeric($id))
            throw new InvalidArgumentException('Id should be integer number. Wrong param: ' . $id);

        $this->id = $id;
    }

    /**
     * Gets id
     *
     * @return int
     */
    public function getId()
    {
        return $this->id;
    }

	/**
	 * Sets action
	 * 
	 * @param int $action Should be in range of Statistics::ACTION_*
	 * @throws InvalidArgumentException
	 */
	public function setAction($action)
	{
		if (!in_array($action, self::getActions()))
			throw new InvalidArgumentException('Action must be in range of IStatistics::*. Wrong param: ' . $action);

        $this->action = $action;
	}
	
	/**
	 * Gets action
	 * 
	 * @return int
	 */
	public function getAction()
	{
		return $this->action;
	}
	
	/**
	 * Gets all possible action values
	 * 
	 * @return array List of actions. IStatistics::*
	 */
	public static function getActions()
	{
		return array(
			IStatistics::CLICK,
			IStatistics::VISIT
		);
	}

    /**
     * Sets detail
     *
     * @param string $detail
     */
    public function setDetail($detail)
    {
        $this->detail = $detail;
    }

    /**
     * Gets detail
     *
     * @return string
     */
    public function getDetail()
    {
        return $this->detail;
    }

    /**
     * Sets counter
     *
     * @param int $number
     * @throws InvalidArgumentException
     */
    public function setCounter($number)
    {
        if (!is_numeric($number) && ($number !== null))
            throw new InvalidArgumentException('Counter should be integer number. Wrong param: ' . $number);

        $this->counter = $number;
    }

    /**
     * Gets counter
     *
     * @return int
     */
    public function getCounter()
    {
        return $this->counter;
    }

    /**
     * Sets user
     *
     * @param string $eid
     */
    public function setUser($eid)
    {
        $this->user = Person::processEID($eid);
    }

    /**
     * Gets user
     *
     * @return string
     */
    public function getUser()
    {
        return $this->user;
    }
}