<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2015 Honeywell International spol. s r.o.
 *
 * For the full copyright and licence information, please view
 * the file licence.txt that was distributed with this source code.
 * @package models
 */

/**
 * Statistics repository access class.
 *
 * @author Vojtech Obrusnik <vojtech.obrusnik@honeywell.com>
 */
class StatisticsRepository
{
	/** @var IStatisticsMapper */
 	private $mapper;
	
	public function __construct(IStatisticsMapper $mapper)
    {
        $this->mapper = $mapper;
    }
	
	/**
	 * Saves record
	 *
	 * @param Statistics $stat
	 * @return boolean True on success, false otherwise
	 */
	public function save(Statistics $stat)
	{		
		return $this->mapper->save($stat);
	}

	/**
	 * Updates record
	 *
	 * @param Statistics $stat
	 * @return boolean True on success, false otherwise
	 */
	public function update(Statistics $stat)
	{		
		return $this->mapper->update($stat);
	}
    
    /**
	 * Increments action counter if action exists or saves record
	 *
	 * @param Statistics $stat
	 * @return boolean True on success, false otherwise
	 */
	public function add(Statistics $stat)
	{
		$old = $this->findByContent($stat->Action, $stat->Detail, $stat->User);
		if ($old)
		{
            $old->Counter = $old->Counter + 1;
            return $this->update($old);
		}
        
        return $this->save($stat);
	}
	
	/**
	 * Deletes record
	 * 
	 * @throws InvalidStateException
	 */
	public function delete()
	{
		$this->mapper->delete();
	}
	
	/**
	 * Finds record
	 * 
	 * @throws InvalidStateException
	 */
	public function find()
	{
		$this->mapper->find();
	}
	
	/**
	 * Finds all records
	 *
	 * @throws InvalidStateException
	 */
	public function findAll()
	{
		$this->mapper->findAll();
	}
	
	/**
	 * Finds record by content
	 *
	 * @param int $action
	 * @param string $detail
	 * @param string $user
	 * @return Statistict Or null if not found
	 */
	public function findByContent($action, $detail, $user)
	{
		return $this->mapper->findByContent($action, $detail, $user);
	}
}