<?php

/**
 * Data container describing Task
 */
class TaskDepreciated implements iProject
{
    public $Task_ID;
    public $SAP_ID;
//    public $WorkPackage_ID;
    public $Name;
//    public $TaskPlan;
//    public $Date;
//    public $CostCenter_ID;
    public $LabourTask;
//    public $Remark;
//    public $CostShare;

    public $level;
    public $plans;
    public $resources;
    public $actuals;
    
    public function  __construct($Task_ID = NULL)
    {
        $this->plans = $this->resources = $this->actuals = array();
        if ($Task_ID != NULL)
        {

            // init self
            $TaskDB = dibi::select('*')->from('Task')->where('[Task_ID] = %i', $Task_ID)->fetch();

            foreach(get_object_vars($this) as $name => $value){
                $this->$name = trim(@$TaskDB->$name);
            }
	        $this->plans = $this->resources = $this->actuals = array();

            // get task plans
            $TaskPlansDB = dibi::select('*')->from('TaskPlan')->where('[Task_ID] = %i', $this->Task_ID)->fetchAll();
            foreach($TaskPlansDB as $TaskPlanDB){
                $TaskPlan = new TaskPlan($TaskPlanDB->TaskPlan_ID);
                $this->plans[$TaskPlan->TaskPlan_ID] = $TaskPlan;
            }

            // get planned resources
            $Person_TasksDB = dibi::select('*')->from('Person_Task')->where('[Task_ID] = %i', $this->Task_ID)->fetchAll();
            foreach($Person_TasksDB as $Person_TaskDB){
                $Person_Task = new Person_Task($Person_TaskDB->Person_Task);
                $this->resources[$Person_Task->Person_Task] = $Person_Task;
            }

            // get actuals
            $ActualsDB = dibi::select('*')->from('Actuals')->where('[ChargeNumber] = %s', $this->SAP_ID)->fetchAll();
            foreach($ActualsDB as $ActualDB){
                $Actual = new Actual($ActualDB->EID, $ActualDB->ChargeNumber, $ActualDB->Year, $ActualDB->FiscalMonth);
                $this->actuals[] = $Actual;
            }

        }
        
    }

    public function getChildren()
    {
        return array();
    }

    public function getPlannedLaborHours($Year, $months = array('January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'))
    {

        if(!(is_array($months)))
            $months = array($months);

        $sum = 0;
        foreach($this->plans as $plan)
            if($Year == $plan->Year)
            {
                foreach($months as $month)
                {
                    $string = substr($month, 0, 3) . "Hrs";
                    $sum += $plan->$string;
                }
            }
        return $sum;

    }

    public function getAssignedHours($Year, $months = array('January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'))
    {

        if(!is_array($months))
            $months = array($months);

        $sum = 0;

        foreach($this->resources as $record)
        {
            if($record->Year == $Year)
                foreach($months as $month)
                {
					$monthNumber = FiscalCalendar::fiscalMonthNameToIndex($month);
                    if($record->Month == $monthNumber)
                        $sum += $record->Hours;
                }
        }

        return $sum;

    }

    public function getActualHours($Year, $months = array('January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'))
    {

        if(!is_array($months))
            $months = array($months);

        $sum = 0;

        foreach($this->actuals as $record)
        {
            if($record->Year == $Year)
                foreach($months as $month)
                {
					$monthNumber = FiscalCalendar::fiscalMonthNameToIndex($month);
                    if($record->FiscalMonth == $monthNumber)
                        $sum += $record->Hours;
                }
        }

        return $sum;

    }

    public function getResources($Year)
    {

        $resources = array();

        foreach($this->resources as $resource)
            if($resource->Year == $Year)
            {
                if(!isset($resources[$resource->EID]))
                {
//                    $resources[$resource->EID] = array();
                    $resources[$resource->EID]['EID'] = $resource->EID;
                    $resources[$resource->EID]['Surname'] = $resource->Surname;
                    $resources[$resource->EID]['Name'] = $resource->Name;
                    $resources[$resource->EID]['resources'] = array();
                    for($month = 0; $month < 12; $month++)
                        $resources[$resource->EID]['resources'][$month] = 0;
                }
                $resources[$resource->EID]['resources'][$resource->Month] += $resource->Hours;
            }
            
//        echo "<pre>"; print_r($resources);

        return $resources;

    }

    public function getActuals($Year)
    {

        $actuals = array();

        foreach($this->actuals as $actual)
            if($actual->Year == $Year)
            {
                if(!isset($actuals[$actual->EID]))
                {
                    $actuals[$actual->EID] = array();
                    $actuals[$actual->EID]['EID'] = $actual->EID;
                    $actuals[$actual->EID]['Surname'] = $actual->Surname;
                    $actuals[$actual->EID]['Name'] = $actual->Name;
                    $actuals[$actual->EID]['ChargeNumber'] = $actual->ChargeNumber;
                    $actuals[$actual->EID]['actuals'] = array();
                    for($month = 0; $month < 12; $month++)
                        $actuals[$actual->EID]['actuals'][$month] = 0;
                }
                $actuals[$actual->EID]['actuals'][$actual->FiscalMonth] += $actual->Hours;
            }

//        echo "<pre>"; print_r($actuals);

        return $actuals;

    }

}
