<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2011 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Year plan for a task.
 * 
 * Contains 12 month plans (class MonthPlan) containing
 * budgets and work-hours for whole year.
 *
 * @author Martin Kotlar <martin.kotlar@honeywell.com>
 * @todo monthPLans should be of MonthArray class
 */
class TaskYearPlan extends Object
{
	/** @var int Year for which this plan is prepared. */
	private $year = 0;
	/** @var int ID of the year plan. */
	private $taskPlanID = 0;
	/** @var int ID of the task this plan belongs to. */
	private $taskID = 0;
	/** @var array of month plans */
	private $monthPlans;
	/** @var int Date and time when plan was created. */
	private $date;
	
	public function __construct($year = 0)
	{
		$this->monthPlans = array();
		for ($i = 1; $i <= 12; $i++)
			$this->monthPlans[$i] = new MonthPlan(0, 0);
		$this->setYear($year);
	}

    /**
     * Set year.
     * 
     * @param int $year Must be positive integer or 0.
     */
	public function setYear($year)
	{
		if (is_numeric($year) && ($year >= 0))
			$this->year = 0 + $year;
		else
			throw new InvalidArgumentException('Year must be integer greater or equal to 0. Wrong param: '.$year);
	}

    /**
     * Gets year.
     * 
     * @return int
     */
	public function getYear()
	{
		return $this->year;
	}

    /**
     * Set ID.
     * 
     * @param int $id Must be positive integer.
     */
	public function setID($id)
	{
		if ($id > 0)
			$this->taskPlanID = $id;
		else
			throw new InvalidArgumentException('ID must be integer greater than 0. Wrong param: '.$id);
	}

    /**
     * Set ID.
     * 
     * @param int $id Must be positive integer.
	 * @deprecated
     */
	public function setTaskPlanID($id)
	{
		$this->setID($id);
	}
	
    /**
     * Gets ID.
     * 
     * @return int
     */
	public function getID()
	{
		return $this->taskPlanID;
	}

    /**
     * Gets ID.
     * 
     * @return int
	 * @deprecated
     */
	public function getTaskPlanID()
	{
		return $this->getID();
	}
	
    /**
     * Set ID of task to which this plan belogs.
     * 
     * @param int $id Must be positive integer.
     */
	public function setTaskID($id)
	{
		if ($id > 0)
			$this->taskID = $id;
		else
			throw new InvalidArgumentException('Task ID must be integer greater than 0. Wrong param: '.$id);
	}
	
    /**
     * Gets ID of task to which this plan belogs.
	 * If 0, plan was not assigned to a task yet.
     * 
     * @return int
     */
	public function getTaskID()
	{
		return $this->taskID;
	}

    /**
     * Set date of creation.
     * 
     * @param string $datetime Date time in YYYY-MM-DD hh:mm:ss format.
	 * @todo Check format of $datetime.
     */
	public function setDate($datetime)
	{
		$this->date = $datetime;
	}
	
    /**
     * Gets date of creation.
     * 
     * @return string
     */
	public function getDate()
	{
		return $this->date;
	}
	
	
    /**
     * Set month plan.
     * 
     * @param $month int	Must be integer from 1 to 12.
     * @param $plan MonthPlan
     */
	public function setMonthPlan($month, MonthPlan $plan)
	{
		if (is_int($month) && ($month >= 1) && ($month <= 12))
			$this->monthPlans[$month] = $plan;
		else
			throw new InvalidArgumentException($month . ' is not integer from 1 to 12.');
	}
	
	/**
     * Get month plan.
     * 
     * @param int $month Must be integer from 1 to 12.
	 * @return MonthPlan
     */
	public function getMonthPlan($month)
	{
		if (is_int($month) && ($month >= 1) && ($month <= 12))
			return $this->monthPlans[$month];
		else
			throw new InvalidArgumentException($month . ' is not integer from 1 to 12.');
	}
    
    /**
     * Get all month plans.
     * @return array Array of MonthPlan where key is month number [1..12]
     */
    public function getMonthPlans()
    {
        return $this->monthPlans;
    }
    
}


