<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2011 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Database access to user settings using Dibi.
 *
 * @author Martin Kotlar <martin.kotlar@honeywell.com>
 */
class UserSettingDibiMapper extends DibiMapper implements IUserSettingMapper
{

	/**
	 * Creates UserSetting class instance from DibiRow.
	 * 
	 * @param DibiRow $row
	 * @return	UserSetting 
	 */
    private function load(DibiRow $row)
    {
		$setting = new UserSetting();
		// TODO: Objects could have their attributes marked by annotations to map them to attributes (see Doctrine 2)
		$reflection = $setting->getReflection();
        foreach ($row as $prop => $val) 
		{
			if ($reflection->hasProperty(''.$prop))
				$setting->$prop = $val;
        }
		return $setting;
    }	

	/**
	 * Inserts user's settings into database.
	 * 
	 * @param UserSetting $setting User ID.
	 * @param string $id User ID.
	 */
	public function insert(UserSetting $setting, $id)
	{        
		try
        {
            $data = array(
                "EID" => $id,
                'WBSShowLabourTasksOnly' => $setting->WBSShowLabourTasksOnly,
                'WBSShowCurrentYear' => $setting->WBSShowCurrentYear,
                'WBSHideFirstWP' => $setting->WBSHideFirstWP,
                'WBSHideAllWP' => $setting->WBSHideAllWP,
                'WBSHideTasksWithoutEffort' => $setting->WBSHideTasksWithoutEffort,
                'EXPDecimalMark' => $setting->EXPDecimalMark,
                'PROOwnSelect' => $setting->PROOwnSelect,
				'ShowFakeProjects' => $setting->ShowFakeProjects,
				'ShowFakeTasks' => $setting->ShowFakeTasks
            );
            $this->conn->insert('Setting', $data)->execute();
            return true;
        }
        catch (DibiException $e)
        {
            Debugger::log("Setting of person: ".Environment::getUser()->getId()." insert failed!. ".$e->getMessage(), Debugger::ERROR);
            return false;
        }
	}
    
	/**
	 * Saves user's settings into database.
	 * 
	 * @param UserSetting $setting User ID.
	 * @param string $id User ID.
	 */
	public function save(UserSetting $setting, $id)
	{
        try
        {
			$data = array(
				'WBSShowLabourTasksOnly' => $setting->WBSShowLabourTasksOnly,
				'WBSShowCurrentYear' => $setting->WBSShowCurrentYear,
				'WBSHideFirstWP' => $setting->WBSHideFirstWP,
				'WBSHideAllWP' => $setting->WBSHideAllWP,
				'WBSHideTasksWithoutEffort' => $setting->WBSHideTasksWithoutEffort,
				'EXPDecimalMark' => $setting->EXPDecimalMark,
				'PROOwnSelect' => $setting->PROOwnSelect,
				'ShowFakeProjects' => $setting->ShowFakeProjects,
				'ShowFakeTasks' => $setting->ShowFakeTasks
			);
            $wp_db_result = $this->conn->update('Setting', $data)->where('EID = %s', $id)->execute();
            return true;
        }
        catch (DibiException $e)
        {
            Debugger::log("User setting update failed. " . $e->getMessage(), Debugger::ERROR);
            return false;
        }
	}
	
	/**
	 * Returns user's application setting from databse by user ID.
	 * 
	 * @param string $id User ID.
	 * @return	UserSetting Returns instance or NULL if not found.
	 */
	public function find($id)
	{
		$setting_db_result = $this->conn->select('*')->from('Setting')->where('[EID] = %s', $id)->fetch();
                if ($setting_db_result)
                    if ($setting_db_result->count() > 0)
                        return $this->load($setting_db_result);
                
                return NULL;
	}
}
