<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2011 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Repository with user settings.
 *
 * @author Martin Kotlar <martin.kotlar@honeywell.com>
 */
class UserSettingRepository extends Object
{

    /** @var IUserSettingMapper */
 	private $mapper;
	/** @var MultiLogger */
	private $multilog;

    public function __construct(IUserSettingMapper $mapper)
    {
        $this->mapper = $mapper;
		$this->multilog = new MultiLogger();
		$batch_id = 'UserSetting-'.time().'-'.rand(1, 9);
		$this->multilog->add(Environment::getContext()->createLogger($batch_id, "User Setting"));
    }	

    /**
     * Saves current logged user's settings to repository.
     * 
	 * @param UserSetting $setting
     * @return UserSetting
     */
	public function save(UserSetting $setting)
    {
		$user_id = Environment::getUser()->getId();
		$oldObject = $this->find($user_id);
		if($this->mapper->save($setting, $user_id))
		{
			$this->multilog->log('Settings for user : ' . $user_id . ' updated. ' . $this->multilog->differences($oldObject, $setting), ILogger::INFO);
			return true;
		}
		else
		{
			return false;
		}
    }

    /**
     * Finds user settings by its ID.
     * 
	 * @param string $user_id Emplyee ID.
     * @return UserSetting
     */
    public function find($user_id)
    {
        if ($this->mapper->find($user_id) == null)
        {
            $setting = new UserSetting();
            $this->mapper->insert($setting, $user_id);
            return $setting;
        }
        else
            return $this->mapper->find($user_id);
    }

    /**
     * Finds current effective (logged user's) settings.
     * 
     * @return UserSetting
     */
    public function actual()
    {
		$user_id = Environment::getUser()->getId();
        return $this->mapper->find($user_id);
    }
	
    /**
	 * Inserts user's settings into database.
	 * 
	 * @param UserSetting $setting User ID.
	 * @param string $id User ID.
	 */
	public function insert(UserSetting $setting, $id)
    {
		if($this->mapper->insert($setting, $id))
		{
			$this->multilog->log('Settings for user : ' . $id . ' saved.', ILogger::INFO);
			return true;
		}
		else
		{
			return false;
		}
    }
}
