<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2011 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Class is a WorkPackage definition. It is an organizational
 * unit for organizing tasks of a project in a tree structure of work packages.
 * 
 * @author Martin Kotlar <martin.kotlar@honeywell.com>
 * @dbtable WorkPackage
 */
class WorkPackage extends Object implements WBSElement
{

    /** 
	 * @var int Unique ID. Positive integer or 0 for new. 
	 * @property
	 * @dbcolumn WorkPackage_ID
	 */
	private $id;
    /** @var string ID for correspondence with external IS (SAP). */
	private $sapID;
    /** @var int ID of owner project. */
	private $projectID;
    /** @var int ID of owner work package. */
	private $parentWorkPackageID;
    /** @var string Work package name. */
	private $name;
    /** @var string Work package creation date. */
	private $date;
	
	public function __construct() 
	{
	}

    /**
     * Sets WorkPackage SAP ID (ID for connecting WorkPackage to external IS).
     * 
     * @param string $id SAP ID.
     */
    public function setID($id)
    {
		if (is_numeric($id) && (is_int(0 + $id)) && ($id >= 0))
			$this->id = $id;
		else
			throw new InvalidArgumentException('WorkPackage ID must be non-negative integer. Invalid value:' . $id);
    }

    /**
     * Gets WorkPackage SAP ID.
     * 
     * @return int
     */
    public function getID()
    {
        return $this->id;
    }
	
    /**
     * Sets WorkPackage SAP ID (ID for connecting WorkPackage to external IS).
     * 
     * @param string $id SAP ID.
     */
    public function setSAPID($id)
    {
		$this->sapID = $id;
    }

    /**
     * Gets WorkPackage SAP ID.
     * 
     * @return string
     */
    public function getSAPID()
    {
        return $this->sapID;
    }

    /**
     * Sets WorkPackage project ID (project it belongs to).
	 * Project ID must be positive integer or 0 (temporarily) if WorkPackage 
	 * is a sub-WorkPackage to another WorkPackage.
     * 
     * @param int $id Project ID (NULL -> 0).
	 * @todo Every WorkPackage should have a ProjectID (every WP belongs to a Project).
     */
    public function setProjectID($id)
    {
		if (is_null($id))
			$this->projectID = 0;
		else
			if (is_numeric($id) && (is_int(0 + $id)) && ($id >= 0))
				$this->projectID = 0 + $id;
			else
				throw new InvalidArgumentException('WorkPackage project ID must be non-negative integer.');
    }

    /**
     * Gets WorkPackage project ID.
     * 
     * @return int
     */
    public function getProjectID()
    {
        return $this->projectID;
    }
	
    /**
     * Sets WorkPackage's parent WorkPackage ID.
	 * Parent ID must be positive integer or zero if WorkPackage is in top
	 * level of WorkPackage tree (it's parent is Project).
     * 
     * @param int $id WorkPackage parent ID (NULL -> 0).
     */
    public function setParentID($id)
    {
		if (is_null($id))
			$this->parentWorkPackageID = 0;
		else
			if (is_numeric($id) && (is_int(0 + $id)) && ($id >= 0))
				$this->parentWorkPackageID = 0 + $id;
			else
				throw new InvalidArgumentException('WorkPackage parent ID must be non-negative integer.');
    }

    /**
     * Gets WorkPackage parent WorkPackage ID.
     * 
     * @return int
     */
    public function getParentID()
    {
        return $this->parentWorkPackageID;
    }
	
    /**
     * Sets WorkPackage name.
     * 
     * @param string $name WorkPackage name.
	 * @todo Should name of WorkPackage be not null?
     */
    public function setName($name)
    {
		$this->name = $name;
    }

    /**
     * Gets WorkPackage name.
     * 
     * @return string
     */
    public function getName()
    {
        return $this->name;
    }
	
    /**
     * Sets WorkPackage creation date.
	 * Date should be in Y-m-d H:i:s format.
     * 
     * @param string $date Date.
	 * @todo Test date format.
     */
    public function setDate($date)
    {
		$this->date = $date;
    }

    /**
     * Gets WorkPackage creation date.
     * 
     * @return string
     */
    public function getDate()
    {
        return $this->date;
    }
	
}
