<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2011 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package utils\Forms
 */

/**
 * Defines interface toform state repository. 
 *
 * @author Martin Kotlar <martin.kotlar@honeywell.com>
 */
interface IFormStateRepository
{
	
	/**
	 * Loads/populates data into given form (updates given object).
	 * 
	 * @param string $key Identifier of saved form.
	 * @param Form $form Application form to populate with data.
	 * @return	boolean Returns TRUE on success and FALSE if state is not available.
	 * @throws InvalidArgumentException if $key is unknown.
	 */
	public function load($key, Form $form);

	/**
	 * Saves form data into state repository.
	 * 
	 * If there is already saved state, it rewrites the state of form
	 * (but doesn't update it, just drops previous data).
	 * 
	 * @param string $key Identifier for saved form.
	 * @param Form $form Application form to save.
	 * @return	boolean Returns TRUE on success.
	 */
	public function save($key, Form $form);

	/**
	 * Checks whether there is already saved state under given key.
	 * 
	 * If there is already saved state, it rewrites the state of form
	 * (but doesn't update it, just drops previous data).
	 * 
	 * @param string $key Identifier for saved form.
	 * @return	boolean Returns TRUE if saved state found.
	 */
	public function exists($key);

	/**
	 * Drops saved state if it exists.
	 * 
	 * @param string $key Identifier for saved form.
	 * @return	boolean Returns TRUE if saved state was dropped and FALSE if it wasn't found.
	 */
	public function drop($key);
	
}


