<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2014 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models\Import
 */

/**
 * iASAP access class for HTS TRV Task SAP ID
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class HtsTrvTaskSAPID extends IASAPWrapper
{
	/** @var string HTS Workpackage SAP ID*/
	private $wpSAPID;
	
	/**
	 * @param string $wpSAPID HTS Workpackage SAP ID
	 * @param ILogger $logger
	 */
	public function __construct($wpSAPID, ILogger $logger = NULL)
	{
		parent::__construct($logger);
		
		$this->wpSAPID = $wpSAPID;
	}
	
	/**
	 * Gets value of HTS Workpackage SAP ID
	 * @return string
	 */
	public function getWpSapID()
	{
		return $this->wpSAPID;
	}
	
	/**
	 * Finds HTS TRV Task iASAP ID
	 * @return array Task SAP ID - array('taskName' => '', 'network' => '', 'def' => '')
	 */
	public function findHtsTrvTaskSAPID()
	{
		$htsTrvTaskSAPID = array('taskName' => '', 'network' => '', 'def' => '');
		
		try
		{
			$db_result = $this->conn->query('SELECT [ps_activity.l2Description], [ps_activity.network], [ps_activity.activityDefinition]
											FROM [ps_activity] WHERE [ps_activity.l2Definition] = %s', $this->wpSAPID)->fetchAll();
		}
        catch (DibiException $e)
        {
            Debugger::log("HTS TRV Task SAP ID was not found! " . $e->getMessage(), Debugger::ERROR);
            return false;
        }

		if ($db_result)
		{
			$htsTrvTaskSAPID['taskName'] = $db_result[0]->l2Description;
			$htsTrvTaskSAPID['network'] = $db_result[0]->network;
			$htsTrvTaskSAPID['def'] = $db_result[0]->activityDefinition;
			return $htsTrvTaskSAPID;
		}
		else
		{
			return false;
		}
	}
}