/**
 * This file is part of the HON Tool
 *
 * Copyright (c) 2009, 2015 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * 
 * Definition of behavior of form error message
 */

/** @var boolean Lock of visibility of form error message */
var form_emsg_lock = false;

/** @var string Set of form fields which may contain error message */
var form_emsg_set = 'input.form-control-error,\
                     select.form-control-error,\
                     textarea.form-control-error';

/**
 * Form error message visibility change according to current state
 */
$(document).on({
    mouseenter: function () {
        if (!form_emsg_lock)
            showFormErrorMessage($(this).attr('id'));
    },
    mouseleave: function () {
        if (!form_emsg_lock)
            hideFormErrorMessage($(this).attr('id'));
    },
    click: function () {
        form_emsg_lock = true;
        showFormErrorMessage($(this).attr('id'));
    },
    blur: function () {
        form_emsg_lock = false;
        hideFormErrorMessage($(this).attr('id'));
    },
    focusin: function () {
        form_emsg_lock = true;
        hideAllFormErrorMessages();
        showFormErrorMessage($(this).attr('id'));
    }
}, form_emsg_set);

/**
 * Shows error message of given form form field
 * @param string field_id Unique id of form field
 */
function showFormErrorMessage(field_id)
{
    var emsg = new FormErrorMessage(field_id);
    emsg.show();
}

/**
 * Hides error message of given form field
 * @param string field_id Unique id of form field
 */
function hideFormErrorMessage(field_id)
{
    var emsg = new FormErrorMessage(field_id);
    emsg.hide();
}

/**
 * Hides all form error messages
 */
function hideAllFormErrorMessages()
{
    $(form_emsg_set).each(function () {
        hideFormErrorMessage($(this).attr('id'));
    });
}

/**
 * Definition of wrapper for error message of form field
 * @param string field_id Unique id of form field
 */
var FormErrorMessage = function (field_id)
{
    /** @var object Form field */
    this.field = $(document).find('#' + field_id);
    /** @var object Error message binded to form field */
    this.emsg = $('div#' + this.field.closest('form').attr('id').replace('-', '') + '-' + this.field.attr('name') + '_message');
}

/**
 * Initializes position of error message block
 */
FormErrorMessage.prototype.initPosition = function() {
    var top_margin = 9;
    var top = this.field.position().top - this.emsg.height() - top_margin;
    var left = this.field.position().left;

    this.emsg.css('top', top + 'px').css('left', left + 'px');
};

/**
 * Initializes width of error message block
 */
FormErrorMessage.prototype.initWidth = function() {
    var border = $(document).width() - parseInt($('body').css('margin-left')) - parseInt($('body').css('margin-right'));
    var emsg_end = this.field.position().left + this.emsg.width();

    if (emsg_end > border)
    {
        var width = this.emsg.width() - (emsg_end - border) - parseInt(this.emsg.css('padding-left')) - parseInt(this.emsg.css('padding-right'));
        this.emsg.css('max-width', width + 'px');
    }
};

/**
 * Shows error message block
 */
FormErrorMessage.prototype.show = function() {
    this.initPosition();
    this.initWidth();
    this.emsg.show();
};

/**
 * Hides error message block
 */
FormErrorMessage.prototype.hide = function() {
    this.emsg.hide();
};