

/**
 * Ajax handle for organization unit selector
 * @param object element Should be reference to currently changed combo box of organization unit selector
 */
function handleOrganizationUnitSelector(element)
{
	// Kill function, because cannot find dependencies without input
	if (!element)
		return false;
	
	// List of part names of selector container
	var container_parts = ['SBE', 'Department', 'Cluster', 'TechnicalGroup'];
	// Container name
	var container_name = element.attr('name').replace(/\[.*?\]/g, '');
	// Get part name only
	var part_name = element.attr('name').replace(new RegExp(container_name + '\\[(.*?)\\]', 'g'), '$1');
	// Value of changed element
	var value = element.val();
	
	// Request with empty value will reset all selected values in container,
	// so try to find first non-empty value on higher level and send it
	if (!value)
	{
        for (var i = $.inArray(part_name, container_parts) - 1; i >= 0; i--)
		{
			value = $('select[name="'+container_name+'['+container_parts[i]+']"]').val();
			if (value)
				break;
		}
	}

	$.ajax({
		url: $('input[name="'+container_name+'[ajaxHandle]"]').val(), // Fetch prepared url of handle
		data: { id: value },
		success: function(payload){
			if (payload && (payload.organizationUnitSelectorResult))
			{
				// Clear all options from container parts except highest static level and prompts
				$('select[name*="'+container_name+'["][name!="'+container_name+'[SBE]"] option[value!=""]').each(function(){
					$(this).remove();
				});
				// Add new options
				if(payload.organizationUnitSelectorResult)
				{
					var result = payload.organizationUnitSelectorResult;
				}
				
				for (var part_name in result)
				{
					var values = sortValues(result[part_name].values);
					for (var name in values)
					{
						$('select[name="'+container_name+'['+part_name+']"][name!="'+container_name+'[SBE]"]').append($('<option>', {
							value: values[name],
							text: name
						}));
					}
					// Fill according to selection
					$('select[name="'+container_name+'['+part_name+']"]').val(result[part_name].id);
				}
			}
		},
		complete: function() {
			// Only filter form should be resubmitted, because it is necessary to store new form state.
			var closest_form = element.closest('form');
			if (closest_form.attr('id').match(/filter/gi))
				closest_form.submit();
		}
	});
}

/**
 * Sorts properties acording to values
 * @param object
 */
function sortValues(obj)
{
	var i;
	var names = [];
    var ids = {};
    var sorted = {};

    for (i in obj)
    {
    	names[names.length] = obj[i];
    	ids[obj[i]] = i;
    }

    names.sort();

    for (i in names)
    	sorted[names[i]] = ids[names[i]];

    return sorted;
}

// Updates organization unit selectors according to pre selected values
$(document).ready(function(){
    $('select[name*="[TechnicalGroup]"]').each(function(){
		handleOrganizationUnitSelector($(this));
	});
});

// Updates organization unit selector according to current state
$(document).on('change', 'select[name*="[SBE]"], select[name*="[Department]"], select[name*="[Cluster]"], select[name*="[TechnicalGroup]"]', function(){
	handleOrganizationUnitSelector($(this));
});